from __future__ import annotations 
from datetime import (
    datetime,
    date,
    time
)
from decimal import Decimal 
from enum import Enum 
import re
import sys
from typing import (
    Any,
    ClassVar,
    List,
    Literal,
    Dict,
    Optional,
    Union
)
from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    RootModel,
    field_validator
)
metamodel_version = "None"
version = "4.2.4"


class ConfiguredBaseModel(BaseModel):
    model_config = ConfigDict(
        validate_assignment = True,
        validate_default = True,
        extra = "forbid",
        arbitrary_types_allowed = True,
        use_enum_values = True,
        strict = False,
    )
    pass




class LinkMLMeta(RootModel):
    root: Dict[str, Any] = {}
    model_config = ConfigDict(frozen=True)

    def __getattr__(self, key:str):
        return getattr(self.root, key)

    def __getitem__(self, key:str):
        return self.root[key]

    def __setitem__(self, key:str, value):
        self.root[key] = value

    def __contains__(self, key:str) -> bool:
        return key in self.root


linkml_meta = LinkMLMeta({'default_curi_maps': ['obo_context',
                           'idot_context',
                           'monarch_context',
                           'semweb_context'],
     'default_prefix': 'biolink',
     'default_range': 'string',
     'description': 'Entity and association taxonomy and datamodel for '
                    'life-sciences data',
     'emit_prefixes': ['rdf', 'rdfs', 'xsd', 'skos', 'oboInOwl', 'BIOGRID', 'SO'],
     'id': 'https://w3id.org/biolink/biolink-model',
     'imports': ['linkml:types'],
     'license': 'https://creativecommons.org/publicdomain/zero/1.0/',
     'name': 'Biolink-Model',
     'prefixes': {'AGRKB': {'prefix_prefix': 'AGRKB',
                            'prefix_reference': 'https://www.alliancegenome.org/'},
                  'AspGD': {'prefix_prefix': 'AspGD',
                            'prefix_reference': 'http://www.aspergillusgenome.org/cgi-bin/locus.pl?dbid='},
                  'CAID': {'prefix_prefix': 'CAID',
                           'prefix_reference': 'http://reg.clinicalgenome.org/redmine/projects/registry/genboree_registry/by_caid?caid='},
                  'CHADO': {'prefix_prefix': 'CHADO',
                            'prefix_reference': 'http://gmod.org/wiki/Chado/'},
                  'CHEMBL.MECHANISM': {'prefix_prefix': 'CHEMBL.MECHANISM',
                                       'prefix_reference': 'https://www.ebi.ac.uk/chembl/mechanism/inspect/'},
                  'CID': {'prefix_prefix': 'CID',
                          'prefix_reference': 'http://pubchem.ncbi.nlm.nih.gov/compound/'},
                  'CLINVAR': {'prefix_prefix': 'CLINVAR',
                              'prefix_reference': 'http://identifiers.org/clinvar'},
                  'COAR_RESOURCE': {'prefix_prefix': 'COAR_RESOURCE',
                                    'prefix_reference': 'http://purl.org/coar/resource_type/'},
                  'COG': {'prefix_prefix': 'COG',
                          'prefix_reference': 'https://www.ncbi.nlm.nih.gov/research/cog-project/'},
                  'CPT': {'prefix_prefix': 'CPT',
                          'prefix_reference': 'https://www.ama-assn.org/practice-management/cpt/'},
                  'CTD': {'prefix_prefix': 'CTD',
                          'prefix_reference': 'http://ctdbase.org/'},
                  'CTD.CHEMICAL': {'prefix_prefix': 'CTD.CHEMICAL',
                                   'prefix_reference': 'http://ctdbase.org/detail.go?type=chem&acc='},
                  'CTD.DISEASE': {'prefix_prefix': 'CTD.DISEASE',
                                  'prefix_reference': 'http://ctdbase.org/detail.go?type=disease&db=MESH&acc='},
                  'CTD.GENE': {'prefix_prefix': 'CTD.GENE',
                               'prefix_reference': 'http://ctdbase.org/detail.go?type=gene&acc='},
                  'ChemBank': {'prefix_prefix': 'ChemBank',
                               'prefix_reference': 'http://chembank.broadinstitute.org/chemistry/viewMolecule.htm?cbid='},
                  'ComplexPortal': {'prefix_prefix': 'ComplexPortal',
                                    'prefix_reference': 'https://www.ebi.ac.uk/complexportal/complex/'},
                  'DGIdb': {'prefix_prefix': 'DGIdb',
                            'prefix_reference': 'https://www.dgidb.org/interaction_types'},
                  'DOID-PROPERTY': {'prefix_prefix': 'DOID-PROPERTY',
                                    'prefix_reference': 'http://purl.obolibrary.org/obo/doid#'},
                  'DrugCentral': {'prefix_prefix': 'DrugCentral',
                                  'prefix_reference': 'http://drugcentral.org/drugcard/'},
                  'ECTO': {'prefix_prefix': 'ECTO',
                           'prefix_reference': 'http://purl.obolibrary.org/obo/ECTO_'},
                  'EDAM-DATA': {'prefix_prefix': 'EDAM-DATA',
                                'prefix_reference': 'http://edamontology.org/data_'},
                  'EDAM-FORMAT': {'prefix_prefix': 'EDAM-FORMAT',
                                  'prefix_reference': 'http://edamontology.org/format_'},
                  'EDAM-OPERATION': {'prefix_prefix': 'EDAM-OPERATION',
                                     'prefix_reference': 'http://edamontology.org/operation_'},
                  'EDAM-TOPIC': {'prefix_prefix': 'EDAM-TOPIC',
                                 'prefix_reference': 'http://edamontology.org/topic_'},
                  'EFO': {'prefix_prefix': 'EFO',
                          'prefix_reference': 'http://www.ebi.ac.uk/efo/EFO_'},
                  'ExO': {'prefix_prefix': 'ExO',
                          'prefix_reference': 'http://purl.obolibrary.org/obo/ExO_'},
                  'FYECO': {'prefix_prefix': 'FYECO',
                            'prefix_reference': 'https://www.pombase.org/term/'},
                  'FYPO': {'prefix_prefix': 'FYPO',
                           'prefix_reference': 'http://purl.obolibrary.org/obo/FYPO_'},
                  'GOP': {'prefix_prefix': 'GOP',
                          'prefix_reference': 'http://purl.obolibrary.org/obo/go#'},
                  'GOREL': {'prefix_prefix': 'GOREL',
                            'prefix_reference': 'http://purl.obolibrary.org/obo/GOREL_'},
                  'GSID': {'prefix_prefix': 'GSID',
                           'prefix_reference': 'https://scholar.google.com/citations?user='},
                  'GTEx': {'prefix_prefix': 'GTEx',
                           'prefix_reference': 'https://www.gtexportal.org/home/gene/'},
                  'GTOPDB': {'prefix_prefix': 'GTOPDB',
                             'prefix_reference': 'https://www.guidetopharmacology.org/GRAC/LigandDisplayForward?ligandId='},
                  'HANCESTRO': {'prefix_prefix': 'HANCESTRO',
                                'prefix_reference': 'http://www.ebi.ac.uk/ancestro/ancestro_'},
                  'HCPCS': {'prefix_prefix': 'HCPCS',
                            'prefix_reference': 'http://purl.bioontology.org/ontology/HCPCS/'},
                  'HsapDv': {'prefix_prefix': 'HsapDv',
                             'prefix_reference': 'http://purl.obolibrary.org/obo/HsapDv_'},
                  'ICD10': {'prefix_prefix': 'ICD10',
                            'prefix_reference': 'https://icd.codes/icd9cm/'},
                  'ICD9': {'prefix_prefix': 'ICD9',
                           'prefix_reference': 'http://translator.ncats.nih.gov/ICD9_'},
                  'INO': {'prefix_prefix': 'INO',
                          'prefix_reference': 'http://purl.obolibrary.org/obo/INO_'},
                  'KEGG': {'prefix_prefix': 'KEGG',
                           'prefix_reference': 'http://www.kegg.jp/entry/'},
                  'KEGG.BRITE': {'prefix_prefix': 'KEGG.BRITE',
                                 'prefix_reference': 'https://bioregistry.io/kegg.brite:'},
                  'KEGG.GENES': {'prefix_prefix': 'KEGG.GENES',
                                 'prefix_reference': 'https://bioregistry.io/kegg.genes:bsu:'},
                  'KEGG.PATHWAY': {'prefix_prefix': 'KEGG.PATHWAY',
                                   'prefix_reference': 'https://bioregistry.io/kegg.pathway:'},
                  'KEGG.RCLASS': {'prefix_prefix': 'KEGG.RCLASS',
                                  'prefix_reference': 'https://www.genome.jp/dbget-bin/www_bget?rc:'},
                  'LOINC': {'prefix_prefix': 'LOINC',
                            'prefix_reference': 'http://loinc.org/rdf/'},
                  'MAXO': {'prefix_prefix': 'MAXO',
                           'prefix_reference': 'http://purl.obolibrary.org/obo/MAXO_'},
                  'MESH': {'prefix_prefix': 'MESH',
                           'prefix_reference': 'http://id.nlm.nih.gov/mesh/'},
                  'METANETX.REACTION': {'prefix_prefix': 'METANETX.REACTION',
                                        'prefix_reference': 'https://www.metanetx.org/equa_info/'},
                  'MI': {'prefix_prefix': 'MI',
                         'prefix_reference': 'http://purl.obolibrary.org/obo/MI_'},
                  'MSigDB': {'prefix_prefix': 'MSigDB',
                             'prefix_reference': 'https://www.gsea-msigdb.org/gsea/msigdb/'},
                  'MmusDv': {'prefix_prefix': 'MmusDv',
                             'prefix_reference': 'http://purl.obolibrary.org/obo/MMUSDV_'},
                  'NBO-PROPERTY': {'prefix_prefix': 'NBO-PROPERTY',
                                   'prefix_reference': 'http://purl.obolibrary.org/obo/nbo#'},
                  'NCBIGene': {'prefix_prefix': 'NCBIGene',
                               'prefix_reference': 'http://identifiers.org/ncbigene/'},
                  'NCIT-OBO': {'prefix_prefix': 'NCIT-OBO',
                               'prefix_reference': 'http://purl.obolibrary.org/obo/ncit#'},
                  'NDDF': {'prefix_prefix': 'NDDF',
                           'prefix_reference': 'http://purl.bioontology.org/ontology/NDDF/'},
                  'NLMID': {'prefix_prefix': 'NLMID',
                            'prefix_reference': 'https://www.ncbi.nlm.nih.gov/nlmcatalog/?term='},
                  'OBAN': {'prefix_prefix': 'OBAN',
                           'prefix_reference': 'http://purl.org/oban/'},
                  'OMIM.PS': {'prefix_prefix': 'OMIM.PS',
                              'prefix_reference': 'https://www.omim.org/phenotypicSeries/'},
                  'ORCID': {'prefix_prefix': 'ORCID',
                            'prefix_reference': 'https://orcid.org/'},
                  'PANTHER.FAMILY': {'prefix_prefix': 'PANTHER.FAMILY',
                                     'prefix_reference': 'http://www.pantherdb.org/panther/family.do?clsAccession='},
                  'PHARMGKB.DISEASE': {'prefix_prefix': 'PHARMGKB.DISEASE',
                                       'prefix_reference': 'https://www.pharmgkb.org/disease/'},
                  'PHARMGKB.DRUG': {'prefix_prefix': 'PHARMGKB.DRUG',
                                    'prefix_reference': 'https://www.pharmgkb.org/chemical/'},
                  'PHARMGKB.GENE': {'prefix_prefix': 'PHARMGKB.GENE',
                                    'prefix_reference': 'https://www.pharmgkb.org/gene/'},
                  'PHARMGKB.PATHWAYS': {'prefix_prefix': 'PHARMGKB.PATHWAYS',
                                        'prefix_reference': 'https://www.pharmgkb.org/pathway/'},
                  'PHARMGKB.VARIANT': {'prefix_prefix': 'PHARMGKB.VARIANT',
                                       'prefix_reference': 'https://www.pharmgkb.org/variant/'},
                  'PHAROS': {'prefix_prefix': 'PHAROS',
                             'prefix_reference': 'http://pharos.nih.gov'},
                  'PMC': {'prefix_prefix': 'PMC',
                          'prefix_reference': 'http://europepmc.org/articles/PMC'},
                  'PathWhiz': {'prefix_prefix': 'PathWhiz',
                               'prefix_reference': 'http://smpdb.ca/pathways/#'},
                  'PomBase': {'prefix_prefix': 'PomBase',
                              'prefix_reference': 'https://www.pombase.org/gene/'},
                  'REPODB': {'prefix_prefix': 'REPODB',
                             'prefix_reference': 'http://apps.chiragjpgroup.org/repoDB/'},
                  'RO': {'prefix_prefix': 'RO',
                         'prefix_reference': 'http://purl.obolibrary.org/obo/RO_'},
                  'RXCUI': {'prefix_prefix': 'RXCUI',
                            'prefix_reference': 'https://mor.nlm.nih.gov/RxNav/search?searchBy=RXCUI&searchTerm='},
                  'RXNORM': {'prefix_prefix': 'RXNORM',
                             'prefix_reference': 'http://purl.bioontology.org/ontology/RXNORM/'},
                  'ResearchID': {'prefix_prefix': 'ResearchID',
                                 'prefix_reference': 'https://publons.com/researcher/'},
                  'SEED.REACTION': {'prefix_prefix': 'SEED.REACTION',
                                    'prefix_reference': 'https://modelseed.org/biochem/reactions/'},
                  'SEMMEDDB': {'prefix_prefix': 'SEMMEDDB',
                               'prefix_reference': 'https://skr3.nlm.nih.gov/SemMedDB'},
                  'SIO': {'prefix_prefix': 'SIO',
                          'prefix_reference': 'http://semanticscience.org/resource/SIO_'},
                  'SNOMEDCT': {'prefix_prefix': 'SNOMEDCT',
                               'prefix_reference': 'http://snomed.info/id/'},
                  'SPDI': {'prefix_prefix': 'SPDI',
                           'prefix_reference': 'https://api.ncbi.nlm.nih.gov/variation/v0/spdi/'},
                  'STY': {'prefix_prefix': 'STY',
                          'prefix_reference': 'http://purl.bioontology.org/ontology/STY/'},
                  'ScopusID': {'prefix_prefix': 'ScopusID',
                               'prefix_reference': 'https://www.scopus.com/authid/detail.uri?authorId='},
                  'UBERGRAPH': {'prefix_prefix': 'UBERGRAPH',
                                'prefix_reference': 'http://translator.renci.org/ubergraph-axioms.ofn#'},
                  'UBERON_CORE': {'prefix_prefix': 'UBERON_CORE',
                                  'prefix_reference': 'http://purl.obolibrary.org/obo/uberon/core#'},
                  'UBERON_NONAMESPACE': {'prefix_prefix': 'UBERON_NONAMESPACE',
                                         'prefix_reference': 'http://purl.obolibrary.org/obo/core#'},
                  'UMLSSG': {'prefix_prefix': 'UMLSSG',
                             'prefix_reference': 'https://lhncbc.nlm.nih.gov/semanticnetwork/download/sg_archive/SemGroups-v04.txt'},
                  'UNIPROT.ISOFORM': {'prefix_prefix': 'UNIPROT.ISOFORM',
                                      'prefix_reference': 'http://purl.uniprot.org/isoforms/'},
                  'UO-PROPERTY': {'prefix_prefix': 'UO-PROPERTY',
                                  'prefix_reference': 'http://purl.obolibrary.org/obo/uo#'},
                  'UniProtKB': {'prefix_prefix': 'UniProtKB',
                                'prefix_reference': 'http://purl.uniprot.org/uniprot/'},
                  'VANDF': {'prefix_prefix': 'VANDF',
                            'prefix_reference': 'https://www.nlm.nih.gov/research/umls/sourcereleasedocs/current/VANDF/'},
                  'VMC': {'prefix_prefix': 'VMC',
                          'prefix_reference': 'https://github.com/ga4gh/vr-spec/'},
                  'WBVocab': {'prefix_prefix': 'WBVocab',
                              'prefix_reference': 'http://bio2rdf.org/wormbase_vocabulary'},
                  'WBbt': {'prefix_prefix': 'WBbt',
                           'prefix_reference': 'http://purl.obolibrary.org/obo/WBbt_'},
                  'WBls': {'prefix_prefix': 'WBls',
                           'prefix_reference': 'http://purl.obolibrary.org/obo/WBls_'},
                  'WIKIDATA': {'prefix_prefix': 'WIKIDATA',
                               'prefix_reference': 'https://www.wikidata.org/entity/'},
                  'WIKIDATA_PROPERTY': {'prefix_prefix': 'WIKIDATA_PROPERTY',
                                        'prefix_reference': 'https://www.wikidata.org/prop/'},
                  'XPO': {'prefix_prefix': 'XPO',
                          'prefix_reference': 'http://purl.obolibrary.org/obo/XPO_'},
                  'Xenbase': {'prefix_prefix': 'Xenbase',
                              'prefix_reference': 'http://www.xenbase.org/gene/showgene.do?method=display&geneId='},
                  'apollo': {'prefix_prefix': 'apollo',
                             'prefix_reference': 'https://github.com/GMOD/Apollo'},
                  'biolink': {'prefix_prefix': 'biolink',
                              'prefix_reference': 'https://w3id.org/biolink/vocab/'},
                  'bioschemas': {'prefix_prefix': 'bioschemas',
                                 'prefix_reference': 'https://bioschemas.org/'},
                  'dcat': {'prefix_prefix': 'dcat',
                           'prefix_reference': 'http://www.w3.org/ns/dcat#'},
                  'dcid': {'prefix_prefix': 'dcid',
                           'prefix_reference': 'https://datacommons.org/browser/'},
                  'dct': {'prefix_prefix': 'dct',
                          'prefix_reference': 'http://purl.org/dc/terms/'},
                  'doi': {'prefix_prefix': 'doi',
                          'prefix_reference': 'https://doi.org/'},
                  'fabio': {'prefix_prefix': 'fabio',
                            'prefix_reference': 'http://purl.org/spar/fabio/'},
                  'foaf': {'prefix_prefix': 'foaf',
                           'prefix_reference': 'http://xmlns.com/foaf/0.1/'},
                  'foodb.compound': {'prefix_prefix': 'foodb.compound',
                                     'prefix_reference': 'http://foodb.ca/compounds/'},
                  'foodb.food': {'prefix_prefix': 'foodb.food',
                                 'prefix_reference': 'http://foodb.ca/foods/'},
                  'gff3': {'prefix_prefix': 'gff3',
                           'prefix_reference': 'https://github.com/The-Sequence-Ontology/Specifications/blob/master/gff3.md#'},
                  'gpi': {'prefix_prefix': 'gpi',
                          'prefix_reference': 'https://github.com/geneontology/go-annotation/blob/master/specs/gpad-gpi-2-0.md#'},
                  'gtpo': {'prefix_prefix': 'gtpo',
                           'prefix_reference': 'https://rdf.guidetopharmacology.org/ns/gtpo#'},
                  'interpro': {'prefix_prefix': 'interpro',
                               'prefix_reference': 'https://www.ebi.ac.uk/interpro/entry/'},
                  'isbn': {'prefix_prefix': 'isbn',
                           'prefix_reference': 'https://www.isbn-international.org/identifier/'},
                  'isni': {'prefix_prefix': 'isni',
                           'prefix_reference': 'https://isni.org/isni/'},
                  'issn': {'prefix_prefix': 'issn',
                           'prefix_reference': 'https://portal.issn.org/resource/ISSN/'},
                  'linkml': {'prefix_prefix': 'linkml',
                             'prefix_reference': 'https://w3id.org/linkml/'},
                  'medgen': {'prefix_prefix': 'medgen',
                             'prefix_reference': 'https://www.ncbi.nlm.nih.gov/medgen/'},
                  'metacyc.reaction': {'prefix_prefix': 'metacyc.reaction',
                                       'prefix_reference': 'http://identifiers.org/metacyc.reaction:'},
                  'mirbase': {'prefix_prefix': 'mirbase',
                              'prefix_reference': 'http://identifiers.org/mirbase'},
                  'mmmp.biomaps': {'prefix_prefix': 'mmmp.biomaps',
                                   'prefix_reference': 'https://bioregistry.io/mmmp.biomaps:'},
                  'ncats.bioplanet': {'prefix_prefix': 'ncats.bioplanet',
                                      'prefix_reference': 'https://tripod.nih.gov/bioplanet/detail.jsp?pid='},
                  'ncats.drug': {'prefix_prefix': 'ncats.drug',
                                 'prefix_reference': 'https://drugs.ncats.io/drug/'},
                  'orphanet': {'prefix_prefix': 'orphanet',
                               'prefix_reference': 'http://www.orpha.net/ORDO/Orphanet_'},
                  'os': {'prefix_prefix': 'os',
                         'prefix_reference': 'https://github.com/cmungall/owlstar/blob/master/owlstar.ttl'},
                  'pav': {'prefix_prefix': 'pav',
                          'prefix_reference': 'http://purl.org/pav/'},
                  'prov': {'prefix_prefix': 'prov',
                           'prefix_reference': 'http://www.w3.org/ns/prov#'},
                  'qud': {'prefix_prefix': 'qud',
                          'prefix_reference': 'http://qudt.org/1.1/schema/qudt#'},
                  'schema': {'prefix_prefix': 'schema',
                             'prefix_reference': 'http://schema.org/'},
                  'wgs': {'prefix_prefix': 'wgs',
                          'prefix_reference': 'http://www.w3.org/2003/01/geo/wgs84_pos'}},
     'source_file': 'src/biolink_model/schema/biolink_model.yaml',
     'subsets': {'model_organism_database': {'description': 'Subset that is '
                                                            'relevant for a '
                                                            'typical Model '
                                                            'Organism Database '
                                                            '(MOD)',
                                             'from_schema': 'https://w3id.org/biolink/biolink-model',
                                             'name': 'model_organism_database'},
                 'samples': {'description': 'Sample/biosample datamodel',
                             'from_schema': 'https://w3id.org/biolink/biolink-model',
                             'name': 'samples'},
                 'testing': {'description': 'TBD',
                             'from_schema': 'https://w3id.org/biolink/biolink-model',
                             'name': 'testing'},
                 'translator_minimal': {'description': 'Minimum subset of '
                                                       'translator work',
                                        'from_schema': 'https://w3id.org/biolink/biolink-model',
                                        'name': 'translator_minimal'}},
     'types': {'biological sequence': {'from_schema': 'https://w3id.org/biolink/biolink-model',
                                       'name': 'biological sequence',
                                       'typeof': 'string',
                                       'uri': 'xsd:string'},
               'chemical formula value': {'base': 'str',
                                          'description': 'A chemical formula',
                                          'from_schema': 'https://w3id.org/biolink/biolink-model',
                                          'name': 'chemical formula value',
                                          'notes': ['Should be implemented as a '
                                                    'stronger type'],
                                          'uri': 'xsd:string'},
               'frequency value': {'from_schema': 'https://w3id.org/biolink/biolink-model',
                                   'name': 'frequency value',
                                   'typeof': 'string',
                                   'uri': 'UO:0000105'},
               'iri type': {'description': 'An IRI',
                            'from_schema': 'https://w3id.org/biolink/biolink-model',
                            'name': 'iri type',
                            'typeof': 'uriorcurie',
                            'uri': 'xsd:string'},
               'label type': {'description': 'A string that provides a '
                                             'human-readable name for an entity',
                              'from_schema': 'https://w3id.org/biolink/biolink-model',
                              'name': 'label type',
                              'typeof': 'string',
                              'uri': 'xsd:string'},
               'narrative text': {'description': 'A string that provides a '
                                                 'human-readable description of '
                                                 'something',
                                  'from_schema': 'https://w3id.org/biolink/biolink-model',
                                  'name': 'narrative text',
                                  'typeof': 'string',
                                  'uri': 'xsd:string'},
               'percentage frequency value': {'from_schema': 'https://w3id.org/biolink/biolink-model',
                                              'name': 'percentage frequency value',
                                              'typeof': 'double',
                                              'uri': 'UO:0000187'},
               'predicate type': {'description': 'A CURIE from the biolink '
                                                 'related_to hierarchy. For '
                                                 'example, biolink:related_to, '
                                                 'biolink:causes, biolink:treats.',
                                  'from_schema': 'https://w3id.org/biolink/biolink-model',
                                  'name': 'predicate type',
                                  'typeof': 'uriorcurie',
                                  'uri': 'xsd:string'},
               'quotient': {'aliases': ['ratio'],
                            'from_schema': 'https://w3id.org/biolink/biolink-model',
                            'name': 'quotient',
                            'typeof': 'double',
                            'uri': 'UO:0010006'},
               'symbol type': {'from_schema': 'https://w3id.org/biolink/biolink-model',
                               'name': 'symbol type',
                               'typeof': 'string',
                               'uri': 'xsd:string'},
               'time type': {'from_schema': 'https://w3id.org/biolink/biolink-model',
                             'name': 'time type',
                             'typeof': 'time',
                             'uri': 'xsd:time'},
               'unit': {'exact_mappings': ['qud:Unit'],
                        'from_schema': 'https://w3id.org/biolink/biolink-model',
                        'id_prefixes': ['UO'],
                        'name': 'unit',
                        'typeof': 'string',
                        'uri': 'UO:0000000'}}} )

class ApprovalStatusEnum(str, Enum):
    # Discovery & Development Phase. Discovery involves researchers finding new possibilities for medication through testing molecular compounds, noting unexpected effects from existing treatments, or the creation of new technology that allows novel ways of targeting medical products to sites in the body. Drug development occurs after researchers identify potential compounds for experiments.
    discovery_and_development_phase = "discovery_and_development_phase"
    # Preclinical Research Phase.  Once researchers have examined the possibilities a new drug may contain, they must do preliminary research to determine its potential for harm (toxicity). This is categorized as preclinical research and can be one of two types: in vitro or in vivo.
    preclinical_research_phase = "preclinical_research_phase"
    # Clinical Research Phase. Clinical research involves trials of the drug on people, and it is one of the most involved stages in the drug development and approval process. Clinical trials must answer specific questions and follow a protocol determined by the drug researcher or manufacturer.
    fda_clinical_research_phase = "fda_clinical_research_phase"
    # FDA Review
    fda_review_phase_4 = "fda_review_phase_4"
    # FDA Post-Market Safety Monitoring.  The last phase of drug approval is an ongoing one while the drug is on the marketplace. If a developer wants to change anything about the drug formulation or approve it for a new use, they must apply with the FDA. The FDA also frequently reviews the drug’s advertising and its manufacturing facility to make sure everything involved in its creation and marketing is in compliance with regulations.
    fda_post_market_safety_review = "fda_post_market_safety_review"
    # In the FDA Clinical Research Phase, the Clinical Research Phase 1 involves 20 – 100 study participants and lasts several months. This phase is used to determine the safety and dosage of the drug, and about 70% of these drugs move on to the next clinical research phase.
    fda_clinical_research_phase_1 = "fda_clinical_research_phase_1"
    # In the FDA Clinical Research Phase, the Clinical Research Phase 2 involves up to several hundred people, who must have the disease or condition the drug supposes to treat. This phase can last from a few months to two years, and its purpose is to monitor the efficacy of the drug, as well as note side effects that may occur.
    fda_clinical_research_phase_2 = "fda_clinical_research_phase_2"
    # In the FDA Clinical Research Phase, the Clinical Research Phase 3 involves 300 – 3000 volunteers and can last up to four years. It is used to continue monitoring the efficacy of the drug, as well as exploring any longer-term adverse reactions.
    fda_clinical_research_phase_3 = "fda_clinical_research_phase_3"
    # In the FDA Clinical Research Phase, the Clinical Research Phase 4 involves several thousands of volunteers who have the disease or condition and continues to monitor safety and efficacy. If a drug passes this phase, it goes on to FDA review.
    fda_clinical_research_phase_4 = "fda_clinical_research_phase_4"
    # Fast track is a process designed to facilitate the development, and expedite the review of drugs to treat serious conditions and fill an unmet medical need. The purpose is to get important new drugs to the patient earlier. Fast Track addresses a broad range of serious conditions. For more information https://www.fda.gov/patients/fast-track-breakthrough-therapy-accelerated-approval-priority-review/fast-track
    fda_fast_track = "fda_fast_track"
    # Breakthrough Therapy designation is a process designed to expedite the development and review of drugs that are intended to treat a serious condition and preliminary clinical evidence indicates that the drug may demonstrate substantial improvement over available therapy on a clinically significant endpoint(s). For more information https://www.fda.gov/patients/fast-track-breakthrough-therapy-accelerated-approval-priority-review/breakthrough-therapy
    fda_breakthrough_therapy = "fda_breakthrough_therapy"
    # When studying a new drug, it can sometimes take many years to learn whether a drug actually provides a real effect on how a patient survives, feels, or functions. A positive therapeutic effect that is clinically meaningful in the context of a given disease is known as “clinical benefit”. Mindful of the fact that it may take an extended period of time to measure a drug’s intended clinical benefit, in 1992 FDA instituted the Accelerated Approval regulations. These regulations allowed drugs for serious conditions that filled an unmet medical need to be approved based on a surrogate endpoint. Using a surrogate endpoint enabled the FDA to approve these drugs faster. For more information https://www.fda.gov/patients/fast-track-breakthrough-therapy-accelerated-approval-priority-review/accelerated-approval
    fda_accelerated_approval = "fda_accelerated_approval"
    # Prior to approval, each drug marketed in the United States must go through a detailed FDA review process. In 1992, under the Prescription Drug User Act (PDUFA), FDA agreed to specific goals for improving the drug review time and created a two-tiered system of review times – Standard Review and Priority Review. A Priority Review designation means FDA’s goal is to take action on an application within 6 months (compared to 10 months under standard review). For more information https://www.fda.gov/patients/fast-track-breakthrough-therapy-accelerated-approval-priority-review/priority-review
    fda_priority_review = "fda_priority_review"
    # Regular FDA Approval.  The last phase of drug approval is an ongoing one while the drug is on the marketplace. If a developer wants to change anything about the drug formulation or approve it for a new use, they must apply with the FDA. The FDA also frequently reviews the drug’s advertising and its manufacturing facility to make sure everything involved in its creation and marketing is in compliance with regulations.
    regular_fda_approval = "regular_fda_approval"
    post_approval_withdrawal = "post_approval_withdrawal"


class ClinicalApprovalStatusEnum(str, Enum):
    approved_for_condition = "approved_for_condition"
    fda_approved_for_condition = "fda_approved_for_condition"
    not_approved_for_condition = "not_approved_for_condition"
    post_approval_withdrawal = "post_approval_withdrawal"
    off_label_use = "off_label_use"
    not_provided = "not_provided"


class MaxResearchPhaseEnum(str, Enum):
    # Biolink 'pre_clinical_research' is the union of both the `FDA discovery and development phase` and `FDA preclinical research phase`. Discovery involves researchers finding new possibilities for medication through testing molecular compounds, noting unexpected effects from existing treatments, or the creation of new technology that allows novel ways of targeting medical products to sites in the body. Drug development occurs after researchers identify potential compounds for experiments Preclinical Research Phase. Once researchers have examined the possibilities a new drug may contain, they must do preliminary research to determine its potential for harm (toxicity). This is categorized as preclinical research and can be one of two types: in vitro or in vivo.
    pre_clinical_research_phase = "pre_clinical_research_phase"
    # Clinical research involves trials of the drug on people, and it is one of the most involved stages in the drug development and approval process. Clinical trials must answer specific questions and follow a protocol determined by the drug researcher or manufacturer.
    clinical_trial_phase = "clinical_trial_phase"
    # In the FDA Clinical Trial Phase, the Clinical Trial Phase 1 involves 20 – 100 study participants and lasts several months. This phase is used to determine the safety and dosage of the drug, and about 70% of these drugs move on to the next clinical research phase.
    clinical_trial_phase_1 = "clinical_trial_phase_1"
    # In the FDA Clinical Trial Phase, the Clinical Trial Phase 2 involves up to several hundred people, who must have the disease or condition the drug supposes to treat. This phase can last from a few months to two years, and its purpose is to monitor the efficacy of the drug, as well as note side effects that may occur.
    clinical_trial_phase_2 = "clinical_trial_phase_2"
    # In the FDA Clinical Trial Phase, the Clinical Trial Phase 3 involves 300 – 3000 volunteers and can last up to four years. It is used to continue monitoring the efficacy of the drug, as well as exploring any longer-term adverse reactions.
    clinical_trial_phase_3 = "clinical_trial_phase_3"
    # In the FDA Clinical Trial Phase, the Clinical Trial Phase 4 involves several thousands of volunteers who have the disease or condition and continues to monitor safety and efficacy. If a drug passes this phase, it goes on to FDA review.
    clinical_trial_phase_4 = "clinical_trial_phase_4"
    not_provided = "not_provided"


class DirectionQualifierEnum(str, Enum):
    increased = "increased"
    upregulated = "upregulated"
    decreased = "decreased"
    downregulated = "downregulated"


class ChemicalEntityDerivativeEnum(str, Enum):
    metabolite = "metabolite"


class ChemicalOrGeneOrGeneProductFormOrVariantEnum(str, Enum):
    genetic_variant_form = "genetic_variant_form"
    modified_form = "modified_form"
    loss_of_function_variant_form = "loss_of_function_variant_form"
    gain_of_function_variant_form = "gain_of_function_variant_form"
    polymorphic_form = "polymorphic_form"
    snp_form = "snp_form"
    analog_form = "analog_form"


class GeneOrGeneProductOrChemicalPartQualifierEnum(str, Enum):
    number_3_prime_utr = "3_prime_utr"
    number_5_prime_utr = "5_prime_utr"
    polya_tail = "polya_tail"
    promoter = "promoter"
    enhancer = "enhancer"
    exon = "exon"
    intron = "intron"


class GeneOrGeneProductOrChemicalEntityAspectEnum(str, Enum):
    # Used in cases where the specificity of the relationship can not be determined to be either activity or abundance.  In general, a more specific value from this enumeration should be used.
    activity_or_abundance = "activity_or_abundance"
    abundance = "abundance"
    activity = "activity"
    expression = "expression"
    synthesis = "synthesis"
    degradation = "degradation"
    cleavage = "cleavage"
    hydrolysis = "hydrolysis"
    metabolic_processing = "metabolic_processing"
    mutation_rate = "mutation_rate"
    stability = "stability"
    folding = "folding"
    localization = "localization"
    transport = "transport"
    absorption = "absorption"
    aggregation = "aggregation"
    interaction = "interaction"
    release = "release"
    secretion = "secretion"
    uptake = "uptake"
    splicing = "splicing"
    molecular_interaction = "molecular_interaction"
    molecular_modification = "molecular_modification"
    acetylation = "acetylation"
    acylation = "acylation"
    alkylation = "alkylation"
    amination = "amination"
    carbamoylation = "carbamoylation"
    ethylation = "ethylation"
    glutathionylation = "glutathionylation"
    glycation = "glycation"
    glycosylation = "glycosylation"
    glucuronidation = "glucuronidation"
    n_linked_glycosylation = "n_linked_glycosylation"
    o_linked_glycosylation = "o_linked_glycosylation"
    hydroxylation = "hydroxylation"
    lipidation = "lipidation"
    farnesylation = "farnesylation"
    geranoylation = "geranoylation"
    myristoylation = "myristoylation"
    palmitoylation = "palmitoylation"
    prenylation = "prenylation"
    methylation = "methylation"
    nitrosation = "nitrosation"
    nucleotidylation = "nucleotidylation"
    phosphorylation = "phosphorylation"
    ribosylation = "ribosylation"
    ADP_ribosylation = "ADP-ribosylation"
    sulfation = "sulfation"
    sumoylation = "sumoylation"
    ubiquitination = "ubiquitination"
    oxidation = "oxidation"
    reduction = "reduction"
    carboxylation = "carboxylation"


class CausalMechanismQualifierEnum(str, Enum):
    # A causal mechanism mediated by the direct contact between effector and target chemical or biomolecular entity, which form a stable physical interaction.
    binding = "binding"
    # A causal mechanism in which the effector binds to the target and negatively effects its normal function, e.g. prevention of enzymatic reaction or activation of downstream pathway.
    inhibition = "inhibition"
    # A causal mechanism in which an antibody specifically binds to and interferes with the target.
    antibody_inhibition = "antibody_inhibition"
    # A causal mechanism in which the effector binds to a receptor and prevents activation by an agonist through competing for the binding site.
    antagonism = "antagonism"
    # A causal mechanism in which the effector binds to a molecular channel and prevents or reduces transport of ions through it.
    molecular_channel_blockage = "molecular_channel_blockage"
    # A causal mechanism in which the effector binds to the same receptor-binding site as an agonist and antagonizes its effects, often exerting the opposite effect of the agonist by suppressing spontaneous receptor signaling.
    inverse_agonism = "inverse_agonism"
    # A causal mechanism in which the effector reduces or prevents the action of the endogenous ligand of a receptor by binding to a site distinct from that ligand (i.e. non-competitive inhibition)
    negative_allosteric_modulation = "negative_allosteric_modulation"
    # A causal mechanism in which the effector binds and activates a receptor to mimic the effect of an endogenous ligand.
    agonism = "agonism"
    # A causal mechanism in which the effector binds to a molecular channel and facilitates transport of ions through it.
    molecular_channel_opening = "molecular_channel_opening"
    # A causal mechanism in which the effector enhances the action of the endogenous ligand of a receptor by binding to a site distinct from that ligand (i.e. non-competitive inhibition)
    positive_allosteric_modulation = "positive_allosteric_modulation"
    # A causal mechanism in which the effector  binds to and enhances or intensifies the effect of some other chemical or drug on its target.
    potentiation = "potentiation"
    # A causal mechanism in which the effector binds to and positively affects the normal functioning of its target.
    activation = "activation"
    # A causal mechanism in which the effector binds to and increases the activity/rate of an enzyme that processes drugs in the body.
    inducer = "inducer"
    # A causal mechanism mediated by through the control of target gene transcription
    transcriptional_regulation = "transcriptional_regulation"
    # A causal mechanism mediated by the activation or control of signaling events that influence the some aspect of the target entity (e.g. its activity, processing, transport, etc)
    signaling_mediated_control = "signaling_mediated_control"
    stabilization = "stabilization"
    stimulation = "stimulation"
    releasing_activity = "releasing_activity"


class LogicalInterpretationEnum(str, Enum):
    # A modifier on a triple that causes the triple to be interpreted as a some-some statement
    some_some = "some_some"
    # A modifier on a triple that causes the triple to be interpreted as an all-some statement.
    all_some = "all_some"
    inverse_all_some = "inverse_all_some"


class ReactionDirectionEnum(str, Enum):
    left_to_right = "left_to_right"
    right_to_left = "right_to_left"
    bidirectional = "bidirectional"
    neutral = "neutral"


class ReactionSideEnum(str, Enum):
    left = "left"
    right = "right"


class PhaseEnum(str, Enum):
    """
    phase
    """
    number_0 = "0"
    number_1 = "1"
    number_2 = "2"


class StrandEnum(str, Enum):
    """
    strand
    """
    # Positive
    PLUS_SIGN = "+"
    # Negative
    _ = "-"
    # Unstranded
    FULL_STOP = "."
    # Unknown
    QUESTION_MARK = "?"


class SequenceEnum(str, Enum):
    """
    type of sequence
    """
    # nucleic acid
    na = "na"
    # amino acid
    aa = "aa"


class DruggableGeneCategoryEnum(str, Enum):
    # These targets have activities in DrugCentral (ie. approved drugs) with known mechanism of action.
    tclin = "tclin"
    # These targets have activities in ChEMBL, Guide to Pharmacology or DrugCentral that satisfy the activity thresholds detailed below.
    tbio = "tbio"
    # These targets do not have known drug or small molecule activities that satisfy the activity thresholds detailed below AND satisfy one or more of the following criteria: target is above the cutoff criteria for Tdark target is annotated with a Gene Ontology Molecular Function or Biological Process leaf term(s) with an Experimental Evidence code
    tchem = "tchem"
    # These are targets about which virtually nothing is known. They do not have known drug or small molecule activities that satisfy the activity thresholds detailed below AND satisfy two or more of the following criteria: A PubMed text-mining score from Jensen Lab less than 5, greater than or equal TO 3 Gene RIFs, or less than or equal to 50 Antibodies available according to http://antibodypedia.com.
    tdark = "tdark"


class DrugAvailabilityEnum(str, Enum):
    # chemical entity is available over the counter without a prescription.
    over_the_counter = "over_the_counter"
    # chemical entity is available by prescription.
    prescription = "prescription"


class DrugDeliveryEnum(str, Enum):
    inhalation = "inhalation"
    oral = "oral"
    absorption_through_the_skin = "absorption_through_the_skin"
    intravenous_injection = "intravenous_injection"


class ResourceRoleEnum(str, Enum):
    """
    The role played by the information reource in serving as a source for an edge in a TRAPI message. Note that a given Edge should have one and only one 'primary' source, and may have any number of 'aggregator' or 'supporting data' sources.  This enumeration is found in Biolink Model, but is repeated here for convenience.
    """
    primary_knowledge_source = "primary_knowledge_source"
    aggregator_knowledge_source = "aggregator_knowledge_source"
    supporting_data_source = "supporting_data_source"


class FDAIDAAdverseEventEnum(str, Enum):
    """
    please consult with the FDA guidelines as proposed in this document: https://www.accessdata.fda.gov/scripts/cdrh/cfdocs/cfcfr/cfrsearch.cfm?fr=312.32
    """
    # An adverse event or suspected adverse reaction is considered 'life-threatening' if, in the view of either the investigator or sponsor, its occurrence places the patient or subject at immediate risk of death. It does not include an adverse event or suspected adverse reaction that, had it occurred in a more severe form, might have caused death.
    life_threatening_adverse_event = "life_threatening_adverse_event"
    # An adverse event or suspected adverse reaction is considered 'serious' if, in the view of either the investigator or sponsor, it results in any of the following outcomes: Death, a life-threatening adverse event, inpatient hospitalization or prolongation of existing hospitalization, a persistent or significant incapacity or substantial disruption of the ability to conduct normal life functions, or a congenital anomaly/birth defect. Important medical events that may not result in death, be life-threatening, or require hospitalization may be considered serious when, based upon appropriate medical judgment, they may jeopardize the patient or subject and may require medical or surgical intervention to prevent one of the outcomes listed in this definition. Examples of such medical events include allergic bronchospasm requiring intensive treatment in an emergency room or at home, blood dyscrasias or convulsions that do not result in inpatient hospitalization, or the development of drug dependency or drug abuse.
    serious_adverse_event = "serious_adverse_event"
    # means any adverse event for which there is a reasonable possibility that the drug caused the adverse event. For the purposes of IND safety reporting, 'reasonable possibility' means there is evidence to suggest a causal relationship between the drug and the adverse event. Suspected adverse reaction implies a lesser degree of certainty about causality than adverse reaction, which means any adverse event caused by a drug.
    suspected_adverse_reaction = "suspected_adverse_reaction"
    # An adverse event or suspected adverse reaction is considered 'unexpected' if it is not listed in the investigator brochure or is not listed at the specificity or severity that has been observed; or, if an investigator brochure is not required or available, is not consistent with the risk information described in the general investigational plan or elsewhere in the current application, as amended. For example, under this definition, hepatic necrosis would be unexpected (by virtue of greater severity) if the investigator brochure referred only to elevated hepatic enzymes or hepatitis. Similarly, cerebral thromboembolism and cerebral vasculitis would be unexpected (by virtue of greater specificity) if the investigator brochure listed only cerebral vascular accidents. 'Unexpected', as used in this definition, also refers to adverse events or suspected adverse reactions that are mentioned in the investigator brochure as occurring with a class of drugs or as anticipated from the pharmacological properties of the drug, but are not specifically mentioned as occurring with the particular drug under investigation.
    unexpected_adverse_event = "unexpected_adverse_event"


class AgentTypeEnum(str, Enum):
    # A human agent who is responsible for generating a statement of knowledge. The human may utilize computationally generated information as evidence for the resulting knowledge,  but the human is the one who ultimately interprets/reasons with  this evidence to produce a statement of knowledge.
    manual_agent = "manual_agent"
    # An automated agent, typically a software program or tool, that is  responsible for generating a statement of knowledge. Human contribution  to the knowledge creation process ends with the definition and coding of algorithms or analysis pipelines that get executed by the automated agent.
    automated_agent = "automated_agent"
    # An automated agent that executes an analysis workflow over data and  reports the direct results of the analysis. These typically report  statistical associations/correlations between variables in the input dataset, and do not interpret/infer broader conclusions from associations the analysis reveals in the data.
    data_analysis_pipeline = "data_analysis_pipeline"
    # An automated agent that generates knowledge statements (typically predictions) based on rules/logic explicitly encoded in an algorithm (e.g. heuristic models, supervised classifiers), or learned from patterns  observed in data (e.g. ML models, unsupervised classifiers).
    computational_model = "computational_model"
    # An automated agent that uses Natural Language Processing to recognize concepts and/or relationships in text, and report them using formally encoded semantics (e.g. as an edge in a knowledge graph).
    text_mining_agent = "text_mining_agent"
    # An automated agent that processes images to generate textual statements of  knowledge derived from the image and/or expressed in text the image  depicts (e.g. via OCR).
    image_processing_agent = "image_processing_agent"
    # A human agent reviews and validates/approves the veracity of knowledge  that is initially generated by an automated agent.
    manual_validation_of_automated_agent = "manual_validation_of_automated_agent"
    # The agent type is not provided, typically because it cannot be determined from available information if the agent that generated the knowledge is  manual or automated.
    not_provided = "not_provided"


class KnowledgeLevelEnum(str, Enum):
    # A statement of purported fact that is put forth by an agent as true, based on assessment of direct evidence. Assertions are likely but not  definitively true.
    knowledge_assertion = "knowledge_assertion"
    # A statement reporting a conclusion that follows logically from premises representing established facts or knowledge assertions (e.g. fingernail part of finger, finger part of hand --> fingernail part of hand).
    logical_entailment = "logical_entailment"
    # A statement of a possible fact based on probabilistic forms of reasoning over more indirect forms of evidence, that lead to more speculative conclusions.
    prediction = "prediction"
    # A statement that reports concepts representing variables in a dataset to be statistically associated with each other in a particular cohort (e.g. 'Metformin Treatment (variable 1) is correlated with Diabetes Diagnosis (variable 2) in EHR dataset X').
    statistical_association = "statistical_association"
    # A statement reporting (and possibly quantifying) a phenomenon that was observed to occur -  absent any analysis or interpretation that generates a statistical association or supports a broader conclusion or inference.
    observation = "observation"
    # The knowledge level is not provided, typically because it cannot be determined from available. information.
    not_provided = "not_provided"



class MappingCollection(ConfiguredBaseModel):
    """
    A collection of deprecated mappings.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'tree_root': True})

    predicate_mappings: Optional[List[PredicateMapping]] = Field(None, description="""A collection of relationships that are not used in biolink, but have biolink patterns that can be used to replace them.  This is a temporary slot to help with the transition to the fully qualified predicate model in Biolink3.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate_mappings', 'domain_of': ['mapping collection']} })


class PredicateMapping(ConfiguredBaseModel):
    """
    A deprecated predicate mapping object contains the deprecated predicate and an example of the rewiring that should be done to use a qualified statement in its place.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    mapped_predicate: Optional[str] = Field(None, description="""The predicate that is being replaced by the fully qualified representation of predicate + subject and object qualifiers.  Only to be used in test data and mapping data to help with the transition to the fully qualified predicate model. Not to be used in knowledge graphs.""", json_schema_extra = { "linkml_meta": {'alias': 'mapped_predicate', 'domain_of': ['predicate mapping']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    subject_form_or_variant_qualifier: Optional[str] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'gene has variant that contributes to disease association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    subject_part_qualifier: Optional[str] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  subject of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    subject_derivative_qualifier: Optional[str] = Field(None, description="""A qualifier that composes with a core subject/object  concept to describe something that is derived from the core concept.  For example, the qualifier ‘metabolite’ combines with a ‘Chemical X’ core concept to express the composed concept ‘a metabolite of Chemical X’.  This qualifier is for the subject of an association  (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_derivative_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'metabolite'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'derivative qualifier'} })
    subject_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'subject_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_form_or_variant_qualifier: Optional[str] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    object_part_qualifier: Optional[str] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  object of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    object_derivative_qualifier: Optional[str] = Field(None, description="""A qualifier that composes with a core subject/object  concept to describe something that is derived from the core concept.  For example, the qualifier ‘metabolite’ combines with a ‘Chemical X’ core concept to express the composed concept ‘a metabolite of Chemical X’.  This qualifier is for the object of an association  (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_derivative_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping', 'gene affects chemical association'],
         'examples': [{'value': 'metabolite'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'derivative qualifier'} })
    object_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'object_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    causal_mechanism_qualifier: Optional[CausalMechanismQualifierEnum] = Field(None, description="""A statement qualifier representing a type of molecular control mechanism through which an effect of a chemical on a gene or gene product is mediated (e.g. 'agonism', 'inhibition', 'allosteric modulation', 'channel blocker')""", json_schema_extra = { "linkml_meta": {'alias': 'causal_mechanism_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    anatomical_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing an anatomical location where an relationship expressed in an association took place (can be a tissue, cell type, or sub-cellular location).""", json_schema_extra = { "linkml_meta": {'alias': 'anatomical_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'blood'}, {'value': 'cerebral cortext'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Anatomical context values can be any term from UBERON. For '
                   'example, the context qualifier ‘cerebral cortext’ combines with a '
                   'core concept of ‘neuron’ to express the composed concept ‘neuron '
                   'in the cerebral cortext’. The species_context_qualifier applies '
                   'taxonomic context, e.g. species-specific molecular activity.  '
                   'Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    species_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing a taxonomic category of species in which a relationship expressed in an association took place.""", json_schema_extra = { "linkml_meta": {'alias': 'species_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'zebrafish'}, {'value': 'human'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    exact_match: Optional[List[str]] = Field(None, description="""holds between two entities that have strictly equivalent meanings, with a high degree of confidence""", json_schema_extra = { "linkml_meta": {'alias': 'exact_match',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'named thing',
         'domain_of': ['predicate mapping'],
         'exact_mappings': ['skos:exactMatch', 'WIKIDATA:Q39893449', 'WIKIDATA:P2888'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'close match',
         'symmetric': True} })
    narrow_match: Optional[List[str]] = Field(None, description="""a list of terms from different schemas or terminology systems that have a narrower, more specific meaning. Narrower terms are typically shown as children in a hierarchy or tree.""", json_schema_extra = { "linkml_meta": {'alias': 'narrow_match',
         'annotations': {'opposite_of': {'tag': 'opposite_of', 'value': 'broad match'}},
         'domain': 'named thing',
         'domain_of': ['predicate mapping'],
         'exact_mappings': ['skos:narrowMatch', 'WIKIDATA:Q39893967'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'broad match',
         'is_a': 'related to at concept level'} })
    broad_match: Optional[List[str]] = Field(None, description="""a list of terms from different schemas or terminology systems that have a broader, more general meaning. Broader terms are typically shown as parents in a hierarchy or tree.""", json_schema_extra = { "linkml_meta": {'alias': 'broad_match',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of',
                                         'value': 'narrow match'}},
         'domain': 'named thing',
         'domain_of': ['predicate mapping'],
         'exact_mappings': ['skos:broadMatch', 'WIKIDATA:Q39894595'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at concept level'} })


class OntologyClass(ConfiguredBaseModel):
    """
    a concept or class in an ontology, vocabulary or thesaurus. Note that nodes in a biolink compatible KG can be considered both instances of biolink classes, and OWL classes in their own right. In general you should not need to use this class directly. Instead, use the appropriate biolink class. For example, for the GO concept of endocytosis (GO:0006897), use bl:BiologicalProcess as the type.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'comments': ["This is modeled as a mixin. 'ontology class' should not be the "
                      'primary type of a node in the KG. Instead you should use an '
                      'informative bioloink category, such as AnatomicalEntity (for '
                      'Uberon classes), ChemicalSubstance (for CHEBI or CHEMBL), etc',
                      'Note that formally this is a metaclass. Instances of this class '
                      "are instances in the graph, but can be the object of 'type' "
                      'edges. For example, if we had a node in the graph representing '
                      'a specific brain of a specific patient (e.g brain001), this '
                      'could have a category of bl:Sample, and by typed more '
                      'specifically with an ontology class UBERON:nnn, which has as '
                      'category bl:AnatomicalEntity'],
         'exact_mappings': ['owl:Class', 'schema:Class'],
         'examples': [{'description': "the class 'brain' from the Uberon anatomy "
                                      'ontology',
                       'value': 'UBERON:0000955'}],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['MESH', 'UMLS', 'KEGG.BRITE'],
         'mixin': True,
         'see_also': ['https://github.com/biolink/biolink-model/issues/486']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })


class Annotation(ConfiguredBaseModel):
    """
    Biolink Model root class for entity annotations.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True, 'from_schema': 'https://w3id.org/biolink/biolink-model'})

    pass


class QuantityValue(Annotation):
    """
    A value of an attribute that is quantitative and measurable, expressed as a combination of a unit and a numeric value
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    has_unit: Optional[str] = Field(None, description="""connects a quantity value to a unit""", json_schema_extra = { "linkml_meta": {'alias': 'has_unit',
         'close_mappings': ['EFO:0001697', 'UO-PROPERTY:is_unit_of'],
         'domain': 'quantity value',
         'domain_of': ['quantity value'],
         'exact_mappings': ['qud:unit', 'IAO:0000039'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_denominator_unit',
                             'SNOMED:has_concentration_strength_numerator_unit',
                             'SNOMED:has_presentation_strength_denominator_unit',
                             'SNOMED:has_presentation_strength_numerator_unit',
                             'SNOMED:has_unit_of_presentation']} })
    has_numeric_value: Optional[float] = Field(None, description="""connects a quantity value to a number""", json_schema_extra = { "linkml_meta": {'alias': 'has_numeric_value',
         'domain': 'quantity value',
         'domain_of': ['quantity value'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples']} })


class RelationshipQuantifier(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class SensitivityQuantifier(RelationshipQuantifier):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class SpecificityQuantifier(RelationshipQuantifier):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class PathognomonicityQuantifier(SpecificityQuantifier):
    """
    A relationship quantifier between a variant or symptom and a disease, which is high when the presence of the feature implies the existence of the disease
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class FrequencyQuantifier(RelationshipQuantifier):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })


class ChemicalOrDrugOrTreatment(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PUBCHEM.COMPOUND', 'CHEMBL.COMPOUND', 'CHEBI', 'MAXO'],
         'mixin': True})

    pass


class Entity(ConfiguredBaseModel):
    """
    Root Biolink Model class for all things and informational relationships, real or imagined.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True, 'from_schema': 'https://w3id.org/biolink/biolink-model'})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Entity","biolink:Entity"]] = Field(["biolink:Entity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class NamedThing(Entity):
    """
    a databased entity or concept/class
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['BFO:0000001',
                            'WIKIDATA:Q35120',
                            'UMLSSG:OBJC',
                            'STY:T071',
                            'dcid:Thing'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'category': {'name': 'category', 'required': True}}})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/NamedThing","biolink:NamedThing"]] = Field(["biolink:NamedThing"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Attribute(NamedThing, OntologyClass):
    """
    A property or characteristic of an entity. For example, an apple may have properties such as color, shape, age, crispiness. An environmental sample may have attributes such as depth, lat, long, material.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SIO:000614'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['EDAM-DATA', 'EDAM-FORMAT', 'EDAM-OPERATION', 'EDAM-TOPIC'],
         'in_subset': ['samples'],
         'mixins': ['ontology class'],
         'slot_usage': {'name': {'description': "The human-readable 'attribute name' "
                                                'can be set to a string which reflects '
                                                'its context of interpretation, e.g. '
                                                'SEPIO evidence/provenance/confidence '
                                                'annotation or it can default to the '
                                                "name associated with the 'has "
                                                "attribute type' slot ontology term.",
                                 'name': 'name'}}})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Attribute","biolink:Attribute"]] = Field(["biolink:Attribute"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalRole(Attribute):
    """
    A role played by the molecular entity or part thereof within a chemical context.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['CHEBI:51086'],
         'examples': [{'value': 'CHEBI:35469'}],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI']})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalRole","biolink:ChemicalRole"]] = Field(["biolink:ChemicalRole"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class BiologicalSex(Attribute):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['PATO:0000047'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BiologicalSex","biolink:BiologicalSex"]] = Field(["biolink:BiologicalSex"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PhenotypicSex(BiologicalSex):
    """
    An attribute corresponding to the phenotypic sex of the individual, based upon the reproductive organs present.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['PATO:0001894'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhenotypicSex","biolink:PhenotypicSex"]] = Field(["biolink:PhenotypicSex"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenotypicSex(BiologicalSex):
    """
    An attribute corresponding to the genotypic sex of the individual, based upon genotypic composition of sex chromosomes.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['PATO:0020000'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypicSex","biolink:GenotypicSex"]] = Field(["biolink:GenotypicSex"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SeverityValue(Attribute):
    """
    describes the severity of a phenotypic feature or disease
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'deprecated': 'True', 'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SeverityValue","biolink:SeverityValue"]] = Field(["biolink:SeverityValue"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class RelationshipType(OntologyClass):
    """
    An OWL property used as an edge label
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })


class TaxonomicRank(OntologyClass):
    """
    A descriptor for the rank within a taxonomic classification. Example instance: TAXRANK:0000017 (kingdom)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['TAXRANK'],
         'mappings': ['WIKIDATA:Q427626']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })


class OrganismTaxon(NamedThing):
    """
    A classification of a set of organisms. Example instances: NCBITaxon:9606 (Homo sapiens), NCBITaxon:2 (Bacteria). Can also be used to represent strains or subspecies.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['taxon', 'taxonomic classification'],
         'exact_mappings': ['WIKIDATA:Q16521', 'STY:T001', 'bioschemas:Taxon'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['NCBITaxon', 'MESH', 'UMLS'],
         'in_subset': ['model_organism_database'],
         'narrow_mappings': ['dcid:BiologicalSpecies'],
         'slot_usage': {'has taxonomic rank': {'mappings': ['WIKIDATA:P105'],
                                               'multivalued': False,
                                               'name': 'has taxonomic rank',
                                               'range': 'taxonomic rank'}},
         'values_from': ['NCBITaxon']})

    has_taxonomic_rank: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_taxonomic_rank',
         'domain': 'named thing',
         'domain_of': ['organism taxon'],
         'is_a': 'node property',
         'mappings': ['WIKIDATA:P105']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismTaxon","biolink:OrganismTaxon"]] = Field(["biolink:OrganismTaxon"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Event(NamedThing):
    """
    Something that happens at a given place and time.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCIT:C25499', 'STY:T051'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Event","biolink:Event"]] = Field(["biolink:Event"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class AdministrativeEntity(NamedThing):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True, 'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/AdministrativeEntity","biolink:AdministrativeEntity"]] = Field(["biolink:AdministrativeEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Agent(AdministrativeEntity):
    """
    person, group, organization or project that provides a piece of information (i.e. a knowledge association)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['group'],
         'exact_mappings': ['prov:Agent', 'dct:Agent'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['isbn', 'ORCID', 'ScopusID', 'ResearchID', 'GSID', 'isni'],
         'narrow_mappings': ['UMLSSG:ORGA',
                             'STY:T092',
                             'STY:T093',
                             'STY:T094',
                             'STY:T095',
                             'STY:T096'],
         'slot_usage': {'id': {'description': 'Different classes of agents have '
                                              'distinct preferred identifiers. For '
                                              'publishers, use the ISBN publisher '
                                              'code. See '
                                              'https://grp.isbn-international.org/ for '
                                              'publisher code lookups. For editors, '
                                              'authors and  individual providers, use '
                                              "the individual's ORCID if available; "
                                              'Otherwise, a ScopusID, ResearchID or '
                                              "Google Scholar ID ('GSID') may be used "
                                              'if the author ORCID is unknown. '
                                              'Institutional agents could be '
                                              'identified by an International Standard '
                                              "Name Identifier ('ISNI') code.",
                               'name': 'id',
                               'required': True,
                               'values_from': ['isbn',
                                               'ORCID',
                                               'ScopusID',
                                               'ResearchID',
                                               'GSID',
                                               'isni']},
                        'name': {'description': "it is recommended that an author's "
                                                "'name' property be formatted as "
                                                '"surname, firstname initial."',
                                 'name': 'name'}}})

    affiliation: Optional[List[str]] = Field(None, description="""a professional relationship between one provider (often a person) within another provider (often an organization). Target provider identity should be specified by a CURIE. Providers may have multiple affiliations.""", json_schema_extra = { "linkml_meta": {'alias': 'affiliation',
         'domain': 'agent',
         'domain_of': ['agent'],
         'is_a': 'node property'} })
    address: Optional[str] = Field(None, description="""the particulars of the place where someone or an organization is situated.  For now, this slot is a simple text \"blob\" containing all relevant details of the given location for fitness of purpose. For the moment, this \"address\" can include other contact details such as email and phone number(?).""", json_schema_extra = { "linkml_meta": {'alias': 'address',
         'domain': 'named thing',
         'domain_of': ['agent'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different classes of agents have distinct preferred identifiers. For publishers, use the ISBN publisher code. See https://grp.isbn-international.org/ for publisher code lookups. For editors, authors and  individual providers, use the individual's ORCID if available; Otherwise, a ScopusID, ResearchID or Google Scholar ID ('GSID') may be used if the author ORCID is unknown. Institutional agents could be identified by an International Standard Name Identifier ('ISNI') code.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal'],
         'values_from': ['isbn', 'ORCID', 'ScopusID', 'ResearchID', 'GSID', 'isni']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Agent","biolink:Agent"]] = Field(["biolink:Agent"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""it is recommended that an author's 'name' property be formatted as \"surname, firstname initial.\"""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class InformationContentEntity(NamedThing):
    """
    a piece of information that typically describes some topic of discourse or is used as support.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'aliases': ['information', 'information artefact', 'information entity'],
         'exact_mappings': ['IAO:0000030'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['doi'],
         'narrow_mappings': ['UMLSSG:CONC',
                             'STY:T077',
                             'STY:T078',
                             'STY:T079',
                             'STY:T080',
                             'STY:T081',
                             'STY:T082',
                             'STY:T089',
                             'STY:T102',
                             'STY:T169',
                             'STY:T171',
                             'STY:T185']})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/InformationContentEntity","biolink:InformationContentEntity"]] = Field(["biolink:InformationContentEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class StudyResult(InformationContentEntity):
    """
    A collection of data items from a study that are about a particular study subject or experimental unit (the 'focus' of the Result) - optionally with context/provenance metadata that may be relevant to the interpretation of this data as evidence.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'notes': ['The data/metadata included in a Study Result object are typically '
                   'a subset of data from a larger study data set, that are selected '
                   'by a curator because they may be useful as evidence for deriving '
                   'knowledge about a specific focus of the study. The notion of a '
                   "'study' here is defined broadly to include any research activity "
                   'at any scale that is aimed at generating knowledge or hypotheses. '
                   'This may include a single assay or computational analyses, or a '
                   'larger scale clinical trial or experimental research '
                   'investigation.']})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/StudyResult","biolink:StudyResult"]] = Field(["biolink:StudyResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class StudyVariable(InformationContentEntity):
    """
    a variable that is used as a measure in the investigation of a study
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['STATO:0000258', 'SIO:000367'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'narrow_mappings': ['NCIT:C142192']})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/StudyVariable","biolink:StudyVariable"]] = Field(["biolink:StudyVariable"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class CommonDataElement(InformationContentEntity):
    """
    A Common Data Element (CDE) is a standardized, precisely defined question, paired with a set of allowable responses, used systematically across different sites, studies, or clinical trials to ensure consistent data collection. Multiple CDEs (from one or more Collections) can be curated into Forms. (https://cde.nlm.nih.gov/home)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['NCIT:C19984'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CommonDataElement","biolink:CommonDataElement"]] = Field(["biolink:CommonDataElement"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ConceptCountAnalysisResult(StudyResult):
    """
    A result of a concept count analysis.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ConceptCountAnalysisResult","biolink:ConceptCountAnalysisResult"]] = Field(["biolink:ConceptCountAnalysisResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ObservedExpectedFrequencyAnalysisResult(StudyResult):
    """
    A result of a observed expected frequency analysis.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ObservedExpectedFrequencyAnalysisResult","biolink:ObservedExpectedFrequencyAnalysisResult"]] = Field(["biolink:ObservedExpectedFrequencyAnalysisResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class RelativeFrequencyAnalysisResult(StudyResult):
    """
    A result of a relative frequency analysis.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/RelativeFrequencyAnalysisResult","biolink:RelativeFrequencyAnalysisResult"]] = Field(["biolink:RelativeFrequencyAnalysisResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class TextMiningResult(StudyResult):
    """
    A result of text mining.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/TextMiningResult","biolink:TextMiningResult"]] = Field(["biolink:TextMiningResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChiSquaredAnalysisResult(StudyResult):
    """
    A result of a chi squared analysis.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChiSquaredAnalysisResult","biolink:ChiSquaredAnalysisResult"]] = Field(["biolink:ChiSquaredAnalysisResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class LogOddsAnalysisResult(StudyResult):
    """
    A result of a log odds ratio analysis.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/LogOddsAnalysisResult","biolink:LogOddsAnalysisResult"]] = Field(["biolink:LogOddsAnalysisResult"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Dataset(InformationContentEntity):
    """
    an item that refers to a collection of data from a data source.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['IAO:0000100',
                            'dctypes:Dataset',
                            'schema:dataset',
                            'dcid:Dataset'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Dataset","biolink:Dataset"]] = Field(["biolink:Dataset"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DatasetDistribution(InformationContentEntity):
    """
    an item that holds distribution level information about a dataset.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['dcat:Distribution'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    distribution_download_url: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'distribution_download_url',
         'domain': 'dataset distribution',
         'domain_of': ['dataset distribution'],
         'exact_mappings': ['dcat:downloadURL'],
         'is_a': 'node property'} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DatasetDistribution","biolink:DatasetDistribution"]] = Field(["biolink:DatasetDistribution"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DatasetVersion(InformationContentEntity):
    """
    an item that holds version level information about a dataset.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    has_dataset: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_dataset',
         'broad_mappings': ['dct:source'],
         'domain': 'dataset version',
         'domain_of': ['dataset version'],
         'is_a': 'node property'} })
    ingest_date: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'ingest_date',
         'broad_mappings': ['dct:issued'],
         'domain': 'dataset version',
         'domain_of': ['dataset version'],
         'is_a': 'node property'} })
    has_distribution: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_distribution',
         'domain': 'dataset version',
         'domain_of': ['dataset version'],
         'is_a': 'node property',
         'slot_uri': 'dct:distribution'} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DatasetVersion","biolink:DatasetVersion"]] = Field(["biolink:DatasetVersion"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DatasetSummary(InformationContentEntity):
    """
    an item that holds summary level information about a dataset.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    source_web_page: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'source_web_page',
         'broad_mappings': ['dct:source'],
         'domain': 'dataset summary',
         'domain_of': ['dataset summary'],
         'is_a': 'node property'} })
    source_logo: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'source_logo',
         'domain': 'dataset summary',
         'domain_of': ['dataset summary'],
         'is_a': 'node property',
         'slot_uri': 'schema:logo'} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DatasetSummary","biolink:DatasetSummary"]] = Field(["biolink:DatasetSummary"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ConfidenceLevel(InformationContentEntity):
    """
    Level of confidence in a statement
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['SEPIO:0000167'],
         'exact_mappings': ['CIO:0000028', 'SEPIO:0000187'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'values_from': ['cio']})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ConfidenceLevel","biolink:ConfidenceLevel"]] = Field(["biolink:ConfidenceLevel"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EvidenceType(InformationContentEntity):
    """
    Class of evidence that supports an association
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['evidence code'],
         'exact_mappings': ['ECO:0000000'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'values_from': ['eco']})

    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EvidenceType","biolink:EvidenceType"]] = Field(["biolink:EvidenceType"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Publication(InformationContentEntity):
    """
    Any ‘published’ piece of information. Publications are considered broadly to include any document or document part made available in print or on the web - which may include scientific journal issues, individual articles, and books - as well as things like pre-prints, white papers, patents, drug labels, web pages, protocol documents,  and even a part of a publication if of significant knowledge scope (e.g. a figure, figure legend, or section highlighted by NLP).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['IAO:0000311'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PMID', 'PMC', 'doi', 'NLMID'],
         'in_subset': ['model_organism_database'],
         'narrow_mappings': ['IAO:0000013', 'STY:T170'],
         'slot_usage': {'id': {'description': 'Different kinds of publication subtypes '
                                              'will have different preferred '
                                              'identifiers (curies when feasible). '
                                              'Precedence of identifiers for '
                                              'scientific articles is as follows: PMID '
                                              'if available; DOI if not; actual '
                                              'alternate CURIE otherwise. Enclosing '
                                              'publications (i.e. referenced by '
                                              "'published in' node property) such as "
                                              'books and journals, should have '
                                              'industry-standard identifier such as '
                                              'from ISBN and ISSN.',
                               'name': 'id'},
                        'name': {'description': "the 'title' of the publication is "
                                                "generally recorded in the 'name' "
                                                'property (inherited from NamedThing). '
                                                "The field name 'title' is now also "
                                                'tagged as an acceptable alias for the '
                                                "node property 'name' (just in case).",
                                 'name': 'name'},
                        'pages': {'description': 'When a 2-tuple of page numbers are '
                                                 'provided, they represent the start '
                                                 'and end page of the publication '
                                                 'within its parent publication '
                                                 'context. For books, this may be set '
                                                 'to the total number of pages of the '
                                                 'book.',
                                  'multivalued': True,
                                  'name': 'pages'},
                        'publication type': {'name': 'publication type',
                                             'required': True}}})

    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Publication","biolink:Publication"]] = Field(["biolink:Publication"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Book(Publication):
    """
    This class may rarely be instantiated except if use cases of a given knowledge graph support its utility.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['isbn', 'NLMID'],
         'in_subset': ['model_organism_database'],
         'slot_usage': {'id': {'description': 'Books should have industry-standard '
                                              'identifier such as from ISBN.',
                               'name': 'id',
                               'required': True},
                        'type': {'description': 'Should generally be set to an '
                                                'ontology class defined term for '
                                                "'book'.",
                                 'name': 'type'}}})

    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Books should have industry-standard identifier such as from ISBN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Book","biolink:Book"]] = Field(["biolink:Book"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""Should generally be set to an ontology class defined term for 'book'.""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class BookChapter(Publication):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['model_organism_database'],
         'slot_usage': {'published in': {'description': 'The enclosing parent book '
                                                        'containing the chapter should '
                                                        'have industry-standard '
                                                        'identifier from ISBN.',
                                         'name': 'published in',
                                         'required': True}}})

    published_in: str = Field(..., description="""The enclosing parent book containing the chapter should have industry-standard identifier from ISBN.""", json_schema_extra = { "linkml_meta": {'alias': 'published_in',
         'domain': 'publication',
         'domain_of': ['book chapter', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P1433'],
         'is_a': 'node property',
         'values_from': ['NLMID', 'issn', 'isbn']} })
    volume: Optional[str] = Field(None, description="""volume of a book or music release in a collection/series or a published collection of journal issues in a serial publication""", json_schema_extra = { "linkml_meta": {'alias': 'volume',
         'domain': 'publication',
         'domain_of': ['book chapter', 'serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P478'],
         'is_a': 'node property'} })
    chapter: Optional[str] = Field(None, description="""chapter of a book""", json_schema_extra = { "linkml_meta": {'alias': 'chapter',
         'domain': 'book chapter',
         'domain_of': ['book chapter'],
         'exact_mappings': ['WIKIDATA:Q1980247'],
         'is_a': 'node property'} })
    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BookChapter","biolink:BookChapter"]] = Field(["biolink:BookChapter"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Serial(Publication):
    """
    This class may rarely be instantiated except if use cases of a given knowledge graph support its utility.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['journal'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['issn', 'NLMID'],
         'in_subset': ['model_organism_database'],
         'slot_usage': {'id': {'description': 'Serials (journals) should have '
                                              'industry-standard identifier such as '
                                              'from ISSN.',
                               'name': 'id',
                               'required': True},
                        'type': {'description': 'Should generally be set to an '
                                                'ontology class defined term for '
                                                "'serial' or 'journal'.",
                                 'name': 'type'}}})

    iso_abbreviation: Optional[str] = Field(None, description="""Standard abbreviation for periodicals in the International Organization for Standardization (ISO) 4 system See https://www.issn.org/services/online-services/access-to-the-ltwa/. If the 'published in' property is set, then the iso abbreviation pertains to the broader publication context (the journal) within which the given publication node is embedded, not the publication itself.""", json_schema_extra = { "linkml_meta": {'alias': 'iso_abbreviation',
         'domain': 'publication',
         'domain_of': ['serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P1160'],
         'is_a': 'node property'} })
    volume: Optional[str] = Field(None, description="""volume of a book or music release in a collection/series or a published collection of journal issues in a serial publication""", json_schema_extra = { "linkml_meta": {'alias': 'volume',
         'domain': 'publication',
         'domain_of': ['book chapter', 'serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P478'],
         'is_a': 'node property'} })
    issue: Optional[str] = Field(None, description="""issue of a newspaper, a scientific journal or magazine for reference purpose""", json_schema_extra = { "linkml_meta": {'alias': 'issue',
         'domain': 'publication',
         'domain_of': ['serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P433'],
         'is_a': 'node property'} })
    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Serials (journals) should have industry-standard identifier such as from ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Serial","biolink:Serial"]] = Field(["biolink:Serial"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""Should generally be set to an ontology class defined term for 'serial' or 'journal'.""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Article(Publication):
    """
    a piece of writing on a particular topic presented as a stand-alone section of a larger publication
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SIO:000154', 'fabio:article'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PMID'],
         'in_subset': ['model_organism_database'],
         'slot_usage': {'iso abbreviation': {'description': 'Optional value, if used '
                                                            'locally as a convenience, '
                                                            'is set to the iso '
                                                            'abbreviation of the '
                                                            "'published in' parent.",
                                             'name': 'iso abbreviation'},
                        'published in': {'description': 'The enclosing parent serial '
                                                        'containing the article should '
                                                        'have industry-standard '
                                                        'identifier from ISSN.',
                                         'name': 'published in',
                                         'required': True}}})

    published_in: str = Field(..., description="""The enclosing parent serial containing the article should have industry-standard identifier from ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'published_in',
         'domain': 'publication',
         'domain_of': ['book chapter', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P1433'],
         'is_a': 'node property',
         'values_from': ['NLMID', 'issn', 'isbn']} })
    iso_abbreviation: Optional[str] = Field(None, description="""Optional value, if used locally as a convenience, is set to the iso abbreviation of the 'published in' parent.""", json_schema_extra = { "linkml_meta": {'alias': 'iso_abbreviation',
         'domain': 'publication',
         'domain_of': ['serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P1160'],
         'is_a': 'node property'} })
    volume: Optional[str] = Field(None, description="""volume of a book or music release in a collection/series or a published collection of journal issues in a serial publication""", json_schema_extra = { "linkml_meta": {'alias': 'volume',
         'domain': 'publication',
         'domain_of': ['book chapter', 'serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P478'],
         'is_a': 'node property'} })
    issue: Optional[str] = Field(None, description="""issue of a newspaper, a scientific journal or magazine for reference purpose""", json_schema_extra = { "linkml_meta": {'alias': 'issue',
         'domain': 'publication',
         'domain_of': ['serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P433'],
         'is_a': 'node property'} })
    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Article","biolink:Article"]] = Field(["biolink:Article"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class JournalArticle(Article):
    """
    an article, typically presenting results of research, that is published in an issue of a scientific journal.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['IAO:0000013', 'fabio:JournalArticle'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PMID', 'PMCID', 'doi']})

    published_in: str = Field(..., description="""The enclosing parent serial containing the article should have industry-standard identifier from ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'published_in',
         'domain': 'publication',
         'domain_of': ['book chapter', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P1433'],
         'is_a': 'node property',
         'values_from': ['NLMID', 'issn', 'isbn']} })
    iso_abbreviation: Optional[str] = Field(None, description="""Optional value, if used locally as a convenience, is set to the iso abbreviation of the 'published in' parent.""", json_schema_extra = { "linkml_meta": {'alias': 'iso_abbreviation',
         'domain': 'publication',
         'domain_of': ['serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P1160'],
         'is_a': 'node property'} })
    volume: Optional[str] = Field(None, description="""volume of a book or music release in a collection/series or a published collection of journal issues in a serial publication""", json_schema_extra = { "linkml_meta": {'alias': 'volume',
         'domain': 'publication',
         'domain_of': ['book chapter', 'serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P478'],
         'is_a': 'node property'} })
    issue: Optional[str] = Field(None, description="""issue of a newspaper, a scientific journal or magazine for reference purpose""", json_schema_extra = { "linkml_meta": {'alias': 'issue',
         'domain': 'publication',
         'domain_of': ['serial', 'article'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P433'],
         'is_a': 'node property'} })
    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/JournalArticle","biolink:JournalArticle"]] = Field(["biolink:JournalArticle"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Patent(Publication):
    """
    a legal document granted by a patent issuing authority which confers upon the patenter the sole right to make, use and sell an invention for a set period of time.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SIO:000153', 'IAO:0000313', 'fabio:Patent'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Patent","biolink:Patent"]] = Field(["biolink:Patent"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class WebPage(Publication):
    """
    a document that is published according to World Wide Web standards, which may incorporate text, graphics, sound, and/or other features.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SIO:000302', 'NCIT-OBO:C142749', 'fabio:WebPage'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/WebPage","biolink:WebPage"]] = Field(["biolink:WebPage"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PreprintPublication(Publication):
    """
    a document reresenting an early version of an author's original scholarly work, such as a research paper or a review, prior to formal peer review and publication in a peer-reviewed scholarly or scientific journal.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['EFO:0010558', 'fabio:Preprint'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PreprintPublication","biolink:PreprintPublication"]] = Field(["biolink:PreprintPublication"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DrugLabel(Publication):
    """
    a document accompanying a drug or its container that provides written, printed or graphic information about the drug, including drug contents, specific instructions or warnings for administration, storage and disposal instructions, etc.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['NCIT-OBO:C41203'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    authors: Optional[List[str]] = Field(None, description="""connects an publication to the list of authors who contributed to the publication. This property should be a comma-delimited list of author names. It is recommended that an author's name be formatted as \"surname, firstname initial.\".   Note that this property is a node annotation expressing the citation list of authorship which might typically otherwise be more completely documented in biolink:PublicationToProviderAssociation defined edges which point to full details about an author and possibly, some qualifiers which clarify the specific status of a given author in the publication.""", json_schema_extra = { "linkml_meta": {'alias': 'authors',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    pages: Optional[List[str]] = Field(None, description="""When a 2-tuple of page numbers are provided, they represent the start and end page of the publication within its parent publication context. For books, this may be set to the total number of pages of the book.""", json_schema_extra = { "linkml_meta": {'alias': 'pages',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P304'],
         'is_a': 'node property'} })
    summary: Optional[str] = Field(None, description="""executive  summary of a publication""", json_schema_extra = { "linkml_meta": {'alias': 'summary',
         'aliases': ['abstract'],
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dct:abstract', 'WIKIDATA:Q333291'],
         'is_a': 'node property'} })
    keywords: Optional[List[str]] = Field(None, description="""keywords tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'keywords',
         'domain': 'publication',
         'domain_of': ['publication'],
         'is_a': 'node property'} })
    mesh_terms: Optional[List[str]] = Field(None, description="""mesh terms tagging a publication""", json_schema_extra = { "linkml_meta": {'alias': 'mesh_terms',
         'domain': 'publication',
         'domain_of': ['publication'],
         'exact_mappings': ['dcid:MeSHTerm'],
         'is_a': 'node property',
         'values_from': ['MESH']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    publication_type: List[str] = Field(..., description="""Ontology term for publication type may be drawn from Dublin Core types (https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/), FRBR-aligned Bibliographic Ontology (https://sparontologies.github.io/fabio/current/fabio.html), the MESH publication types (https://www.nlm.nih.gov/mesh/pubtypes.html), the Confederation of Open Access Repositories (COAR) Controlled Vocabulary for Resource Type Genres (http://vocabularies.coar-repositories.org/documentation/resource_types/), Wikidata (https://www.wikidata.org/wiki/Wikidata:Publication_types), or equivalent publication type ontology. When a given publication type ontology term is used within a given knowledge graph, then the CURIE identified term must be documented in the graph as a concept node of biolink:category biolink:OntologyClass.""", json_schema_extra = { "linkml_meta": {'alias': 'publication_type',
         'domain_of': ['publication'],
         'slot_uri': 'dct:type',
         'values_from': ['dctypes', 'fabio', 'MESH_PUB', 'COAR_RESOURCE', 'WIKIDATA']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""Different kinds of publication subtypes will have different preferred identifiers (curies when feasible). Precedence of identifiers for scientific articles is as follows: PMID if available; DOI if not; actual alternate CURIE otherwise. Enclosing publications (i.e. referenced by 'published in' node property) such as books and journals, should have industry-standard identifier such as from ISBN and ISSN.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DrugLabel","biolink:DrugLabel"]] = Field(["biolink:DrugLabel"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class RetrievalSource(InformationContentEntity):
    """
    Provides information about how a particular InformationResource served as a source from which knowledge expressed in an Edge, or data used to generate this knowledge, was retrieved.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'resource id': {'description': 'The InformationResource that '
                                                       'served as a source for the '
                                                       'knowledge expressed in an '
                                                       'Edge, or data used to generate '
                                                       'this knowledge.',
                                        'name': 'resource id',
                                        'required': True},
                        'resource role': {'description': 'The role of the '
                                                         'InformationResource in the '
                                                         'retrieval of the knowledge '
                                                         'expressed in an Edge, or '
                                                         'data used to generate this '
                                                         'knowledge.',
                                          'name': 'resource role',
                                          'required': True},
                        'upstream resource ids': {'description': 'The '
                                                                 'InformationResources '
                                                                 'that served as a '
                                                                 'source for the '
                                                                 'InformationResource '
                                                                 'that served as a '
                                                                 'source for the '
                                                                 'knowledge expressed '
                                                                 'in an Edge, or data '
                                                                 'used to generate '
                                                                 'this knowledge.',
                                                  'name': 'upstream resource ids'}}})

    resource_id: str = Field(..., description="""The InformationResource that served as a source for the knowledge expressed in an Edge, or data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'resource_id',
         'domain': 'retrieval source',
         'domain_of': ['retrieval source'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    resource_role: ResourceRoleEnum = Field(..., description="""The role of the InformationResource in the retrieval of the knowledge expressed in an Edge, or data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'resource_role',
         'domain': 'retrieval source',
         'domain_of': ['retrieval source'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    upstream_resource_ids: Optional[str] = Field(None, description="""The InformationResources that served as a source for the InformationResource that served as a source for the knowledge expressed in an Edge, or data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'upstream_resource_ids',
         'domain': 'retrieval source',
         'domain_of': ['retrieval source'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    license: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'license',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:license'],
         'is_a': 'node property',
         'narrow_mappings': ['WIKIDATA_PROPERTY:P275']} })
    rights: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'rights',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:rights'],
         'is_a': 'node property'} })
    format: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'format',
         'domain': 'information content entity',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:format', 'WIKIDATA_PROPERTY:P2701'],
         'is_a': 'node property'} })
    creation_date: Optional[date] = Field(None, description="""date on which an entity was created. This can be applied to nodes or edges""", json_schema_extra = { "linkml_meta": {'alias': 'creation_date',
         'aliases': ['publication date'],
         'domain': 'named thing',
         'domain_of': ['information content entity'],
         'exact_mappings': ['dct:createdOn', 'WIKIDATA_PROPERTY:P577'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/RetrievalSource","biolink:RetrievalSource"]] = Field(["biolink:RetrievalSource"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PhysicalEssenceOrOccurrent(ConfiguredBaseModel):
    """
    Either a physical or processual entity.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class PhysicalEssence(PhysicalEssenceOrOccurrent):
    """
    Semantic mixin concept.  Pertains to entities that have physical properties such as mass, volume, or charge.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class PhysicalEntity(PhysicalEssence, NamedThing):
    """
    An entity that has material reality (a.k.a. physical essence).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T072'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['physical essence'],
         'narrow_mappings': ['STY:T073']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhysicalEntity","biolink:PhysicalEntity"]] = Field(["biolink:PhysicalEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Occurrent(PhysicalEssenceOrOccurrent):
    """
    A processual entity.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['BFO:0000003'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True})

    pass


class ActivityAndBehavior(Occurrent):
    """
    Activity or behavior of any independent integral living, organization or mechanical actor in the world
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['UMLSSG:ACTI'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True})

    pass


class Activity(ActivityAndBehavior, NamedThing):
    """
    An activity is something that occurs over a period of time and acts upon or with entities; it may include consuming, processing, transforming, modifying, relocating, using, or generating entities.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['prov:Activity', 'NCIT:C43431', 'STY:T052'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['activity and behavior'],
         'narrow_mappings': ['STY:T056',
                             'STY:T057',
                             'STY:T064',
                             'STY:T066',
                             'STY:T062',
                             'STY:T065',
                             'STY:T058']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Activity","biolink:Activity"]] = Field(["biolink:Activity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Study(Activity):
    """
    a detailed investigation and/or analysis
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['SIO:001066', 'SEPIO:0000004'],
         'exact_mappings': ['NCIT:C63536'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'narrow_mappings': ['SIO:000994']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Study","biolink:Study"]] = Field(["biolink:Study"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Procedure(ActivityAndBehavior, NamedThing):
    """
    A series of actions conducted in a certain order or manner
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['UMLSSG:PROC', 'dcid:MedicalProcedure'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CPT'],
         'mixins': ['activity and behavior'],
         'narrow_mappings': ['STY:T059', 'STY:T060', 'STY:T061', 'STY:T063']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Procedure","biolink:Procedure"]] = Field(["biolink:Procedure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Phenomenon(Occurrent, NamedThing):
    """
    a fact or situation that is observed to exist or happen, especially one whose cause or explanation is in question
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['STY:T067', 'STY:T068', 'STY:T070'],
         'exact_mappings': ['UMLSSG:PHEN'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['occurrent'],
         'narrow_mappings': ['STY:T034', 'STY:T038', 'STY:T069']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Phenomenon","biolink:Phenomenon"]] = Field(["biolink:Phenomenon"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Device(NamedThing):
    """
    A thing made or adapted for a particular purpose, especially a piece of mechanical or electronic equipment
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'narrow_mappings': ['UMLSSG:DEVI', 'STY:T074', 'STY:T075', 'STY:T203']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Device","biolink:Device"]] = Field(["biolink:Device"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DiagnosticAid(NamedThing):
    """
    A device or substance used to help diagnose disease or injury
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T130', 'SNOMED:2949005'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiagnosticAid","biolink:DiagnosticAid"]] = Field(["biolink:DiagnosticAid"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SubjectOfInvestigation(ConfiguredBaseModel):
    """
    An entity that has the role of being studied in an investigation, study, or experiment
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class MaterialSample(SubjectOfInvestigation, PhysicalEntity):
    """
    A sample is a limited quantity of something (e.g. an individual or set of individuals from a population, or a portion of a substance) to be used for testing, analysis, inspection, investigation, demonstration, or trial use. [SIO]
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['biospecimen', 'sample', 'biosample', 'physical sample'],
         'exact_mappings': ['OBI:0000747', 'SIO:001050'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['BIOSAMPLE', 'GOLD.META'],
         'mixins': ['subject of investigation']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MaterialSample","biolink:MaterialSample"]] = Field(["biolink:MaterialSample"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PlanetaryEntity(NamedThing):
    """
    Any entity or process that exists at the level of the whole planet
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PlanetaryEntity","biolink:PlanetaryEntity"]] = Field(["biolink:PlanetaryEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EnvironmentalProcess(PlanetaryEntity, Occurrent):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['ENVO:02500000'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['occurrent']})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EnvironmentalProcess","biolink:EnvironmentalProcess"]] = Field(["biolink:EnvironmentalProcess"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EnvironmentalFeature(PlanetaryEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['ENVO:01000254'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EnvironmentalFeature","biolink:EnvironmentalFeature"]] = Field(["biolink:EnvironmentalFeature"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeographicLocation(PlanetaryEntity):
    """
    a location that can be described in lat/long coordinates
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['UMLSSG:GEOG', 'STY:T083'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    latitude: Optional[float] = Field(None, description="""latitude""", json_schema_extra = { "linkml_meta": {'alias': 'latitude',
         'domain': 'named thing',
         'domain_of': ['geographic location'],
         'exact_mappings': ['wgs:lat'],
         'is_a': 'node property'} })
    longitude: Optional[float] = Field(None, description="""longitude""", json_schema_extra = { "linkml_meta": {'alias': 'longitude',
         'domain': 'named thing',
         'domain_of': ['geographic location'],
         'exact_mappings': ['wgs:long'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeographicLocation","biolink:GeographicLocation"]] = Field(["biolink:GeographicLocation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeographicLocationAtTime(GeographicLocation):
    """
    a location that can be described in lat/long coordinates, for a particular time
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    latitude: Optional[float] = Field(None, description="""latitude""", json_schema_extra = { "linkml_meta": {'alias': 'latitude',
         'domain': 'named thing',
         'domain_of': ['geographic location'],
         'exact_mappings': ['wgs:lat'],
         'is_a': 'node property'} })
    longitude: Optional[float] = Field(None, description="""longitude""", json_schema_extra = { "linkml_meta": {'alias': 'longitude',
         'domain': 'named thing',
         'domain_of': ['geographic location'],
         'exact_mappings': ['wgs:long'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeographicLocationAtTime","biolink:GeographicLocationAtTime"]] = Field(["biolink:GeographicLocationAtTime"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ThingWithTaxon(ConfiguredBaseModel):
    """
    A mixin that can be used on any entity that can be taxonomically classified. This includes individual organisms; genes, their products and other molecular entities; body parts; biological processes
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })


class BiologicalEntity(ThingWithTaxon, NamedThing):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'aliases': ['bioentity'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['thing with taxon'],
         'narrow_mappings': ['WIKIDATA:Q28845870',
                             'STY:T050',
                             'SIO:010046',
                             'STY:T129']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BiologicalEntity","biolink:BiologicalEntity"]] = Field(["biolink:BiologicalEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenomicEntity(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['translator_minimal'],
         'mixin': True,
         'narrow_mappings': ['STY:T028', 'GENO:0000897']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })


class EpigenomicEntity(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['translator_minimal'],
         'mixin': True})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })


class BiologicalProcessOrActivity(BiologicalEntity, Occurrent, OntologyClass):
    """
    Either an individual molecular activity, or a collection of causally connected molecular activities in a biological system.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['GO', 'REACT'],
         'mixins': ['occurrent', 'ontology class']})

    has_input: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an input into the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an output of the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""holds between a process and a physical entity, where the physical entity executes the process""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BiologicalProcessOrActivity","biolink:BiologicalProcessOrActivity"]] = Field(["biolink:BiologicalProcessOrActivity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MolecularActivity(BiologicalProcessOrActivity, Occurrent, OntologyClass):
    """
    An execution of a molecular function carried out by a gene product or macromolecular complex.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['molecular function', 'molecular event', 'reaction'],
         'broad_mappings': ['STY:T045'],
         'exact_mappings': ['GO:0003674', 'STY:T044'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['GO',
                         'REACT',
                         'RHEA',
                         'metacyc.reaction',
                         'EC',
                         'TCDB',
                         'KEGG.REACTION',
                         'KEGG',
                         'KEGG.ORTHOLOGY',
                         'UMLS',
                         'BIGG.REACTION',
                         'SEED.REACTION',
                         'METANETX.REACTION'],
         'mixins': ['occurrent', 'ontology class'],
         'slot_usage': {'enabled by': {'description': 'The gene product, gene, or '
                                                      'complex that catalyzes the '
                                                      'reaction',
                                       'name': 'enabled by',
                                       'range': 'macromolecular machine mixin'},
                        'has input': {'description': 'A chemical entity that is the '
                                                     'input for the reaction',
                                      'name': 'has input',
                                      'range': 'molecular entity'},
                        'has output': {'description': 'A chemical entity that is the '
                                                      'output for the reaction',
                                       'name': 'has output',
                                       'range': 'molecular entity'}}})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    has_input: Optional[List[str]] = Field(None, description="""A chemical entity that is the input for the reaction""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""A chemical entity that is the output for the reaction""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""The gene product, gene, or complex that catalyzes the reaction""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MolecularActivity","biolink:MolecularActivity"]] = Field(["biolink:MolecularActivity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class BiologicalProcess(BiologicalProcessOrActivity, Occurrent, OntologyClass):
    """
    One or more causally connected executions of molecular functions
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['WIKIDATA:P682'],
         'exact_mappings': ['GO:0008150', 'SIO:000006', 'WIKIDATA:Q2996394'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['GO', 'REACT', 'metacyc.reaction', 'KEGG.MODULE', 'KEGG'],
         'mixins': ['occurrent', 'ontology class']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    has_input: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an input into the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an output of the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""holds between a process and a physical entity, where the physical entity executes the process""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BiologicalProcess","biolink:BiologicalProcess"]] = Field(["biolink:BiologicalProcess"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Pathway(BiologicalProcess, OntologyClass):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['PW:0000001', 'WIKIDATA:Q4915012'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['GO',
                         'REACT',
                         'KEGG',
                         'SMPDB',
                         'MSigDB',
                         'PHARMGKB.PATHWAYS',
                         'WIKIPATHWAYS',
                         'FB',
                         'PANTHER.PATHWAY',
                         'KEGG.PATHWAY',
                         'ncats.bioplanet'],
         'mixins': ['ontology class'],
         'narrow_mappings': ['SIO:010526', 'GO:0007165']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    has_input: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an input into the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an output of the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""holds between a process and a physical entity, where the physical entity executes the process""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Pathway","biolink:Pathway"]] = Field(["biolink:Pathway"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PhysiologicalProcess(BiologicalProcess, OntologyClass):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['physiology'],
         'exact_mappings': ['STY:T039', 'WIKIDATA:Q30892994'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['GO', 'REACT'],
         'mixins': ['ontology class'],
         'narrow_mappings': ['STY:T040', 'STY:T042', 'STY:T043', 'STY:T045']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    has_input: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an input into the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an output of the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""holds between a process and a physical entity, where the physical entity executes the process""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhysiologicalProcess","biolink:PhysiologicalProcess"]] = Field(["biolink:PhysiologicalProcess"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Behavior(BiologicalProcess, ActivityAndBehavior, OntologyClass):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['GO:0007610', 'STY:T053'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['ontology class', 'activity and behavior'],
         'narrow_mappings': ['STY:T041', 'STY:T054', 'STY:T055']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    has_input: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an input into the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an output of the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""holds between a process and a physical entity, where the physical entity executes the process""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Behavior","biolink:Behavior"]] = Field(["biolink:Behavior"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class OrganismAttribute(Attribute):
    """
    describes a characteristic of an organismal entity.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T032'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismAttribute","biolink:OrganismAttribute"]] = Field(["biolink:OrganismAttribute"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PhenotypicQuality(OrganismAttribute):
    """
    A property of a phenotype
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['phenotypic properties'],
         'examples': [{'value': 'weight'}],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mappings': ['PATO:0000001']})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhenotypicQuality","biolink:PhenotypicQuality"]] = Field(["biolink:PhenotypicQuality"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneticInheritance(BiologicalEntity):
    """
    The pattern or 'mode' in which a particular genetic trait or disorder is passed from one generation to the next, e.g. autosomal dominant, autosomal recessive, etc.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['inheritance'],
         'close_mappings': ['STY:T045'],
         'exact_mappings': ['HP:0000005', 'GENO:0000141', 'NCIT:C45827'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['HP', 'GENO', 'NCIT']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneticInheritance","biolink:GeneticInheritance"]] = Field(["biolink:GeneticInheritance"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class OrganismalEntity(BiologicalEntity, SubjectOfInvestigation):
    """
    A named entity that is either a part of an organism, a whole organism, population or clade of organisms, excluding chemical entities
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'exact_mappings': ['WIKIDATA:Q7239', 'UMLSSG:LIVB', 'CARO:0001010'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation'],
         'narrow_mappings': ['STY:T008'],
         'slot_usage': {'has attribute': {'description': 'may often be an organism '
                                                         'attribute',
                                          'name': 'has attribute'}}})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismalEntity","biolink:OrganismalEntity"]] = Field(["biolink:OrganismalEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Bacterium(OrganismalEntity):
    """
    A member of a group of unicellular microorganisms lacking a nuclear membrane, that reproduce by binary fission and are often motile.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCBITaxon:1869227', 'STY:T007'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Bacterium","biolink:Bacterium"]] = Field(["biolink:Bacterium"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Virus(OrganismalEntity, SubjectOfInvestigation):
    """
    A virus is a microorganism that replicates itself as a microRNA and infects the host cell.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCBITaxon:10239', 'STY:T005'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Virus","biolink:Virus"]] = Field(["biolink:Virus"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class CellularOrganism(OrganismalEntity, SubjectOfInvestigation):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCBITaxon:131567'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CellularOrganism","biolink:CellularOrganism"]] = Field(["biolink:CellularOrganism"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Mammal(CellularOrganism, SubjectOfInvestigation):
    """
    A member of the class Mammalia, a clade of endothermic amniotes distinguished from reptiles and birds by the possession of hair, three middle ear bones, mammary glands, and a neocortex
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCBITaxon:40674',
                            'STY:T015',
                            'NCIT:C14234',
                            'FOODON:03411134'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Mammal","biolink:Mammal"]] = Field(["biolink:Mammal"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Human(Mammal, SubjectOfInvestigation):
    """
    A member of the the species Homo sapiens.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T016', 'NCBITaxon:9606', 'SIO:000485', 'NCIT:C14225'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Human","biolink:Human"]] = Field(["biolink:Human"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Plant(CellularOrganism):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCIT:C14258', 'STY:T002', 'PO:0000003', 'NCIT:C79659'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Plant","biolink:Plant"]] = Field(["biolink:Plant"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Invertebrate(CellularOrganism):
    """
    An animal lacking a vertebral column. This group consists of 98% of all animal species.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCIT:C14228',
                            'OMIT:0008565',
                            'FOODON:00002452',
                            'STY:T011'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'related_mappings': ['NCBITaxon:1767184']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Invertebrate","biolink:Invertebrate"]] = Field(["biolink:Invertebrate"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Vertebrate(CellularOrganism):
    """
    A sub-phylum of animals consisting of those having a bony or cartilaginous vertebral column.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T010', 'NCBITaxon:7742', 'OMIT:0015545'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'related_mappings': ['NCBITaxon:2662825']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Vertebrate","biolink:Vertebrate"]] = Field(["biolink:Vertebrate"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Fungus(CellularOrganism):
    """
    A kingdom of eukaryotic, heterotrophic organisms that live as saprobes or parasites, including mushrooms, yeasts, smuts, molds, etc. They reproduce either sexually or asexually, and have life cycles that range from simple to complex. Filamentous fungi refer to those that grow as multicellular colonies (mushrooms and molds).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T004', 'NCIT:C14209', 'FOODON:03411261'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'narrow_mappings': ['FOODON:03315605', 'NCBITaxon:1670606']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Fungus","biolink:Fungus"]] = Field(["biolink:Fungus"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class LifeStage(OrganismalEntity):
    """
    A stage of development or growth of an organism, including post-natal adult stages
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['UBERON:0000105'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['HsapDv', 'MmusDv', 'ZFS', 'FBdv', 'WBls', 'UBERON'],
         'in_subset': ['model_organism_database'],
         'narrow_mappings': ['HsapDv:0000000']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/LifeStage","biolink:LifeStage"]] = Field(["biolink:LifeStage"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class IndividualOrganism(OrganismalEntity, SubjectOfInvestigation):
    """
    An instance of an organism. For example, Richard Nixon, Charles Darwin, my pet cat. Example ID: ORCID:0000-0002-5355-2576
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['organism'],
         'exact_mappings': ['SIO:010000', 'STY:T001'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['ORCID'],
         'mixins': ['subject of investigation'],
         'narrow_mappings': ['WIKIDATA:Q795052', 'foaf:Person']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/IndividualOrganism","biolink:IndividualOrganism"]] = Field(["biolink:IndividualOrganism"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PopulationOfIndividualOrganisms(OrganismalEntity, SubjectOfInvestigation):
    """
    A collection of individuals from the same taxonomic class distinguished by one or more characteristics.  Characteristics can include, but are not limited to, shared geographic location, genetics, phenotypes.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['PCO:0000001', 'SIO:001061', 'STY:T098', 'OBI:0000181'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['HANCESTRO'],
         'in_subset': ['model_organism_database'],
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'population'}},
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PopulationOfIndividualOrganisms","biolink:PopulationOfIndividualOrganisms"]] = Field(["biolink:PopulationOfIndividualOrganisms"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class StudyPopulation(PopulationOfIndividualOrganisms):
    """
    A group of people banded together or treated as a group as participants in a research study.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['WIKIDATA:Q7229825'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/StudyPopulation","biolink:StudyPopulation"]] = Field(["biolink:StudyPopulation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DiseaseOrPhenotypicFeature(BiologicalEntity):
    """
    Either one of a disease or an individual phenotypic feature. Some knowledge resources such as Monarch treat these as distinct, others such as MESH conflate.  Please see definitions of phenotypic feature and disease in this model for their independent descriptions.  This class is helpful to enforce domains and ranges that may involve either a disease or a phenotypic feature.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['phenome'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'narrow_mappings': ['STY:T033'],
         'union_of': ['disease', 'phenotypic feature']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiseaseOrPhenotypicFeature","biolink:DiseaseOrPhenotypicFeature"]] = Field(["biolink:DiseaseOrPhenotypicFeature"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Disease(DiseaseOrPhenotypicFeature):
    """
    A disorder of structure or function, especially one that produces specific signs, phenotypes or symptoms or that affects a specific location and is not simply a direct result of physical injury.  A disposition to undergo pathological processes that exists in an organism because of one or more disorders in that organism.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['condition', 'disorder', 'medical condition'],
         'exact_mappings': ['MONDO:0000001',
                            'DOID:4',
                            'NCIT:C2991',
                            'WIKIDATA:Q12136',
                            'SIO:010299',
                            'UMLSSG:DISO',
                            'STY:T047',
                            'dcid:Disease'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['MONDO',
                         'DOID',
                         'OMIM',
                         'OMIM.PS',
                         'orphanet',
                         'EFO',
                         'UMLS',
                         'MESH',
                         'MEDDRA',
                         'NCIT',
                         'SNOMEDCT',
                         'medgen',
                         'ICD10',
                         'ICD9',
                         'KEGG.DISEASE',
                         'HP',
                         'MP',
                         'PHARMGKB.DISEASE'],
         'in_subset': ['model_organism_database', 'translator_minimal'],
         'narrow_mappings': ['STY:T019',
                             'STY:T020',
                             'STY:T048',
                             'STY:T049',
                             'STY:T191',
                             'MONDO:0042489']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Disease","biolink:Disease"]] = Field(["biolink:Disease"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PhenotypicFeature(DiseaseOrPhenotypicFeature):
    """
    A combination of entity and quality that makes up a phenotyping statement. An observable characteristic of an individual resulting from the interaction of its genotype with its molecular and physical environment.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['sign', 'symptom', 'phenotype', 'trait', 'endophenotype'],
         'broad_mappings': ['BFO:0000019', 'PATO:0000001'],
         'exact_mappings': ['UPHENO:0001001',
                            'SIO:010056',
                            'WIKIDATA:Q104053',
                            'UMLS:C4021819',
                            'NCIT:C16977',
                            'SNOMEDCT:8116006',
                            'MESH:D010641'],
         'examples': [{'description': 'decreased body weight', 'value': 'MP:0001262'}],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['HP',
                         'EFO',
                         'NCIT',
                         'UMLS',
                         'MEDDRA',
                         'MP',
                         'ZP',
                         'UPHENO',
                         'APO',
                         'FBcv',
                         'WBPhenotype',
                         'SNOMEDCT',
                         'MESH',
                         'XPO',
                         'FYPO',
                         'TO'],
         'in_subset': ['model_organism_database'],
         'narrow_mappings': ['STY:T184',
                             'WIKIDATA:Q169872',
                             'WIKIDATA:Q25203551',
                             'ZP:00000000',
                             'FBcv:0001347',
                             'HP:0000118',
                             'MP:0000001',
                             'WBPhenotype:0000886',
                             'XPO:00000000',
                             'FYPO:0000001',
                             'APO:0000017',
                             'TO:0000387',
                             'STY:T190']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhenotypicFeature","biolink:PhenotypicFeature"]] = Field(["biolink:PhenotypicFeature"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class BehavioralFeature(PhenotypicFeature):
    """
    A phenotypic feature which is behavioral in nature.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NBO:0000243'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BehavioralFeature","biolink:BehavioralFeature"]] = Field(["biolink:BehavioralFeature"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class AnatomicalEntity(OrganismalEntity, PhysicalEssence):
    """
    A subcellular location, cell type or gross anatomical part
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['UBERON:0001062',
                            'WIKIDATA:Q4936952',
                            'UMLSSG:ANAT',
                            'STY:T017',
                            'FMA:62955',
                            'CARO:0000000',
                            'SIO:001262',
                            'STY:T029',
                            'STY:T030'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['UBERON',
                         'GO',
                         'CL',
                         'UMLS',
                         'MESH',
                         'NCIT',
                         'EMAPA',
                         'ZFA',
                         'FBbt',
                         'WBbt'],
         'in_subset': ['model_organism_database'],
         'mixins': ['physical essence'],
         'narrow_mappings': ['ZFA:0100000',
                             'FBbt:10000000',
                             'EMAPA:0',
                             'MA:0000001',
                             'XAO:0000000',
                             'WBbt:0000100',
                             'NCIT:C12219',
                             'GO:0110165',
                             'STY:T031'],
         'related_mappings': ['SNOMEDCT:123037004']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/AnatomicalEntity","biolink:AnatomicalEntity"]] = Field(["biolink:AnatomicalEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class CellularComponent(AnatomicalEntity):
    """
    A location in or around a cell
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['cell component', 'cell part'],
         'broad_mappings': ['WIKIDATA:P681'],
         'exact_mappings': ['GO:0005575',
                            'SIO:001400',
                            'WIKIDATA:Q5058355',
                            'STY:T026'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['GO', 'MESH', 'UMLS', 'NCIT', 'SNOMEDCT', 'CL', 'UBERON']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CellularComponent","biolink:CellularComponent"]] = Field(["biolink:CellularComponent"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Cell(AnatomicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['GO:0005623',
                            'CL:0000000',
                            'SIO:010001',
                            'WIKIDATA:Q7868',
                            'STY:T025',
                            'MESH:D002477'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CL',
                         'PO',
                         'UMLS',
                         'NCIT',
                         'MESH',
                         'UBERON',
                         'SNOMEDCT',
                         'MESH']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Cell","biolink:Cell"]] = Field(["biolink:Cell"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class CellLine(OrganismalEntity, SubjectOfInvestigation):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['CLO:0000031'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CLO'],
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CellLine","biolink:CellLine"]] = Field(["biolink:CellLine"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GrossAnatomicalStructure(AnatomicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['tissue', 'organ'],
         'exact_mappings': ['UBERON:0010000', 'WIKIDATA:Q4936952'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['UBERON', 'UMLS', 'MESH', 'NCIT', 'PO', 'FAO'],
         'narrow_mappings': ['STY:T023', 'STY:T024', 'STY:T018']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GrossAnatomicalStructure","biolink:GrossAnatomicalStructure"]] = Field(["biolink:GrossAnatomicalStructure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalEntityOrGeneOrGeneProduct(ConfiguredBaseModel):
    """
    A union of chemical entities and children, and gene or gene product. This mixin is helpful to use when searching across chemical entities that must include genes and their children as chemical entities.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class RegulatoryRegion(ChemicalEntityOrGeneOrGeneProduct, GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    A region (or regions) of the genome that contains known or putative regulatory elements that act in cis- or trans- to affect the transcription of gene
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['regulatory element'],
         'exact_mappings': ['SO:0005836', 'SIO:001225', 'WIKIDATA:Q3238407'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['genomic entity',
                    'chemical entity or gene or gene product',
                    'physical essence',
                    'ontology class']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/RegulatoryRegion","biolink:RegulatoryRegion"]] = Field(["biolink:RegulatoryRegion"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class AccessibleDnaRegion(RegulatoryRegion, ChemicalEntityOrGeneOrGeneProduct, GenomicEntity, PhysicalEssence, OntologyClass):
    """
    A region (or regions) of a chromatinized genome that has been measured to be more accessible to an enzyme such as DNase-I or Tn5 Transpose
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['dnase-seq accessible region', 'atac-seq accessible region'],
         'exact_mappings': ['SO:0002231'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['genomic entity',
                    'chemical entity or gene or gene product',
                    'physical essence',
                    'ontology class']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/AccessibleDnaRegion","biolink:AccessibleDnaRegion"]] = Field(["biolink:AccessibleDnaRegion"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class TranscriptionFactorBindingSite(RegulatoryRegion, ChemicalEntityOrGeneOrGeneProduct, GenomicEntity, PhysicalEssence, OntologyClass):
    """
    A region (or regions) of the genome that contains a region of DNA known or predicted to bind a protein that modulates gene transcription
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['tf binding site', 'binding site'],
         'exact_mappings': ['SO:0000235'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['genomic entity',
                    'chemical entity or gene or gene product',
                    'physical essence',
                    'ontology class']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/TranscriptionFactorBindingSite","biolink:TranscriptionFactorBindingSite"]] = Field(["biolink:TranscriptionFactorBindingSite"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalEntityOrProteinOrPolypeptide(ConfiguredBaseModel):
    """
    A union of chemical entities and children, and protein and polypeptide. This mixin is helpful to use when searching across chemical entities that must include genes and their children as chemical entities.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class ChemicalEntity(ChemicalEntityOrProteinOrPolypeptide, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, NamedThing, ChemicalOrDrugOrTreatment):
    """
    A chemical entity is a physical entity that pertains to chemistry or biochemistry.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['STY:T167'],
         'exact_mappings': ['CHEBI:24431', 'SIO:010004', 'WIKIDATA:Q79529', 'STY:T103'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'in_subset': ['translator_minimal'],
         'mixins': ['physical essence',
                    'chemical or drug or treatment',
                    'chemical entity or gene or gene product',
                    'chemical entity or protein or polypeptide'],
         'narrow_mappings': ['WIKIDATA:Q43460564', 'STY:T123', 'STY:T131']})

    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalEntity","biolink:ChemicalEntity"]] = Field(["biolink:ChemicalEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MolecularEntity(ChemicalEntity):
    """
    A molecular entity is a chemical entity composed of individual or covalently bonded atoms.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['STY:T088',
                             'STY:T085',
                             'CHEBI:23367',
                             'bioschemas:MolecularEntity']})

    is_metabolite: Optional[bool] = Field(None, description="""indicates whether a molecular entity is a metabolite""", json_schema_extra = { "linkml_meta": {'alias': 'is_metabolite',
         'domain': 'molecular entity',
         'domain_of': ['molecular entity'],
         'exact_mappings': ['CHEBI:25212'],
         'is_a': 'node property'} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MolecularEntity","biolink:MolecularEntity"]] = Field(["biolink:MolecularEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SmallMolecule(MolecularEntity):
    """
    A small molecule entity is a molecular entity characterized by availability in small-molecule databases of SMILES, InChI, IUPAC, or other unambiguous representation of its precise chemical structure; for convenience of representation, any valid chemical representation is included, even if it is not strictly molecular (e.g., sodium ion).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['chemical substance'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'in_subset': ['model_organism_database', 'translator_minimal'],
         'narrow_mappings': ['STY:T196',
                             'CHEBI:59999',
                             'bioschemas:ChemicalSubstance',
                             'STY:T125',
                             'STY:T197',
                             'STY:T109',
                             'STY:T118',
                             'STY:T111',
                             'STY:T119',
                             'STY:T124',
                             'STY:T115',
                             'STY:T110',
                             'STY:T127']})

    is_metabolite: Optional[bool] = Field(None, description="""indicates whether a molecular entity is a metabolite""", json_schema_extra = { "linkml_meta": {'alias': 'is_metabolite',
         'domain': 'molecular entity',
         'domain_of': ['molecular entity'],
         'exact_mappings': ['CHEBI:25212'],
         'is_a': 'node property'} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SmallMolecule","biolink:SmallMolecule"]] = Field(["biolink:SmallMolecule"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalMixture(ChemicalEntity):
    """
    A chemical mixture is a chemical entity composed of two or more molecular entities.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['dcid:ChemicalCompound'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['NCIT:C20401', 'SNOMEDCT:49616005']})

    is_supplement: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_supplement',
         'domain': 'chemical mixture',
         'domain_of': ['chemical mixture'],
         'is_a': 'node property'} })
    highest_FDA_approval_status: Optional[ApprovalStatusEnum] = Field(None, description="""Should be the highest level of FDA approval this chemical entity or device has, regardless of which disease, condition or phenotype it is currently being reviewed to treat.  For specific levels of FDA approval for a specific condition, disease, phenotype, etc., see the association slot, 'clinical approval status.'""", json_schema_extra = { "linkml_meta": {'alias': 'highest_FDA_approval_status', 'domain_of': ['chemical mixture']} })
    drug_regulatory_status_world_wide: Optional[ApprovalStatusEnum] = Field(None, description="""An agglomeration of drug regulatory status worldwide. Not specific to FDA.""", json_schema_extra = { "linkml_meta": {'alias': 'drug_regulatory_status_world_wide',
         'aliases': ['max phase'],
         'domain_of': ['chemical mixture'],
         'exact_mappings': ['NCIT:C172573'],
         'narrow_mappings': ['NCIT:R172',
                             'NCIT:regimen_has_accepted_use_for_disease',
                             'REPODB:clinically_tested_approved_unknown_phase',
                             'REPODB:clinically_tested_suspended_phase_0',
                             'REPODB:clinically_tested_suspended_phase_1',
                             'REPODB:clinically_tested_suspended_phase_1_or_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2_or_phase_3',
                             'REPODB:clinically_tested_suspended_phase_3',
                             'REPODB:clinically_tested_terminated_phase_0',
                             'REPODB:clinically_tested_terminated_phase_1',
                             'REPODB:clinically_tested_terminated_phase_1_or_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2_or_phase_3',
                             'REPODB:clinically_tested_terminated_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_0',
                             'REPODB:clinically_tested_withdrawn_phase_1',
                             'REPODB:clinically_tested_withdrawn_phase_1_or_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2_or_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_3']} })
    routes_of_delivery: Optional[List[DrugDeliveryEnum]] = Field(None, description="""the method or process of administering a pharmaceutical compound to achieve a therapeutic effect in humans or animals.""", json_schema_extra = { "linkml_meta": {'alias': 'routes_of_delivery', 'domain_of': ['chemical mixture']} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalMixture","biolink:ChemicalMixture"]] = Field(["biolink:ChemicalMixture"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class NucleicAcidEntity(MolecularEntity, GenomicEntity, ThingWithTaxon, PhysicalEssence, OntologyClass):
    """
    A nucleic acid entity is a molecular entity characterized by availability in gene databases of nucleotide-based sequence representations of its precise sequence; for convenience of representation, partial sequences of various kinds are included.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['sequence feature', 'genomic entity'],
         'exact_mappings': ['SO:0000110'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'UNII',
                         'CHEBI',
                         'MESH',
                         'CAS',
                         'GTOPDB',
                         'HMDB',
                         'KEGG',
                         'KEGG.COMPOUND',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'INCHI',
                         'INCHIKEY',
                         'KEGG.GLYCAN',
                         'KEGG.ENVIRON',
                         'ChemBank',
                         'SIDER.DRUG',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'UMLS'],
         'in_subset': ['model_organism_database', 'translator_minimal'],
         'mixins': ['genomic entity',
                    'thing with taxon',
                    'physical essence',
                    'ontology class'],
         'narrow_mappings': ['STY:T086', 'STY:T114']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    is_metabolite: Optional[bool] = Field(None, description="""indicates whether a molecular entity is a metabolite""", json_schema_extra = { "linkml_meta": {'alias': 'is_metabolite',
         'domain': 'molecular entity',
         'domain_of': ['molecular entity'],
         'exact_mappings': ['CHEBI:25212'],
         'is_a': 'node property'} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/NucleicAcidEntity","biolink:NucleicAcidEntity"]] = Field(["biolink:NucleicAcidEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MolecularMixture(ChemicalMixture):
    """
    A molecular mixture is a chemical mixture composed of two or more molecular entities with known concentration and stoichiometry.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'in_subset': ['translator_minimal']})

    is_supplement: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_supplement',
         'domain': 'chemical mixture',
         'domain_of': ['chemical mixture'],
         'is_a': 'node property'} })
    highest_FDA_approval_status: Optional[ApprovalStatusEnum] = Field(None, description="""Should be the highest level of FDA approval this chemical entity or device has, regardless of which disease, condition or phenotype it is currently being reviewed to treat.  For specific levels of FDA approval for a specific condition, disease, phenotype, etc., see the association slot, 'clinical approval status.'""", json_schema_extra = { "linkml_meta": {'alias': 'highest_FDA_approval_status', 'domain_of': ['chemical mixture']} })
    drug_regulatory_status_world_wide: Optional[ApprovalStatusEnum] = Field(None, description="""An agglomeration of drug regulatory status worldwide. Not specific to FDA.""", json_schema_extra = { "linkml_meta": {'alias': 'drug_regulatory_status_world_wide',
         'aliases': ['max phase'],
         'domain_of': ['chemical mixture'],
         'exact_mappings': ['NCIT:C172573'],
         'narrow_mappings': ['NCIT:R172',
                             'NCIT:regimen_has_accepted_use_for_disease',
                             'REPODB:clinically_tested_approved_unknown_phase',
                             'REPODB:clinically_tested_suspended_phase_0',
                             'REPODB:clinically_tested_suspended_phase_1',
                             'REPODB:clinically_tested_suspended_phase_1_or_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2_or_phase_3',
                             'REPODB:clinically_tested_suspended_phase_3',
                             'REPODB:clinically_tested_terminated_phase_0',
                             'REPODB:clinically_tested_terminated_phase_1',
                             'REPODB:clinically_tested_terminated_phase_1_or_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2_or_phase_3',
                             'REPODB:clinically_tested_terminated_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_0',
                             'REPODB:clinically_tested_withdrawn_phase_1',
                             'REPODB:clinically_tested_withdrawn_phase_1_or_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2_or_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_3']} })
    routes_of_delivery: Optional[List[DrugDeliveryEnum]] = Field(None, description="""the method or process of administering a pharmaceutical compound to achieve a therapeutic effect in humans or animals.""", json_schema_extra = { "linkml_meta": {'alias': 'routes_of_delivery', 'domain_of': ['chemical mixture']} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MolecularMixture","biolink:MolecularMixture"]] = Field(["biolink:MolecularMixture"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ComplexMolecularMixture(ChemicalMixture):
    """
    A complex molecular mixture is a chemical mixture composed of two or more molecular entities with unknown concentration and stoichiometry.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'UNII',
                         'CHEBI',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG',
                         'KEGG.ENVIRON',
                         'UMLS'],
         'in_subset': ['translator_minimal']})

    is_supplement: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_supplement',
         'domain': 'chemical mixture',
         'domain_of': ['chemical mixture'],
         'is_a': 'node property'} })
    highest_FDA_approval_status: Optional[ApprovalStatusEnum] = Field(None, description="""Should be the highest level of FDA approval this chemical entity or device has, regardless of which disease, condition or phenotype it is currently being reviewed to treat.  For specific levels of FDA approval for a specific condition, disease, phenotype, etc., see the association slot, 'clinical approval status.'""", json_schema_extra = { "linkml_meta": {'alias': 'highest_FDA_approval_status', 'domain_of': ['chemical mixture']} })
    drug_regulatory_status_world_wide: Optional[ApprovalStatusEnum] = Field(None, description="""An agglomeration of drug regulatory status worldwide. Not specific to FDA.""", json_schema_extra = { "linkml_meta": {'alias': 'drug_regulatory_status_world_wide',
         'aliases': ['max phase'],
         'domain_of': ['chemical mixture'],
         'exact_mappings': ['NCIT:C172573'],
         'narrow_mappings': ['NCIT:R172',
                             'NCIT:regimen_has_accepted_use_for_disease',
                             'REPODB:clinically_tested_approved_unknown_phase',
                             'REPODB:clinically_tested_suspended_phase_0',
                             'REPODB:clinically_tested_suspended_phase_1',
                             'REPODB:clinically_tested_suspended_phase_1_or_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2_or_phase_3',
                             'REPODB:clinically_tested_suspended_phase_3',
                             'REPODB:clinically_tested_terminated_phase_0',
                             'REPODB:clinically_tested_terminated_phase_1',
                             'REPODB:clinically_tested_terminated_phase_1_or_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2_or_phase_3',
                             'REPODB:clinically_tested_terminated_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_0',
                             'REPODB:clinically_tested_withdrawn_phase_1',
                             'REPODB:clinically_tested_withdrawn_phase_1_or_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2_or_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_3']} })
    routes_of_delivery: Optional[List[DrugDeliveryEnum]] = Field(None, description="""the method or process of administering a pharmaceutical compound to achieve a therapeutic effect in humans or animals.""", json_schema_extra = { "linkml_meta": {'alias': 'routes_of_delivery', 'domain_of': ['chemical mixture']} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ComplexMolecularMixture","biolink:ComplexMolecularMixture"]] = Field(["biolink:ComplexMolecularMixture"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ProcessedMaterial(ChemicalMixture):
    """
    A chemical entity (often a mixture) processed for consumption for nutritional, medical or technical use. Is a material entity that is created or changed during material processing.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['OBI:0000047'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'foodb.food',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS']})

    is_supplement: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_supplement',
         'domain': 'chemical mixture',
         'domain_of': ['chemical mixture'],
         'is_a': 'node property'} })
    highest_FDA_approval_status: Optional[ApprovalStatusEnum] = Field(None, description="""Should be the highest level of FDA approval this chemical entity or device has, regardless of which disease, condition or phenotype it is currently being reviewed to treat.  For specific levels of FDA approval for a specific condition, disease, phenotype, etc., see the association slot, 'clinical approval status.'""", json_schema_extra = { "linkml_meta": {'alias': 'highest_FDA_approval_status', 'domain_of': ['chemical mixture']} })
    drug_regulatory_status_world_wide: Optional[ApprovalStatusEnum] = Field(None, description="""An agglomeration of drug regulatory status worldwide. Not specific to FDA.""", json_schema_extra = { "linkml_meta": {'alias': 'drug_regulatory_status_world_wide',
         'aliases': ['max phase'],
         'domain_of': ['chemical mixture'],
         'exact_mappings': ['NCIT:C172573'],
         'narrow_mappings': ['NCIT:R172',
                             'NCIT:regimen_has_accepted_use_for_disease',
                             'REPODB:clinically_tested_approved_unknown_phase',
                             'REPODB:clinically_tested_suspended_phase_0',
                             'REPODB:clinically_tested_suspended_phase_1',
                             'REPODB:clinically_tested_suspended_phase_1_or_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2_or_phase_3',
                             'REPODB:clinically_tested_suspended_phase_3',
                             'REPODB:clinically_tested_terminated_phase_0',
                             'REPODB:clinically_tested_terminated_phase_1',
                             'REPODB:clinically_tested_terminated_phase_1_or_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2_or_phase_3',
                             'REPODB:clinically_tested_terminated_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_0',
                             'REPODB:clinically_tested_withdrawn_phase_1',
                             'REPODB:clinically_tested_withdrawn_phase_1_or_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2_or_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_3']} })
    routes_of_delivery: Optional[List[DrugDeliveryEnum]] = Field(None, description="""the method or process of administering a pharmaceutical compound to achieve a therapeutic effect in humans or animals.""", json_schema_extra = { "linkml_meta": {'alias': 'routes_of_delivery', 'domain_of': ['chemical mixture']} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ProcessedMaterial","biolink:ProcessedMaterial"]] = Field(["biolink:ProcessedMaterial"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Drug(MolecularMixture, ChemicalOrDrugOrTreatment, OntologyClass):
    """
    A substance intended for use in the diagnosis, cure, mitigation, treatment, or prevention of disease
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['STY:T121'],
         'comments': ['The CHEBI ID represents a role rather than a substance'],
         'exact_mappings': ['WIKIDATA:Q12140', 'CHEBI:23888', 'STY:T200', 'dcid:Drug'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['ncats.drug',
                         'RXCUI',
                         'NDC',
                         'UMLS',
                         'CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'KEGG.GLYCAN',
                         'KEGG.ENVIRON',
                         'KEGG.ENVIRON',
                         'KEGG'],
         'mixins': ['chemical or drug or treatment', 'ontology class'],
         'narrow_mappings': ['STY:T195']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    is_supplement: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_supplement',
         'domain': 'chemical mixture',
         'domain_of': ['chemical mixture'],
         'is_a': 'node property'} })
    highest_FDA_approval_status: Optional[ApprovalStatusEnum] = Field(None, description="""Should be the highest level of FDA approval this chemical entity or device has, regardless of which disease, condition or phenotype it is currently being reviewed to treat.  For specific levels of FDA approval for a specific condition, disease, phenotype, etc., see the association slot, 'clinical approval status.'""", json_schema_extra = { "linkml_meta": {'alias': 'highest_FDA_approval_status', 'domain_of': ['chemical mixture']} })
    drug_regulatory_status_world_wide: Optional[ApprovalStatusEnum] = Field(None, description="""An agglomeration of drug regulatory status worldwide. Not specific to FDA.""", json_schema_extra = { "linkml_meta": {'alias': 'drug_regulatory_status_world_wide',
         'aliases': ['max phase'],
         'domain_of': ['chemical mixture'],
         'exact_mappings': ['NCIT:C172573'],
         'narrow_mappings': ['NCIT:R172',
                             'NCIT:regimen_has_accepted_use_for_disease',
                             'REPODB:clinically_tested_approved_unknown_phase',
                             'REPODB:clinically_tested_suspended_phase_0',
                             'REPODB:clinically_tested_suspended_phase_1',
                             'REPODB:clinically_tested_suspended_phase_1_or_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2_or_phase_3',
                             'REPODB:clinically_tested_suspended_phase_3',
                             'REPODB:clinically_tested_terminated_phase_0',
                             'REPODB:clinically_tested_terminated_phase_1',
                             'REPODB:clinically_tested_terminated_phase_1_or_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2_or_phase_3',
                             'REPODB:clinically_tested_terminated_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_0',
                             'REPODB:clinically_tested_withdrawn_phase_1',
                             'REPODB:clinically_tested_withdrawn_phase_1_or_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2_or_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_3']} })
    routes_of_delivery: Optional[List[DrugDeliveryEnum]] = Field(None, description="""the method or process of administering a pharmaceutical compound to achieve a therapeutic effect in humans or animals.""", json_schema_extra = { "linkml_meta": {'alias': 'routes_of_delivery', 'domain_of': ['chemical mixture']} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Drug","biolink:Drug"]] = Field(["biolink:Drug"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EnvironmentalFoodContaminant(ChemicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'foodb.food',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'related_mappings': ['CHEBI:78299']})

    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EnvironmentalFoodContaminant","biolink:EnvironmentalFoodContaminant"]] = Field(["biolink:EnvironmentalFoodContaminant"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class FoodAdditive(ChemicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'foodb.compound',
                         'foodb.food',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS'],
         'related_mappings': ['CHEBI:64047']})

    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/FoodAdditive","biolink:FoodAdditive"]] = Field(["biolink:FoodAdditive"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Food(ChemicalMixture):
    """
    A substance consumed by a living organism as a source of nutrition
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['foodb.food',
                         'foodb.compound',
                         'FOODON',
                         'CHEBI',
                         'UNII',
                         'PUBCHEM.COMPOUND',
                         'CHEMBL.COMPOUND',
                         'DRUGBANK',
                         'MESH',
                         'CAS',
                         'DrugCentral',
                         'GTOPDB',
                         'HMDB',
                         'KEGG.COMPOUND',
                         'PHARMGKB.DRUG',
                         'ChemBank',
                         'PUBCHEM.SUBSTANCE',
                         'SIDER.DRUG',
                         'INCHI',
                         'INCHIKEY',
                         'BIGG.METABOLITE',
                         'KEGG.GLYCAN',
                         'KEGG.DRUG',
                         'KEGG.ENVIRON',
                         'KEGG',
                         'UMLS']})

    is_supplement: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_supplement',
         'domain': 'chemical mixture',
         'domain_of': ['chemical mixture'],
         'is_a': 'node property'} })
    highest_FDA_approval_status: Optional[ApprovalStatusEnum] = Field(None, description="""Should be the highest level of FDA approval this chemical entity or device has, regardless of which disease, condition or phenotype it is currently being reviewed to treat.  For specific levels of FDA approval for a specific condition, disease, phenotype, etc., see the association slot, 'clinical approval status.'""", json_schema_extra = { "linkml_meta": {'alias': 'highest_FDA_approval_status', 'domain_of': ['chemical mixture']} })
    drug_regulatory_status_world_wide: Optional[ApprovalStatusEnum] = Field(None, description="""An agglomeration of drug regulatory status worldwide. Not specific to FDA.""", json_schema_extra = { "linkml_meta": {'alias': 'drug_regulatory_status_world_wide',
         'aliases': ['max phase'],
         'domain_of': ['chemical mixture'],
         'exact_mappings': ['NCIT:C172573'],
         'narrow_mappings': ['NCIT:R172',
                             'NCIT:regimen_has_accepted_use_for_disease',
                             'REPODB:clinically_tested_approved_unknown_phase',
                             'REPODB:clinically_tested_suspended_phase_0',
                             'REPODB:clinically_tested_suspended_phase_1',
                             'REPODB:clinically_tested_suspended_phase_1_or_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2',
                             'REPODB:clinically_tested_suspended_phase_2_or_phase_3',
                             'REPODB:clinically_tested_suspended_phase_3',
                             'REPODB:clinically_tested_terminated_phase_0',
                             'REPODB:clinically_tested_terminated_phase_1',
                             'REPODB:clinically_tested_terminated_phase_1_or_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2',
                             'REPODB:clinically_tested_terminated_phase_2_or_phase_3',
                             'REPODB:clinically_tested_terminated_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_0',
                             'REPODB:clinically_tested_withdrawn_phase_1',
                             'REPODB:clinically_tested_withdrawn_phase_1_or_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2',
                             'REPODB:clinically_tested_withdrawn_phase_2_or_phase_3',
                             'REPODB:clinically_tested_withdrawn_phase_3']} })
    routes_of_delivery: Optional[List[DrugDeliveryEnum]] = Field(None, description="""the method or process of administering a pharmaceutical compound to achieve a therapeutic effect in humans or animals.""", json_schema_extra = { "linkml_meta": {'alias': 'routes_of_delivery', 'domain_of': ['chemical mixture']} })
    trade_name: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'trade_name',
         'domain': 'chemical entity',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    available_from: Optional[List[DrugAvailabilityEnum]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'available_from',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    max_tolerated_dose: Optional[str] = Field(None, description="""The highest dose of a drug or treatment that does not cause unacceptable side effects. The maximum tolerated dose is determined in clinical trials by testing increasing doses on different groups of people until the highest dose with acceptable side effects is found. Also called MTD.""", json_schema_extra = { "linkml_meta": {'alias': 'max_tolerated_dose',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    is_toxic: Optional[bool] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'is_toxic',
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'is_a': 'node property'} })
    has_chemical_role: Optional[List[str]] = Field(None, description="""A role is particular behaviour which a chemical entity may exhibit.""", json_schema_extra = { "linkml_meta": {'alias': 'has_chemical_role',
         'comments': ['We expect primarily to use CHEBI chemical roles here; however, '
                      'we are looking for a mapping between CHEBI And ATC codes to '
                      'support this slot.'],
         'domain': 'named thing',
         'domain_of': ['chemical entity'],
         'id_prefixes': ['CHEBI'],
         'inherited': True,
         'is_a': 'related to at concept level'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Food","biolink:Food"]] = Field(["biolink:Food"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MacromolecularMachineMixin(ConfiguredBaseModel):
    """
    A union of gene locus, gene product, and macromolecular complex. These are the basic units of function in a cell. They either carry out individual biological activities, or they encode molecules which do this.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'name': {'description': 'genes are typically designated by a '
                                                'short symbol and a full name. We map '
                                                'the symbol to the default display '
                                                'name and use an additional slot for '
                                                'full name',
                                 'name': 'name',
                                 'range': 'symbol type'}}})

    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })


class GeneOrGeneProduct(MacromolecularMachineMixin):
    """
    A union of gene loci or gene products. Frequently an identifier for one will be used as proxy for another
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CHEMBL.TARGET', 'IUPHAR.FAMILY'],
         'mixin': True})

    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })


class Gene(GeneOrGeneProduct, ChemicalEntityOrGeneOrGeneProduct, GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    A region (or regions) that includes all of the sequence elements necessary to encode a functional transcript. A gene locus may include regulatory regions, transcribed regions and/or other functional sequence regions.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['NCIT:C45822'],
         'exact_mappings': ['SO:0000704', 'SIO:010035', 'WIKIDATA:Q7187', 'dcid:Gene'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['NCBIGene',
                         'ENSEMBL',
                         'HGNC',
                         'MGI',
                         'ZFIN',
                         'dictyBase',
                         'WB',
                         'WormBase',
                         'FB',
                         'RGD',
                         'SGD',
                         'PomBase',
                         'OMIM',
                         'KEGG.GENES',
                         'UMLS',
                         'Xenbase',
                         'AspGD',
                         'PHARMGKB.GENE'],
         'in_subset': ['translator_minimal', 'model_organism_database'],
         'mixins': ['gene or gene product',
                    'genomic entity',
                    'chemical entity or gene or gene product',
                    'physical essence',
                    'ontology class'],
         'narrow_mappings': ['bioschemas:gene']})

    symbol: Optional[str] = Field(None, description="""Symbol for a particular thing""", json_schema_extra = { "linkml_meta": {'alias': 'symbol',
         'domain': 'named thing',
         'domain_of': ['gene'],
         'exact_mappings': ['AGRKB:symbol', 'gpi:DB_Object_Symbol'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Gene","biolink:Gene"]] = Field(["biolink:Gene"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneProductMixin(GeneOrGeneProduct):
    """
    The functional molecular product of a single gene locus. Gene products are either proteins or functional RNA molecules.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['WIKIDATA:Q424689', 'GENO:0000907', 'NCIT:C26548'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['UniProtKB', 'gtpo', 'PR'],
         'mixin': True})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })


class GeneProductIsoformMixin(GeneProductMixin):
    """
    This is an abstract class that can be mixed in with different kinds of gene products to indicate that the gene product is intended to represent a specific isoform rather than a canonical or reference or generic product. The designation of canonical or reference may be arbitrary, or it may represent the superclass of all isoforms.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })


class MacromolecularComplex(MacromolecularMachineMixin, BiologicalEntity):
    """
    A stable assembly of two or more macromolecules, i.e. proteins, nucleic acids, carbohydrates or lipids, in which at least one component is a protein and the constituent parts function together.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['GO:0032991', 'WIKIDATA:Q22325163'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['INTACT', 'GO', 'PR', 'REACT', 'ComplexPortal'],
         'in_subset': ['model_organism_database'],
         'mixins': ['macromolecular machine mixin']})

    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MacromolecularComplex","biolink:MacromolecularComplex"]] = Field(["biolink:MacromolecularComplex"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class NucleosomeModification(GeneProductIsoformMixin, EpigenomicEntity, GenomicEntity, BiologicalEntity):
    """
    A chemical modification of a histone protein within a nucleosome octomer or a substitution of a histone with a variant histone isoform. e.g. Histone 4 Lysine 20 methylation (H4K20me), histone variant H2AZ substituting H2A.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene product isoform mixin',
                    'genomic entity',
                    'epigenomic entity']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/NucleosomeModification","biolink:NucleosomeModification"]] = Field(["biolink:NucleosomeModification"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Genome(GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    A genome is the sum of genetic material within a cell or virion.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['dcid:GenomeAssemblyUnit'],
         'exact_mappings': ['SO:0001026', 'SIO:000984', 'WIKIDATA:Q7020'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['model_organism_database'],
         'mixins': ['genomic entity', 'physical essence', 'ontology class']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Genome","biolink:Genome"]] = Field(["biolink:Genome"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Exon(BiologicalEntity):
    """
    A region of the transcript sequence within a gene which is not removed from the primary RNA transcript by RNA splicing.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SO:0000147', 'SIO:010445', 'WIKIDATA:Q373027'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Exon","biolink:Exon"]] = Field(["biolink:Exon"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Transcript(BiologicalEntity):
    """
    An RNA synthesized on a DNA or RNA template by an RNA polymerase.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SO:0000673',
                            'SIO:010450',
                            'WIKIDATA:Q7243183',
                            'dcid:RNATranscript'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['ENSEMBL', 'FB'],
         'in_subset': ['model_organism_database']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Transcript","biolink:Transcript"]] = Field(["biolink:Transcript"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class CodingSequence(GenomicEntity, BiologicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SO:0000316', 'SIO:001390'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['genomic entity']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CodingSequence","biolink:CodingSequence"]] = Field(["biolink:CodingSequence"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Polypeptide(ChemicalEntityOrProteinOrPolypeptide, ChemicalEntityOrGeneOrGeneProduct, BiologicalEntity):
    """
    A polypeptide is a molecular entity characterized by availability in protein databases of amino-acid-based sequence representations of its precise primary structure; for convenience of representation, partial sequences of various kinds are included, even if they do not represent a physical molecule.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['amino acid entity'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['UniProtKB', 'PR', 'ENSEMBL', 'FB', 'UMLS'],
         'in_subset': ['model_organism_database'],
         'mixins': ['chemical entity or gene or gene product',
                    'chemical entity or protein or polypeptide'],
         'narrow_mappings': ['SO:0000104', 'STY:T116', 'STY:T087']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Polypeptide","biolink:Polypeptide"]] = Field(["biolink:Polypeptide"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Protein(Polypeptide, GeneProductMixin):
    """
    A gene product that is composed of a chain of amino acid sequences and is produced by ribosome-mediated translation of mRNA
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['bioschemas:Protein'],
         'exact_mappings': ['PR:000000001', 'SIO:010043', 'WIKIDATA:Q8054'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['UniProtKB',
                         'PR',
                         'ENSEMBL',
                         'FB',
                         'UMLS',
                         'MESH',
                         'ncats.drug'],
         'mixins': ['gene product mixin'],
         'narrow_mappings': ['STY:T126', 'STY:T192']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Protein","biolink:Protein"]] = Field(["biolink:Protein"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ProteinIsoform(Protein, GeneProductIsoformMixin):
    """
    Represents a protein that is a specific isoform of the canonical or reference protein. See https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4114032/
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['proteoform'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['UniProtKB', 'UNIPROT.ISOFORM', 'PR', 'ENSEMBL'],
         'mixins': ['gene product isoform mixin']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ProteinIsoform","biolink:ProteinIsoform"]] = Field(["biolink:ProteinIsoform"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PosttranslationalModification(GeneProductIsoformMixin, BiologicalEntity):
    """
    A chemical modification of a polypeptide or protein that occurs after translation. e.g. polypeptide cleavage to form separate proteins, methylation or acetylation of histone tail amino acids, protein ubiquitination.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene product isoform mixin']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PosttranslationalModification","biolink:PosttranslationalModification"]] = Field(["biolink:PosttranslationalModification"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class NucleicAcidSequenceMotif(BiologicalEntity):
    """
    A linear nucleotide sequence pattern that is widespread and has, or is conjectured to have, a biological significance. e.g. the TATA box promoter motif, transcription factor binding consensus sequences.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['consensus sequence'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/NucleicAcidSequenceMotif","biolink:NucleicAcidSequenceMotif"]] = Field(["biolink:NucleicAcidSequenceMotif"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class RNAProduct(Transcript, GeneProductMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['CHEBI:33697', 'WIKIDATA:Q11053'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['RNACENTRAL'],
         'mixins': ['gene product mixin']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/RNAProduct","biolink:RNAProduct"]] = Field(["biolink:RNAProduct"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class RNAProductIsoform(RNAProduct, GeneProductIsoformMixin):
    """
    Represents a protein that is a specific isoform of the canonical or reference RNA
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['RNACENTRAL'],
         'mixins': ['gene product isoform mixin']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/RNAProductIsoform","biolink:RNAProductIsoform"]] = Field(["biolink:RNAProductIsoform"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class NoncodingRNAProduct(RNAProduct):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SO:0000655', 'SIO:001235'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['RNACENTRAL', 'NCBIGene', 'ENSEMBL']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/NoncodingRNAProduct","biolink:NoncodingRNAProduct"]] = Field(["biolink:NoncodingRNAProduct"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MicroRNA(NoncodingRNAProduct):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SO:0000276', 'SIO:001397', 'WIKIDATA:Q310899'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['MIR', 'HGNC', 'WormBase'],
         'in_subset': ['model_organism_database']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MicroRNA","biolink:MicroRNA"]] = Field(["biolink:MicroRNA"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SiRNA(NoncodingRNAProduct):
    """
    A small RNA molecule that is the product of a longer exogenous or endogenous dsRNA, which is either a bimolecular duplex or very long hairpin, processed (via the Dicer pathway) such that numerous siRNAs accumulate from both strands of the dsRNA. SRNAs trigger the cleavage of their target molecules.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['small interfering RNA', 'RNAi'],
         'exact_mappings': ['SO:0000646', 'WIKIDATA:Q203221'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['MIR', 'HGNC', 'WormBase'],
         'in_subset': ['model_organism_database']})

    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SiRNA","biolink:SiRNA"]] = Field(["biolink:SiRNA"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""genes are typically designated by a short symbol and a full name. We map the symbol to the default display name and use an additional slot for full name""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneGroupingMixin(ConfiguredBaseModel):
    """
    any grouping of multiple genes or gene products
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    has_gene_or_gene_product: Optional[List[str]] = Field(None, description="""connects an entity with one or more gene or gene products""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene_or_gene_product',
         'domain': 'named thing',
         'domain_of': ['gene grouping mixin'],
         'is_a': 'node property'} })


class ProteinDomain(GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct, BiologicalEntity):
    """
    A conserved part of protein sequence and (tertiary) structure that can evolve, function, and exist independently of the rest of the protein chain. Protein domains maintain their structure and function independently of the proteins in which they are found. e.g. an SH3 domain.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCIT:C13379', 'SIO:001379', 'UMLS:C1514562'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene grouping mixin', 'chemical entity or gene or gene product']})

    has_gene_or_gene_product: Optional[List[str]] = Field(None, description="""connects an entity with one or more gene or gene products""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene_or_gene_product',
         'domain': 'named thing',
         'domain_of': ['gene grouping mixin'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ProteinDomain","biolink:ProteinDomain"]] = Field(["biolink:ProteinDomain"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ProteinFamily(GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct, BiologicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['NCIT:C26004', 'WIKIDATA:Q2278983'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene grouping mixin', 'chemical entity or gene or gene product'],
         'narrow_mappings': ['SIO:001380', 'NCIT:C20130', 'WIKIDATA:Q417841']})

    has_gene_or_gene_product: Optional[List[str]] = Field(None, description="""connects an entity with one or more gene or gene products""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene_or_gene_product',
         'domain': 'named thing',
         'domain_of': ['gene grouping mixin'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ProteinFamily","biolink:ProteinFamily"]] = Field(["biolink:ProteinFamily"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneFamily(GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct, BiologicalEntity):
    """
    any grouping of multiple genes or gene products related by common descent
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['orthogroup', 'protein family'],
         'exact_mappings': ['NCIT:C26004', 'WIKIDATA:Q2278983'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['PANTHER.FAMILY',
                         'HGNC.FAMILY',
                         'FB',
                         'interpro',
                         'CATH',
                         'CDD',
                         'HAMAP',
                         'PFAM',
                         'PIRSF',
                         'PRINTS',
                         'PRODOM',
                         'PROSITE',
                         'SMART',
                         'SUPFAM',
                         'TIGRFAM',
                         'CATH.SUPERFAMILY',
                         'RFAM',
                         'KEGG.ORTHOLOGY',
                         'EGGNOG',
                         'COG'],
         'in_subset': ['model_organism_database'],
         'mixins': ['gene grouping mixin', 'chemical entity or gene or gene product'],
         'narrow_mappings': ['SIO:001380', 'NCIT:C20130', 'WIKIDATA:Q417841']})

    has_gene_or_gene_product: Optional[List[str]] = Field(None, description="""connects an entity with one or more gene or gene products""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene_or_gene_product',
         'domain': 'named thing',
         'domain_of': ['gene grouping mixin'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneFamily","biolink:GeneFamily"]] = Field(["biolink:GeneFamily"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Zygosity(Attribute):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['GENO:0000133'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Zygosity","biolink:Zygosity"]] = Field(["biolink:Zygosity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Genotype(GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    An information content entity that describes a genome by specifying the total variation in genomic sequence and/or gene expression, relative to some established background
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'comments': ['Consider renaming as genotypic entity'],
         'exact_mappings': ['GENO:0000536', 'SIO:001079'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['ZFIN', 'FB'],
         'in_subset': ['model_organism_database'],
         'mixins': ['physical essence', 'genomic entity', 'ontology class']})

    has_zygosity: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_zygosity',
         'domain': 'nucleic acid entity',
         'domain_of': ['genotype'],
         'is_a': 'node property'} })
    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Genotype","biolink:Genotype"]] = Field(["biolink:Genotype"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Haplotype(GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    A set of zero or more Alleles on a single instance of a Sequence[VMC]
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['GENO:0000871', 'SO:0001024', 'VMC:Haplotype'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['genomic entity', 'physical essence', 'ontology class']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Haplotype","biolink:Haplotype"]] = Field(["biolink:Haplotype"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SequenceVariant(GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    A sequence_variant is a non exact copy of a sequence_feature or genome exhibiting one or more sequence_alteration.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['allele'],
         'alt_descriptions': {'AGR': {'description': 'An entity that describes a '
                                                     'single affected, endogenous '
                                                     'allele. These can be of any type '
                                                     'that matches that definition',
                                      'source': 'AGR'},
                              'VMC': {'description': 'A contiguous change at a '
                                                     'Location',
                                      'source': 'VMC'}},
         'close_mappings': ['dcid:Allele',
                            'SO:0001060',
                            'VMC:Allele',
                            'GENO:0000002',
                            'SIO:010277',
                            'SO:0001060'],
         'comments': ['This class is for modeling the specific state at a locus. A '
                      'single DBSNP rs ID could correspond to more than one sequence '
                      'variants (e.g CIViC:1252 and CIViC:1253, two distinct BRCA2 '
                      'alleles for rs28897743)'],
         'exact_mappings': ['WIKIDATA:Q15304597'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['CAID',
                         'CLINVAR',
                         'WIKIDATA',
                         'DBSNP',
                         'MGI',
                         'ZFIN',
                         'FB',
                         'RGD',
                         'AGRKB',
                         'SPDI',
                         'WB',
                         'WormBase',
                         'PHARMGKB.VARIANT'],
         'in_subset': ['model_organism_database'],
         'local_names': {'agr': {'local_name_source': 'agr',
                                 'local_name_value': 'allele'}},
         'mixins': ['genomic entity', 'physical essence', 'ontology class'],
         'slot_usage': {'has biological sequence': {'description': 'The state of the '
                                                                   'sequence w.r.t a '
                                                                   'reference sequence',
                                                    'name': 'has biological sequence'},
                        'has gene': {'description': 'Each allele can be associated '
                                                    'with any number of genes',
                                     'multivalued': True,
                                     'name': 'has gene'},
                        'id': {'examples': [{'description': 'ti282a allele from ZFIN',
                                             'value': 'ZFIN:ZDB-ALT-980203-1091'},
                                            {'description': 'NM_007294.3(BRCA1):c.2521C>T '
                                                            '(p.Arg841Trp)',
                                             'value': 'CLINVAR:17681'}],
                               'name': 'id'}}})

    has_gene: Optional[List[str]] = Field(None, description="""Each allele can be associated with any number of genes""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene',
         'domain': 'named thing',
         'domain_of': ['sequence variant'],
         'is_a': 'has gene or gene product'} })
    has_biological_sequence: Optional[str] = Field(None, description="""The state of the sequence w.r.t a reference sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'examples': [{'description': 'ti282a allele from ZFIN',
                       'value': 'ZFIN:ZDB-ALT-980203-1091'},
                      {'description': 'NM_007294.3(BRCA1):c.2521C>T (p.Arg841Trp)',
                       'value': 'CLINVAR:17681'}],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SequenceVariant","biolink:SequenceVariant"]] = Field(["biolink:SequenceVariant"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Snv(SequenceVariant):
    """
    SNVs are single nucleotide positions in genomic DNA at which different sequence alternatives exist
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['single nucleotide variant',
                     'single nucleotide polymorphism',
                     'snp'],
         'exact_mappings': ['SO:0001483'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    has_gene: Optional[List[str]] = Field(None, description="""Each allele can be associated with any number of genes""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene',
         'domain': 'named thing',
         'domain_of': ['sequence variant'],
         'is_a': 'has gene or gene product'} })
    has_biological_sequence: Optional[str] = Field(None, description="""The state of the sequence w.r.t a reference sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'examples': [{'description': 'ti282a allele from ZFIN',
                       'value': 'ZFIN:ZDB-ALT-980203-1091'},
                      {'description': 'NM_007294.3(BRCA1):c.2521C>T (p.Arg841Trp)',
                       'value': 'CLINVAR:17681'}],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Snv","biolink:Snv"]] = Field(["biolink:Snv"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ReagentTargetedGene(GenomicEntity, BiologicalEntity, PhysicalEssence, OntologyClass):
    """
    A gene altered in its expression level in the context of some experiment as a result of being targeted by gene-knockdown reagent(s) such as a morpholino or RNAi.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['sequence targeting reagent'],
         'exact_mappings': ['GENO:0000504'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['model_organism_database'],
         'mixins': ['genomic entity', 'physical essence', 'ontology class']})

    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ReagentTargetedGene","biolink:ReagentTargetedGene"]] = Field(["biolink:ReagentTargetedGene"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalAttribute(Attribute):
    """
    Attributes relating to a clinical manifestation
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['STY:T201'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalAttribute","biolink:ClinicalAttribute"]] = Field(["biolink:ClinicalAttribute"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalMeasurement(ClinicalAttribute):
    """
    A clinical measurement is a special kind of attribute which results from a laboratory observation from a subject individual or sample. Measurements can be connected to their subject by the 'has attribute' slot.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['EFO:0001444'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'has attribute type': {'multivalued': False,
                                               'name': 'has attribute type',
                                               'required': True,
                                               'values_from': ['EFO', 'LOINC']}}})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type'],
         'values_from': ['EFO', 'LOINC']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalMeasurement","biolink:ClinicalMeasurement"]] = Field(["biolink:ClinicalMeasurement"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalModifier(ClinicalAttribute):
    """
    Used to characterize and specify the phenotypic abnormalities defined in the phenotypic abnormality sub-ontology, with respect to severity, laterality, and other aspects
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalModifier","biolink:ClinicalModifier"]] = Field(["biolink:ClinicalModifier"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalCourse(ClinicalAttribute):
    """
    The course a disease typically takes from its onset, progression in time, and eventual resolution or death of the affected individual
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['HP:0031797'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalCourse","biolink:ClinicalCourse"]] = Field(["biolink:ClinicalCourse"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Onset(ClinicalCourse):
    """
    The age group in which (disease) symptom manifestations appear.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['HP:0003674'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'notes': ['This class is in Biolink to support HP ontology annotations which '
                   'use "onset" (with terms from HP)  as an annotation on a disease to '
                   'phenotypic feature association.  This should be the primary use '
                   'case for this class.']})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Onset","biolink:Onset"]] = Field(["biolink:Onset"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalEntity(NamedThing):
    """
    Any entity or process that exists in the clinical domain and outside the biological realm. Diseases are placed under biological entities
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalEntity","biolink:ClinicalEntity"]] = Field(["biolink:ClinicalEntity"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalTrial(ClinicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalTrial","biolink:ClinicalTrial"]] = Field(["biolink:ClinicalTrial"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalIntervention(ClinicalEntity):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalIntervention","biolink:ClinicalIntervention"]] = Field(["biolink:ClinicalIntervention"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ClinicalFinding(PhenotypicFeature):
    """
    this category is currently considered broad enough to tag clinical lab measurements and other biological attributes taken as 'clinical traits' with some statistical score, for example, a p value in genetic associations.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'id_prefixes': ['LOINC', 'NCIT', 'EFO'],
         'slot_usage': {'has attribute': {'name': 'has attribute',
                                          'range': 'clinical attribute'}}})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ClinicalFinding","biolink:ClinicalFinding"]] = Field(["biolink:ClinicalFinding"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Hospitalization(ClinicalIntervention):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SNOMEDCT:32485007', 'WIKIDATA:Q3140971'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Hospitalization","biolink:Hospitalization"]] = Field(["biolink:Hospitalization"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SocioeconomicAttribute(Attribute):
    """
    Attributes relating to a socioeconomic manifestation
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SocioeconomicAttribute","biolink:SocioeconomicAttribute"]] = Field(["biolink:SocioeconomicAttribute"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Case(IndividualOrganism, SubjectOfInvestigation):
    """
    An individual (human) organism that has a patient role in some clinical context.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['patient', 'proband'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Case","biolink:Case"]] = Field(["biolink:Case"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Cohort(StudyPopulation, SubjectOfInvestigation):
    """
    A group of people banded together or treated as a group who share common characteristics. A cohort 'study' is a particular form of longitudinal study that samples a cohort, performing a cross-section at intervals through time.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['WIKIDATA:Q1303415'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['subject of investigation'],
         'narrow_mappings': ['STY:T097', 'STY:T099', 'STY:T100', 'STY:T101']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Cohort","biolink:Cohort"]] = Field(["biolink:Cohort"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ExposureEvent(OntologyClass):
    """
    A (possibly time bounded) incidence of a feature of the environment of an organism that influences one or more phenotypic features of that organism, potentially mediated by genes
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['exposure', 'experimental condition'],
         'exact_mappings': ['XCO:0000000'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['model_organism_database'],
         'mixin': True})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })


class GenomicBackgroundExposure(ExposureEvent, GeneGroupingMixin, GenomicEntity, ThingWithTaxon, PhysicalEssence, Attribute, OntologyClass):
    """
    A genomic background exposure is where an individual's specific genomic background of genes, sequence variants or other pre-existing genomic conditions constitute a kind of 'exposure' to the organism, leading to or influencing an outcome.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event',
                    'gene grouping mixin',
                    'physical essence',
                    'genomic entity',
                    'thing with taxon',
                    'ontology class']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    has_gene_or_gene_product: Optional[List[str]] = Field(None, description="""connects an entity with one or more gene or gene products""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene_or_gene_product',
         'domain': 'named thing',
         'domain_of': ['gene grouping mixin'],
         'is_a': 'node property'} })
    has_biological_sequence: Optional[str] = Field(None, description="""connects a genomic feature to its sequence""", json_schema_extra = { "linkml_meta": {'alias': 'has_biological_sequence',
         'domain': 'named thing',
         'domain_of': ['genomic entity', 'epigenomic entity'],
         'is_a': 'node property'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenomicBackgroundExposure","biolink:GenomicBackgroundExposure"]] = Field(["biolink:GenomicBackgroundExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PathologicalEntityMixin(ConfiguredBaseModel):
    """
    A pathological (abnormal) structure or process.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['MPATH:0'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'narrow_mappings': ['HP:0000118']})

    pass


class PathologicalProcess(PathologicalEntityMixin, BiologicalProcess):
    """
    A biologic function or a process having an abnormal or deleterious effect at the subcellular, cellular, multicellular, or organismal level.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['OBI:1110122', 'NCIT:C16956', 'MPATH:596'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['pathological entity mixin'],
         'narrow_mappings': ['NCIT:C19151', 'EFO:0009708', 'STY:T046', 'STY:T037']})

    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    has_input: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an input into the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_input',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has output'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002233', 'SEMMEDDB:USES'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['LOINC:has_fragments_for_synonyms',
                             'LOINC:has_system',
                             'PathWhiz:has_left_element',
                             'RO:0002590',
                             'RO:0004009',
                             'SNOMED:has_finding_method',
                             'SNOMED:has_precondition',
                             'SNOMED:has_specimen_source_identity',
                             'SNOMED:has_specimen_substance',
                             'SNOMED:uses_access_device',
                             'SNOMED:uses_device',
                             'SNOMED:uses_energy',
                             'SNOMED:uses_substance']} })
    has_output: Optional[List[str]] = Field(None, description="""holds between a process and a continuant, where the continuant is an output of the process""", json_schema_extra = { "linkml_meta": {'alias': 'has_output',
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True},
                         'opposite_of': {'tag': 'opposite_of', 'value': 'has input'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002234'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'has participant',
         'narrow_mappings': ['NCIT:R31',
                             'OBI:0000299',
                             'PathWhiz:has_right_element',
                             'RO:0002296',
                             'RO:0002297',
                             'RO:0002298',
                             'RO:0002299',
                             'RO:0002588',
                             'RO:0004008']} })
    enabled_by: Optional[List[str]] = Field(None, description="""holds between a process and a physical entity, where the physical entity executes the process""", json_schema_extra = { "linkml_meta": {'alias': 'enabled_by',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'prevented by'}},
         'domain': 'biological process or activity',
         'domain_of': ['biological process or activity'],
         'exact_mappings': ['RO:0002333'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'inverse': 'enables',
         'is_a': 'has participant'} })
    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PathologicalProcess","biolink:PathologicalProcess"]] = Field(["biolink:PathologicalProcess"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PathologicalProcessExposure(ExposureEvent, Attribute):
    """
    A pathological process, when viewed as an exposure, representing a precondition, leading to or influencing an outcome, e.g. autoimmunity leading to disease.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PathologicalProcessExposure","biolink:PathologicalProcessExposure"]] = Field(["biolink:PathologicalProcessExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PathologicalAnatomicalStructure(PathologicalEntityMixin, AnatomicalEntity):
    """
    An anatomical structure with the potential of have an abnormal or deleterious effect at the subcellular, cellular, multicellular, or organismal level.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['MPATH:603'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['pathological entity mixin']})

    in_taxon: Optional[List[str]] = Field(None, description="""connects an entity to its taxonomic classification. Only certain kinds of entities can be taxonomically classified; see 'thing with taxon'""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon',
         'aliases': ['instance of',
                     'is organism source of gene product',
                     'organism has gene',
                     'gene found in organism',
                     'gene product has organism source'],
         'annotations': {'canonical_predicate': {'tag': 'canonical_predicate',
                                                 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['RO:0002162', 'WIKIDATA_PROPERTY:P703'],
         'in_subset': ['translator_minimal'],
         'inherited': True,
         'is_a': 'related to at instance level',
         'narrow_mappings': ['RO:0002160']} })
    in_taxon_label: Optional[str] = Field(None, description="""The human readable scientific name for the taxon of the entity.""", json_schema_extra = { "linkml_meta": {'alias': 'in_taxon_label',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'thing with taxon',
         'domain_of': ['thing with taxon'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P225'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property'} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PathologicalAnatomicalStructure","biolink:PathologicalAnatomicalStructure"]] = Field(["biolink:PathologicalAnatomicalStructure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""may often be an organism attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PathologicalAnatomicalExposure(ExposureEvent, Attribute):
    """
    An abnormal anatomical structure, when viewed as an exposure, representing an precondition, leading to or influencing an outcome, e.g. thrombosis leading to an ischemic disease outcome.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PathologicalAnatomicalExposure","biolink:PathologicalAnatomicalExposure"]] = Field(["biolink:PathologicalAnatomicalExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DiseaseOrPhenotypicFeatureExposure(PathologicalEntityMixin, ExposureEvent, Attribute):
    """
    A disease or phenotypic feature state, when viewed as an exposure, represents an precondition, leading to or influencing an outcome, e.g. HIV predisposing an individual to infections; a relative deficiency of skin pigmentation predisposing an individual to skin cancer.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event', 'pathological entity mixin']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiseaseOrPhenotypicFeatureExposure","biolink:DiseaseOrPhenotypicFeatureExposure"]] = Field(["biolink:DiseaseOrPhenotypicFeatureExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalExposure(ExposureEvent, Attribute):
    """
    A chemical exposure is an intake of a particular chemical entity.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['ECTO:9000000', 'SIO:001399'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalExposure","biolink:ChemicalExposure"]] = Field(["biolink:ChemicalExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ComplexChemicalExposure(Attribute):
    """
    A complex chemical exposure is an intake of a chemical mixture (e.g. gasoline), other than a drug.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ComplexChemicalExposure","biolink:ComplexChemicalExposure"]] = Field(["biolink:ComplexChemicalExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DrugExposure(ChemicalExposure, ExposureEvent):
    """
    A drug exposure is an intake of a particular drug.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['drug intake', 'drug dose', 'medication intake'],
         'broad_mappings': ['SIO:001005'],
         'exact_mappings': ['ECTO:0000509'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DrugExposure","biolink:DrugExposure"]] = Field(["biolink:DrugExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DrugToGeneInteractionExposure(DrugExposure, GeneGroupingMixin):
    """
    drug to gene interaction exposure is a drug exposure is where the interactions of the drug with specific genes are known to constitute an 'exposure' to the organism, leading to or influencing an outcome.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene grouping mixin']})

    has_gene_or_gene_product: Optional[List[str]] = Field(None, description="""connects an entity with one or more gene or gene products""", json_schema_extra = { "linkml_meta": {'alias': 'has_gene_or_gene_product',
         'domain': 'named thing',
         'domain_of': ['gene grouping mixin'],
         'is_a': 'node property'} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DrugToGeneInteractionExposure","biolink:DrugToGeneInteractionExposure"]] = Field(["biolink:DrugToGeneInteractionExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Treatment(ExposureEvent, NamedThing, ChemicalOrDrugOrTreatment):
    """
    A treatment is targeted at a disease or phenotype and may involve multiple drug 'exposures', medical devices and/or procedures
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['medical action', 'medical intervention'],
         'broad_mappings': ['MAXO:0000058'],
         'exact_mappings': ['OGMS:0000090', 'SIO:001398'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event', 'chemical or drug or treatment']})

    has_drug: Optional[List[str]] = Field(None, description="""connects an entity to one or more drugs""", json_schema_extra = { "linkml_meta": {'alias': 'has_drug',
         'domain': 'named thing',
         'domain_of': ['treatment'],
         'is_a': 'node property'} })
    has_device: Optional[List[str]] = Field(None, description="""connects an entity to one or more (medical) devices""", json_schema_extra = { "linkml_meta": {'alias': 'has_device',
         'domain': 'named thing',
         'domain_of': ['treatment'],
         'is_a': 'node property'} })
    has_procedure: Optional[List[str]] = Field(None, description="""connects an entity to one or more (medical) procedures""", json_schema_extra = { "linkml_meta": {'alias': 'has_procedure',
         'domain': 'named thing',
         'domain_of': ['treatment'],
         'is_a': 'node property'} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Treatment","biolink:Treatment"]] = Field(["biolink:Treatment"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class BioticExposure(ExposureEvent, Attribute):
    """
    An external biotic exposure is an intake of (sometimes pathological) biological organisms (including viruses).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['viral exposure', 'bacterial exposure'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BioticExposure","biolink:BioticExposure"]] = Field(["biolink:BioticExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EnvironmentalExposure(ExposureEvent, Attribute):
    """
    A environmental exposure is a factor relating to abiotic processes in the environment including sunlight (UV-B), atmospheric (heat, cold, general pollution) and water-born contaminants.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EnvironmentalExposure","biolink:EnvironmentalExposure"]] = Field(["biolink:EnvironmentalExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeographicExposure(EnvironmentalExposure, ExposureEvent):
    """
    A geographic exposure is a factor relating to geographic proximity to some impactful entity.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['dcid:GeologicalEvent'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event'],
         'narrow_mappings': ['dcid:IceStoremEvent',
                             'dcid:LakeEffectSnowEvent',
                             'dcid:LandslideEvent',
                             'dcid:MarineDenseFogEvent',
                             'dcid:MarineLighteningEvent',
                             'dcid:MarineStrongWindEvent',
                             'dcid:MarineThunderstormWindEvent',
                             'dcid:StormEvent',
                             'dcid:StormSurgeTideEvent',
                             'dcid:StrongWindEvent',
                             'dcid:ThunderstormWindEvent',
                             'dcid:TornadoEvent',
                             'dcid:TropicalDepressionEvent',
                             'dcid:WinterStoremEvent']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeographicExposure","biolink:GeographicExposure"]] = Field(["biolink:GeographicExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class BehavioralExposure(ExposureEvent, Attribute):
    """
    A behavioral exposure is a factor relating to behavior impacting an individual.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event']})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BehavioralExposure","biolink:BehavioralExposure"]] = Field(["biolink:BehavioralExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SocioeconomicExposure(ExposureEvent, Attribute):
    """
    A socioeconomic exposure is a factor relating to social and financial status of an affected individual (e.g. poverty).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['exposure event'],
         'slot_usage': {'has attribute': {'name': 'has attribute',
                                          'range': 'socioeconomic attribute',
                                          'required': True}}})

    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    name: Optional[str] = Field(None, description="""The human-readable 'attribute name' can be set to a string which reflects its context of interpretation, e.g. SEPIO evidence/provenance/confidence annotation or it can default to the name associated with the 'has attribute type' slot ontology term.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    has_attribute_type: str = Field(..., description="""connects an attribute to a class that describes it""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute_type',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples'],
         'narrow_mappings': ['LOINC:has_modality_type', 'LOINC:has_view_type']} })
    has_quantitative_value: Optional[List[QuantityValue]] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_quantitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute', 'chemical exposure'],
         'exact_mappings': ['qud:quantityValue'],
         'in_subset': ['samples'],
         'narrow_mappings': ['SNOMED:has_concentration_strength_numerator_value',
                             'SNOMED:has_presentation_strength_denominator_value',
                             'SNOMED:has_presentation_strength_numerator_value']} })
    has_qualitative_value: Optional[str] = Field(None, description="""connects an attribute to a value""", json_schema_extra = { "linkml_meta": {'alias': 'has_qualitative_value',
         'domain': 'attribute',
         'domain_of': ['attribute'],
         'in_subset': ['samples']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    provided_by: Optional[List[str]] = Field(None, description="""The value in this node property represents the knowledge provider that created or assembled the node and all of its attributes.  Used internally to represent how a particular node made its way into a knowledge provider or graph.""", json_schema_extra = { "linkml_meta": {'alias': 'provided_by',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    xref: Optional[List[str]] = Field(None, description="""A database cross reference or alternative identifier for a NamedThing or edge between two NamedThings.  This property should point to a database record or webpage that supports the existence of the edge, or gives more detail about the edge. This property can be used on a node or edge to provide multiple URIs or CURIE cross references.""", json_schema_extra = { "linkml_meta": {'alias': 'xref',
         'aliases': ['dbxref', 'Dbxref', 'DbXref', 'record_url', 'source_record_urls'],
         'domain': 'named thing',
         'domain_of': ['named thing',
                       'publication',
                       'retrieval source',
                       'gene',
                       'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Dbxref', 'gpi:DB_Xrefs']} })
    full_name: Optional[str] = Field(None, description="""a long-form human readable name for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'full_name',
         'domain': 'named thing',
         'domain_of': ['named thing'],
         'is_a': 'node property'} })
    synonym: Optional[List[str]] = Field(None, description="""Alternate human-readable names for a thing""", json_schema_extra = { "linkml_meta": {'alias': 'synonym',
         'aliases': ['alias'],
         'domain': 'named thing',
         'domain_of': ['named thing', 'gene product mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'node property',
         'narrow_mappings': ['skos:altLabel',
                             'gff3:Alias',
                             'AGRKB:synonyms',
                             'gpi:DB_Object_Synonyms',
                             'HANCESTRO:0330',
                             'IAO:0000136',
                             'RXNORM:has_tradename']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SocioeconomicExposure","biolink:SocioeconomicExposure"]] = Field(["biolink:SocioeconomicExposure"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: List[str] = Field(..., description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class Outcome(ConfiguredBaseModel):
    """
    An entity that has the role of being the consequence of an exposure event. This is an abstract mixin grouping of various categories of possible biological or non-biological (e.g. clinical) outcomes.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    pass


class PathologicalProcessOutcome(Outcome):
    """
    An outcome resulting from an exposure event which is the manifestation of a pathological process.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class PathologicalAnatomicalOutcome(Outcome):
    """
    An outcome resulting from an exposure event which is the manifestation of an abnormal anatomical structure.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class DiseaseOrPhenotypicFeatureOutcome(Outcome):
    """
    Physiological outcomes resulting from an exposure event which is the manifestation of a disease or other characteristic phenotype.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class BehavioralOutcome(Outcome):
    """
    An outcome resulting from an exposure event which is the manifestation of human behavior.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class HospitalizationOutcome(Outcome):
    """
    An outcome resulting from an exposure event which is the increased manifestation of acute (e.g. emergency room visit) or chronic (inpatient) hospitalization.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class MortalityOutcome(Outcome):
    """
    An outcome of death from resulting from an exposure event.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class EpidemiologicalOutcome(Outcome):
    """
    An epidemiological outcome, such as societal disease burden, resulting from an exposure event.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['outcome'],
         'related_mappings': ['NCIT:C19291']})

    pass


class SocioeconomicOutcome(Outcome):
    """
    An general social or economic outcome, such as healthcare costs, utilization, etc., resulting from an exposure event
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixins': ['outcome']})

    pass


class Association(Entity):
    """
    A typed association between two entities, supported by evidence
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'comments': ['This is roughly the model used by biolink and ontobio at the '
                      'moment'],
         'exact_mappings': ['OBAN:association', 'rdf:Statement', 'owl:Axiom'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'category': {'name': 'category',
                                     'range': 'uriorcurie',
                                     'required': False},
                        'type': {'description': 'rdf:type of biolink:Association '
                                                'should be fixed at rdf:Statement',
                                 'name': 'type'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/Association","biolink:Association"]] = Field(["biolink:Association"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalEntityAssessesNamedThingAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'named thing'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'assesses'},
                        'subject': {'name': 'subject', 'range': 'chemical entity'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'assesses'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalEntityAssessesNamedThingAssociation","biolink:ChemicalEntityAssessesNamedThingAssociation"]] = Field(["biolink:ChemicalEntityAssessesNamedThingAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ContributorAssociation(Association):
    """
    Any association between an entity (such as a publication) and various agents that contribute to its realisation
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'agent helping to realise the given '
                                                  'entity (e.g. such as a publication)',
                                   'name': 'object',
                                   'range': 'agent'},
                        'predicate': {'description': 'generally one of the predicate '
                                                     "values 'provider', 'publisher', "
                                                     "'editor' or 'author'",
                                      'name': 'predicate',
                                      'subproperty_of': 'contributor'},
                        'qualifiers': {'description': 'this field can be used to '
                                                      'annotate special '
                                                      'characteristics of an agent '
                                                      'relationship, such as the fact '
                                                      'that a given author agent of a '
                                                      'publication is the '
                                                      "'corresponding author'",
                                       'name': 'qualifiers'},
                        'subject': {'description': 'information content entity which '
                                                   'an agent has helped realise',
                                    'name': 'subject',
                                    'range': 'information content entity'}}})

    subject: str = Field(..., description="""information content entity which an agent has helped realise""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""generally one of the predicate values 'provider', 'publisher', 'editor' or 'author'""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'contributor'} })
    object: str = Field(..., description="""agent helping to realise the given entity (e.g. such as a publication)""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""this field can be used to annotate special characteristics of an agent relationship, such as the fact that a given author agent of a publication is the 'corresponding author'""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ContributorAssociation","biolink:ContributorAssociation"]] = Field(["biolink:ContributorAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenotypeToGenotypePartAssociation(Association):
    """
    Any association between one genotype and a genotypic entity that is a sub-component of it
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'child genotype',
                                   'name': 'object',
                                   'range': 'genotype'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has variant part'},
                        'subject': {'description': 'parent genotype',
                                    'name': 'subject',
                                    'range': 'genotype'}}})

    subject: str = Field(..., description="""parent genotype""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has variant part'} })
    object: str = Field(..., description="""child genotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypeToGenotypePartAssociation","biolink:GenotypeToGenotypePartAssociation"]] = Field(["biolink:GenotypeToGenotypePartAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenotypeToGeneAssociation(Association):
    """
    Any association between a genotype and a gene. The genotype have have multiple variants in that gene or a single one. There is no assumption of cardinality
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'gene implicated in genotype',
                                   'name': 'object',
                                   'range': 'gene'},
                        'predicate': {'description': 'the relationship type used to '
                                                     'connect genotype to gene',
                                      'name': 'predicate'},
                        'subject': {'description': 'parent genotype',
                                    'name': 'subject',
                                    'range': 'genotype'}}})

    subject: str = Field(..., description="""parent genotype""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""the relationship type used to connect genotype to gene""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""gene implicated in genotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypeToGeneAssociation","biolink:GenotypeToGeneAssociation"]] = Field(["biolink:GenotypeToGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenotypeToVariantAssociation(Association):
    """
    Any association between a genotype and a sequence variant.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'gene implicated in genotype',
                                   'name': 'object',
                                   'range': 'sequence variant'},
                        'predicate': {'description': 'the relationship type used to '
                                                     'connect genotype to gene',
                                      'name': 'predicate'},
                        'subject': {'description': 'parent genotype',
                                    'name': 'subject',
                                    'range': 'genotype'}}})

    subject: str = Field(..., description="""parent genotype""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""the relationship type used to connect genotype to gene""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""gene implicated in genotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypeToVariantAssociation","biolink:GenotypeToVariantAssociation"]] = Field(["biolink:GenotypeToVariantAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneToGeneAssociation(Association):
    """
    abstract parent class for different kinds of gene-gene or gene product to gene product relationships. Includes homology and interaction.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'aliases': ['molecular or genetic interaction'],
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'the object gene in the association. '
                                                  'If the relation is symmetric, '
                                                  'subject vs object is arbitrary. We '
                                                  'allow a gene product to stand as a '
                                                  'proxy for the gene or vice versa.',
                                   'name': 'object',
                                   'range': 'gene or gene product'},
                        'subject': {'description': 'the subject gene in the '
                                                   'association. If the relation is '
                                                   'symmetric, subject vs object is '
                                                   'arbitrary. We allow a gene product '
                                                   'to stand as a proxy for the gene '
                                                   'or vice versa.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""the subject gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the object gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToGeneAssociation","biolink:GeneToGeneAssociation"]] = Field(["biolink:GeneToGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneToGeneHomologyAssociation(GeneToGeneAssociation):
    """
    A homology association between two genes. May be orthology (in which case the species of subject and object should differ) or paralogy (in which case the species may be the same)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'gene or gene product'},
                        'predicate': {'description': 'homology relationship type',
                                      'name': 'predicate',
                                      'subproperty_of': 'homologous to',
                                      'symmetric': True},
                        'subject': {'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""the subject gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""homology relationship type""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'homologous to',
         'symmetric': True} })
    object: str = Field(..., description="""the object gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToGeneHomologyAssociation","biolink:GeneToGeneHomologyAssociation"]] = Field(["biolink:GeneToGeneHomologyAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneToGeneFamilyAssociation(Association):
    """
    Set membership of a gene in a family of genes related by common evolutionary ancestry usually inferred by sequence comparisons. The genes in a given family generally share common sequence motifs which generally map onto shared gene product structure-function relationships.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'gene family'},
                        'predicate': {'description': 'membership of the gene in the '
                                                     'given gene family.',
                                      'name': 'predicate',
                                      'subproperty_of': 'member of',
                                      'symmetric': False},
                        'subject': {'name': 'subject', 'range': 'gene'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""membership of the gene in the given gene family.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'member of',
         'symmetric': False} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToGeneFamilyAssociation","biolink:GeneToGeneFamilyAssociation"]] = Field(["biolink:GeneToGeneFamilyAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneExpressionMixin(ConfiguredBaseModel):
    """
    Observed gene expression intensity, context (site, stage) and associated phenotypic status within which the expression occurs.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'quantifier qualifier': {'description': 'Optional quantitative '
                                                                'value indicating '
                                                                'degree of expression.',
                                                 'name': 'quantifier qualifier'}}})

    quantifier_qualifier: Optional[str] = Field(None, description="""Optional quantitative value indicating degree of expression.""", json_schema_extra = { "linkml_meta": {'alias': 'quantifier_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'is_a': 'association slot',
         'narrow_mappings': ['LOINC:analyzes',
                             'LOINC:measured_by',
                             'LOINC:property_of',
                             'SEMMEDDB:MEASURES',
                             'UMLS:measures']} })
    expression_site: Optional[str] = Field(None, description="""location in which gene or protein expression takes place. May be cell, tissue, or organ.""", json_schema_extra = { "linkml_meta": {'alias': 'expression_site',
         'domain': 'association',
         'domain_of': ['gene expression mixin'],
         'examples': [{'description': 'cerebellum', 'value': 'UBERON:0002037'}],
         'is_a': 'association slot'} })
    stage_qualifier: Optional[str] = Field(None, description="""stage during which gene or protein expression of takes place.""", json_schema_extra = { "linkml_meta": {'alias': 'stage_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'examples': [{'description': 'larval stage', 'value': 'UBERON:0000069'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    phenotypic_state: Optional[str] = Field(None, description="""in experiments (e.g. gene expression) assaying diseased or unhealthy tissue, the phenotypic state can be put here, e.g. MONDO ID. For healthy tissues, use XXX.""", json_schema_extra = { "linkml_meta": {'alias': 'phenotypic_state',
         'domain': 'association',
         'domain_of': ['gene expression mixin'],
         'is_a': 'association slot'} })


class GeneToGeneCoexpressionAssociation(GeneExpressionMixin, GeneToGeneAssociation):
    """
    Indicates that two genes are co-expressed, generally under the same conditions.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene expression mixin'],
         'slot_usage': {'predicate': {'name': 'predicate',
                                      'subproperty_of': 'coexpressed with',
                                      'symmetric': True}}})

    quantifier_qualifier: Optional[str] = Field(None, description="""Optional quantitative value indicating degree of expression.""", json_schema_extra = { "linkml_meta": {'alias': 'quantifier_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'is_a': 'association slot',
         'narrow_mappings': ['LOINC:analyzes',
                             'LOINC:measured_by',
                             'LOINC:property_of',
                             'SEMMEDDB:MEASURES',
                             'UMLS:measures']} })
    expression_site: Optional[str] = Field(None, description="""location in which gene or protein expression takes place. May be cell, tissue, or organ.""", json_schema_extra = { "linkml_meta": {'alias': 'expression_site',
         'domain': 'association',
         'domain_of': ['gene expression mixin'],
         'examples': [{'description': 'cerebellum', 'value': 'UBERON:0002037'}],
         'is_a': 'association slot'} })
    stage_qualifier: Optional[str] = Field(None, description="""stage during which gene or protein expression of takes place.""", json_schema_extra = { "linkml_meta": {'alias': 'stage_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'examples': [{'description': 'larval stage', 'value': 'UBERON:0000069'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    phenotypic_state: Optional[str] = Field(None, description="""in experiments (e.g. gene expression) assaying diseased or unhealthy tissue, the phenotypic state can be put here, e.g. MONDO ID. For healthy tissues, use XXX.""", json_schema_extra = { "linkml_meta": {'alias': 'phenotypic_state',
         'domain': 'association',
         'domain_of': ['gene expression mixin'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""the subject gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'coexpressed with',
         'symmetric': True} })
    object: str = Field(..., description="""the object gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToGeneCoexpressionAssociation","biolink:GeneToGeneCoexpressionAssociation"]] = Field(["biolink:GeneToGeneCoexpressionAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PairwiseGeneToGeneInteraction(GeneToGeneAssociation):
    """
    An interaction between two genes or two gene products. May be physical (e.g. protein binding) or genetic (between genes). May be symmetric (e.g. protein interaction) or directed (e.g. phosphorylation)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'narrow_mappings': ['dcid:ProteinProteinInteraction'],
         'slot_usage': {'predicate': {'description': 'interaction relationship type',
                                      'name': 'predicate',
                                      'subproperty_of': 'interacts with',
                                      'symmetric': True}}})

    subject: str = Field(..., description="""the subject gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""interaction relationship type""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'interacts with',
         'symmetric': True} })
    object: str = Field(..., description="""the object gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PairwiseGeneToGeneInteraction","biolink:PairwiseGeneToGeneInteraction"]] = Field(["biolink:PairwiseGeneToGeneInteraction"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PairwiseMolecularInteraction(PairwiseGeneToGeneInteraction):
    """
    An interaction at the molecular level between two physical entities
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'id': {'description': 'identifier for the interaction. This '
                                              'may come from an interaction database '
                                              'such as IMEX.',
                               'examples': [{'value': 'WB:WBInteraction000538741'}],
                               'name': 'id',
                               'values_from': ['IMEX', 'BioGRID']},
                        'object': {'name': 'object', 'range': 'molecular entity'},
                        'predicate': {'description': 'interaction relationship type',
                                      'examples': [{'description': 'the subject '
                                                                   'molecular '
                                                                   'phosphorylates the '
                                                                   'object molecule',
                                                    'value': 'RO:0002447'}],
                                      'name': 'predicate',
                                      'subproperty_of': 'interacts with'},
                        'subject': {'name': 'subject', 'range': 'molecular entity'}}})

    interacting_molecules_category: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'interacting_molecules_category',
         'domain': 'association',
         'domain_of': ['pairwise molecular interaction'],
         'exact_mappings': ['MI:1046'],
         'examples': [{'description': 'smallmolecule-protein', 'value': 'MI:1048'}],
         'is_a': 'association slot',
         'values_from': ['MI']} })
    subject: str = Field(..., description="""the subject gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""interaction relationship type""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'examples': [{'description': 'the subject molecular phosphorylates the object '
                                      'molecule',
                       'value': 'RO:0002447'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'interacts with',
         'symmetric': True} })
    object: str = Field(..., description="""the object gene in the association. If the relation is symmetric, subject vs object is arbitrary. We allow a gene product to stand as a proxy for the gene or vice versa.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""identifier for the interaction. This may come from an interaction database such as IMEX.""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'examples': [{'value': 'WB:WBInteraction000538741'}],
         'in_subset': ['translator_minimal'],
         'values_from': ['IMEX', 'BioGRID']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PairwiseMolecularInteraction","biolink:PairwiseMolecularInteraction"]] = Field(["biolink:PairwiseMolecularInteraction"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class CellLineToEntityAssociationMixin(ConfiguredBaseModel):
    """
    An relationship between a cell line and another entity
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'name': 'subject', 'range': 'cell line'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class ChemicalEntityToEntityAssociationMixin(ConfiguredBaseModel):
    """
    An interaction between a chemical entity and another entity
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'the chemical entity that is an '
                                                   'interactor',
                                    'name': 'subject',
                                    'range': 'chemical entity or gene or gene '
                                             'product'}}})

    subject: str = Field(..., description="""the chemical entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class DrugToEntityAssociationMixin(ChemicalEntityToEntityAssociationMixin):
    """
    An interaction between a drug and another entity
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'the drug that is an interactor',
                                    'name': 'subject',
                                    'range': 'drug'}}})

    subject: str = Field(..., description="""the drug that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class ChemicalToEntityAssociationMixin(ChemicalEntityToEntityAssociationMixin):
    """
    An interaction between a chemical entity and another entity
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'the chemical entity or entity that '
                                                   'is an interactor',
                                    'name': 'subject',
                                    'range': 'chemical entity or gene or gene '
                                             'product'}}})

    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class CaseToEntityAssociationMixin(ConfiguredBaseModel):
    """
    An abstract association for use where the case is the subject
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'the case (e.g. patient) that has '
                                                   'the property',
                                    'name': 'subject',
                                    'range': 'case'}}})

    subject: str = Field(..., description="""the case (e.g. patient) that has the property""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class ChemicalToChemicalAssociation(ChemicalToEntityAssociationMixin, Association):
    """
    A relationship between two chemical entities. This can encompass actual interactions as well as temporal causal edges, e.g. one chemical converted to another.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['chemical to entity association mixin'],
         'slot_usage': {'object': {'description': 'the chemical element that is the '
                                                  'target of the statement',
                                   'name': 'object',
                                   'range': 'chemical entity'}}})

    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the chemical element that is the target of the statement""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalToChemicalAssociation","biolink:ChemicalToChemicalAssociation"]] = Field(["biolink:ChemicalToChemicalAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ReactionToParticipantAssociation(ChemicalToChemicalAssociation):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'subject': {'name': 'subject', 'range': 'molecular entity'}}})

    stoichiometry: Optional[int] = Field(None, description="""the relationship between the relative quantities of substances taking part in a reaction or forming a compound, typically a ratio of whole integers.""", json_schema_extra = { "linkml_meta": {'alias': 'stoichiometry',
         'domain': 'association',
         'domain_of': ['reaction to participant association'],
         'is_a': 'association slot'} })
    reaction_direction: Optional[ReactionDirectionEnum] = Field(None, description="""the direction of a reaction as constrained by the direction enum (ie: left_to_right, neutral, etc.)""", json_schema_extra = { "linkml_meta": {'alias': 'reaction_direction',
         'domain': 'association',
         'domain_of': ['reaction to participant association'],
         'is_a': 'association slot',
         'narrow_mappings': ['NCIT:C42677']} })
    reaction_side: Optional[ReactionSideEnum] = Field(None, description="""the side of a reaction being modeled (ie: left or right)""", json_schema_extra = { "linkml_meta": {'alias': 'reaction_side',
         'domain': 'association',
         'domain_of': ['reaction to participant association'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the chemical element that is the target of the statement""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ReactionToParticipantAssociation","biolink:ReactionToParticipantAssociation"]] = Field(["biolink:ReactionToParticipantAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ReactionToCatalystAssociation(ReactionToParticipantAssociation):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'gene or gene product'}}})

    stoichiometry: Optional[int] = Field(None, description="""the relationship between the relative quantities of substances taking part in a reaction or forming a compound, typically a ratio of whole integers.""", json_schema_extra = { "linkml_meta": {'alias': 'stoichiometry',
         'domain': 'association',
         'domain_of': ['reaction to participant association'],
         'is_a': 'association slot'} })
    reaction_direction: Optional[ReactionDirectionEnum] = Field(None, description="""the direction of a reaction as constrained by the direction enum (ie: left_to_right, neutral, etc.)""", json_schema_extra = { "linkml_meta": {'alias': 'reaction_direction',
         'domain': 'association',
         'domain_of': ['reaction to participant association'],
         'is_a': 'association slot',
         'narrow_mappings': ['NCIT:C42677']} })
    reaction_side: Optional[ReactionSideEnum] = Field(None, description="""the side of a reaction being modeled (ie: left or right)""", json_schema_extra = { "linkml_meta": {'alias': 'reaction_side',
         'domain': 'association',
         'domain_of': ['reaction to participant association'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the chemical element that is the target of the statement""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ReactionToCatalystAssociation","biolink:ReactionToCatalystAssociation"]] = Field(["biolink:ReactionToCatalystAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalToChemicalDerivationAssociation(ChemicalToChemicalAssociation):
    """
    A causal relationship between two chemical entities, where the subject represents the upstream entity and the object represents the downstream. For any such association there is an implicit reaction: IF R has-input C1 AND R has-output C2 AND R enabled-by P AND R type Reaction THEN C1 derives-into C2 catalyst qualifier P
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'catalyst qualifier': {'description': 'this connects the '
                                                              'derivation edge to the '
                                                              'chemical entity that '
                                                              'catalyzes the reaction '
                                                              'that causes the subject '
                                                              'chemical to transform '
                                                              'into the object '
                                                              'chemical.',
                                               'name': 'catalyst qualifier'},
                        'object': {'description': 'the downstream chemical entity',
                                   'name': 'object',
                                   'range': 'chemical entity'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'derives into'},
                        'subject': {'description': 'the upstream chemical entity',
                                    'name': 'subject',
                                    'range': 'chemical entity'}}})

    catalyst_qualifier: Optional[List[str]] = Field(None, description="""this connects the derivation edge to the chemical entity that catalyzes the reaction that causes the subject chemical to transform into the object chemical.""", json_schema_extra = { "linkml_meta": {'alias': 'catalyst_qualifier',
         'domain': 'association',
         'domain_of': ['chemical to chemical derivation association'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""the upstream chemical entity""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'derives into'} })
    object: str = Field(..., description="""the downstream chemical entity""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalToChemicalDerivationAssociation","biolink:ChemicalToChemicalDerivationAssociation"]] = Field(["biolink:ChemicalToChemicalDerivationAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MolecularActivityToPathwayAssociation(Association):
    """
    Association that holds the relationship between a reaction and the pathway it participates in.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'pathway'},
                        'predicate': {'name': 'predicate', 'subproperty_of': 'part of'},
                        'subject': {'name': 'subject', 'range': 'molecular activity'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'part of'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MolecularActivityToPathwayAssociation","biolink:MolecularActivityToPathwayAssociation"]] = Field(["biolink:MolecularActivityToPathwayAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalToPathwayAssociation(ChemicalToEntityAssociationMixin, Association):
    """
    An interaction between a chemical entity and a biological process or pathway.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'exact_mappings': ['SIO:001250'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['chemical to entity association mixin'],
         'slot_usage': {'object': {'description': 'the pathway that is affected by the '
                                                  'chemical',
                                   'name': 'object',
                                   'range': 'pathway'},
                        'subject': {'description': 'the chemical entity that is '
                                                   'affecting the pathway',
                                    'name': 'subject',
                                    'range': 'chemical entity'}}})

    subject: str = Field(..., description="""the chemical entity that is affecting the pathway""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the pathway that is affected by the chemical""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalToPathwayAssociation","biolink:ChemicalToPathwayAssociation"]] = Field(["biolink:ChemicalToPathwayAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class NamedThingAssociatedWithLikelihoodOfNamedThingAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject',
                            'subject aspect qualifier',
                            'subject context qualifier',
                            'predicate',
                            'object',
                            'object aspect qualifier',
                            'object context qualifier',
                            'population context qualifier'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object aspect qualifier': {'name': 'object aspect qualifier'},
                        'object context qualifier': {'name': 'object context qualifier',
                                                     'range': 'ontology class'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'associated with'},
                        'subject aspect qualifier': {'name': 'subject aspect '
                                                             'qualifier'},
                        'subject context qualifier': {'name': 'subject context '
                                                              'qualifier',
                                                      'range': 'ontology class'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'subject_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'associated with'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'object_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    population_context_qualifier: Optional[str] = Field(None, description="""a biological population (general, study, cohort, etc.) with a specific set of characteristics to constrain an association.""", json_schema_extra = { "linkml_meta": {'alias': 'population_context_qualifier',
         'domain': 'association',
         'domain_of': ['named thing associated with likelihood of named thing '
                       'association',
                       'exposure event to outcome association'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/NamedThingAssociatedWithLikelihoodOfNamedThingAssociation","biolink:NamedThingAssociatedWithLikelihoodOfNamedThingAssociation"]] = Field(["biolink:NamedThingAssociatedWithLikelihoodOfNamedThingAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalGeneInteractionAssociation(ChemicalToEntityAssociationMixin, Association):
    """
    describes a physical interaction between a chemical entity and a gene or gene product. Any biological or chemical effect resulting from such an interaction are out of scope, and covered by the ChemicalAffectsGeneAssociation type (e.g. impact of a chemical on the abundance, activity, structure, etc, of either participant in the interaction)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'exact_mappings': ['SIO:001257'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['chemical to entity association mixin'],
         'slot_usage': {'anatomical context qualifier': {'name': 'anatomical context '
                                                                 'qualifier',
                                                         'range': 'anatomical entity'},
                        'object': {'name': 'object', 'range': 'gene or gene product'},
                        'object context qualifier': {'name': 'object context qualifier',
                                                     'range': 'anatomical entity'},
                        'object form or variant qualifier': {'name': 'object form or '
                                                                     'variant '
                                                                     'qualifier',
                                                             'range': 'ChemicalOrGeneOrGeneProductFormOrVariantEnum'},
                        'object part qualifier': {'name': 'object part qualifier',
                                                  'range': 'GeneOrGeneProductOrChemicalPartQualifierEnum'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'physically interacts with'},
                        'subject': {'name': 'subject', 'range': 'chemical entity'},
                        'subject context qualifier': {'name': 'subject context '
                                                              'qualifier',
                                                      'range': 'anatomical entity'},
                        'subject derivative qualifier': {'name': 'subject derivative '
                                                                 'qualifier',
                                                         'range': 'ChemicalEntityDerivativeEnum'},
                        'subject form or variant qualifier': {'name': 'subject form or '
                                                                      'variant '
                                                                      'qualifier',
                                                              'range': 'ChemicalOrGeneOrGeneProductFormOrVariantEnum'},
                        'subject part qualifier': {'name': 'subject part qualifier',
                                                   'range': 'GeneOrGeneProductOrChemicalPartQualifierEnum'}}})

    subject_form_or_variant_qualifier: Optional[ChemicalOrGeneOrGeneProductFormOrVariantEnum] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'gene has variant that contributes to disease association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    subject_part_qualifier: Optional[GeneOrGeneProductOrChemicalPartQualifierEnum] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  subject of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    subject_derivative_qualifier: Optional[ChemicalEntityDerivativeEnum] = Field(None, description="""A qualifier that composes with a core subject/object  concept to describe something that is derived from the core concept.  For example, the qualifier ‘metabolite’ combines with a ‘Chemical X’ core concept to express the composed concept ‘a metabolite of Chemical X’.  This qualifier is for the subject of an association  (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_derivative_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'metabolite'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'derivative qualifier'} })
    subject_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'subject_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    object_form_or_variant_qualifier: Optional[ChemicalOrGeneOrGeneProductFormOrVariantEnum] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    object_part_qualifier: Optional[GeneOrGeneProductOrChemicalPartQualifierEnum] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  object of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    object_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'object_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    anatomical_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing an anatomical location where an relationship expressed in an association took place (can be a tissue, cell type, or sub-cellular location).""", json_schema_extra = { "linkml_meta": {'alias': 'anatomical_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'blood'}, {'value': 'cerebral cortext'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Anatomical context values can be any term from UBERON. For '
                   'example, the context qualifier ‘cerebral cortext’ combines with a '
                   'core concept of ‘neuron’ to express the composed concept ‘neuron '
                   'in the cerebral cortext’. The species_context_qualifier applies '
                   'taxonomic context, e.g. species-specific molecular activity.  '
                   'Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'physically interacts with'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalGeneInteractionAssociation","biolink:ChemicalGeneInteractionAssociation"]] = Field(["biolink:ChemicalGeneInteractionAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneRegulatesGeneAssociation(Association):
    """
    Describes a regulatory relationship between two genes or gene products.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'examples': [{'value': "JsonObj(subject='NCBIGene:551', "
                                "predicate='regulates', qualified_predicte='causes', "
                                "object='NCBIGene:1636', "
                                "object_aspect_qualifier='activity_or_abundance', "
                                "object_direction_qualifier='downregulated')"}],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'gene or gene product'},
                        'object aspect qualifier': {'description': 'the aspect of the '
                                                                   'object gene or '
                                                                   'gene product that '
                                                                   'is being '
                                                                   'regulated, must be '
                                                                   'a descendant of  '
                                                                   '"activity_or_abundance""',
                                                    'name': 'object aspect qualifier',
                                                    'range': 'GeneOrGeneProductOrChemicalEntityAspectEnum',
                                                    'required': True},
                        'object direction qualifier': {'name': 'object direction '
                                                               'qualifier',
                                                       'range': 'DirectionQualifierEnum',
                                                       'required': True},
                        'predicate': {'id_prefixes': ['regulates'],
                                      'name': 'predicate'},
                        'qualified predicate': {'name': 'qualified predicate',
                                                'required': True,
                                                'subproperty_of': 'causes'},
                        'subject': {'name': 'subject',
                                    'range': 'gene or gene product'}}})

    object_aspect_qualifier: GeneOrGeneProductOrChemicalEntityAspectEnum = Field(..., description="""the aspect of the object gene or gene product that is being regulated, must be a descendant of  \"activity_or_abundance\"\"""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: DirectionQualifierEnum = Field(..., description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: str = Field(..., description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)'],
         'subproperty_of': 'causes'} })
    species_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing a taxonomic category of species in which a relationship expressed in an association took place.""", json_schema_extra = { "linkml_meta": {'alias': 'species_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'zebrafish'}, {'value': 'human'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'id_prefixes': ['regulates'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneRegulatesGeneAssociation","biolink:GeneRegulatesGeneAssociation"]] = Field(["biolink:GeneRegulatesGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ProcessRegulatesProcessAssociation(Association):
    """
    Describes a regulatory relationship between two genes or gene products.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'biological process'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'regulates'},
                        'subject': {'name': 'subject', 'range': 'biological process'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'regulates'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ProcessRegulatesProcessAssociation","biolink:ProcessRegulatesProcessAssociation"]] = Field(["biolink:ProcessRegulatesProcessAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalAffectsGeneAssociation(Association):
    """
    Describes an effect that a chemical has on a gene or gene product (e.g. an impact of on its abundance, activity,localization, processing, expression, etc.)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'anatomical context qualifier': {'name': 'anatomical context '
                                                                 'qualifier',
                                                         'range': 'anatomical entity'},
                        'causal mechanism qualifier': {'name': 'causal mechanism '
                                                               'qualifier',
                                                       'range': 'CausalMechanismQualifierEnum'},
                        'object': {'name': 'object', 'range': 'gene or gene product'},
                        'object aspect qualifier': {'name': 'object aspect qualifier',
                                                    'range': 'GeneOrGeneProductOrChemicalEntityAspectEnum'},
                        'object context qualifier': {'name': 'object context qualifier',
                                                     'range': 'anatomical entity'},
                        'object direction qualifier': {'name': 'object direction '
                                                               'qualifier',
                                                       'range': 'DirectionQualifierEnum'},
                        'object form or variant qualifier': {'name': 'object form or '
                                                                     'variant '
                                                                     'qualifier',
                                                             'range': 'ChemicalOrGeneOrGeneProductFormOrVariantEnum'},
                        'object part qualifier': {'name': 'object part qualifier',
                                                  'range': 'GeneOrGeneProductOrChemicalPartQualifierEnum'},
                        'predicate': {'name': 'predicate', 'subproperty_of': 'affects'},
                        'qualified predicate': {'name': 'qualified predicate',
                                                'subproperty_of': 'causes'},
                        'species context qualifier': {'name': 'species context '
                                                              'qualifier',
                                                      'range': 'organism taxon'},
                        'subject': {'name': 'subject', 'range': 'chemical entity'},
                        'subject aspect qualifier': {'name': 'subject aspect qualifier',
                                                     'range': 'GeneOrGeneProductOrChemicalEntityAspectEnum'},
                        'subject context qualifier': {'name': 'subject context '
                                                              'qualifier',
                                                      'range': 'anatomical entity'},
                        'subject derivative qualifier': {'name': 'subject derivative '
                                                                 'qualifier',
                                                         'range': 'ChemicalEntityDerivativeEnum'},
                        'subject direction qualifier': {'name': 'subject direction '
                                                                'qualifier',
                                                        'range': 'DirectionQualifierEnum'},
                        'subject form or variant qualifier': {'name': 'subject form or '
                                                                      'variant '
                                                                      'qualifier',
                                                              'range': 'ChemicalOrGeneOrGeneProductFormOrVariantEnum'},
                        'subject part qualifier': {'name': 'subject part qualifier',
                                                   'range': 'GeneOrGeneProductOrChemicalPartQualifierEnum'}}})

    subject_form_or_variant_qualifier: Optional[ChemicalOrGeneOrGeneProductFormOrVariantEnum] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'gene has variant that contributes to disease association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    subject_part_qualifier: Optional[GeneOrGeneProductOrChemicalPartQualifierEnum] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  subject of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    subject_derivative_qualifier: Optional[ChemicalEntityDerivativeEnum] = Field(None, description="""A qualifier that composes with a core subject/object  concept to describe something that is derived from the core concept.  For example, the qualifier ‘metabolite’ combines with a ‘Chemical X’ core concept to express the composed concept ‘a metabolite of Chemical X’.  This qualifier is for the subject of an association  (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_derivative_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'metabolite'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'derivative qualifier'} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'subject_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_form_or_variant_qualifier: Optional[ChemicalOrGeneOrGeneProductFormOrVariantEnum] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    object_part_qualifier: Optional[GeneOrGeneProductOrChemicalPartQualifierEnum] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  object of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    object_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'object_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    causal_mechanism_qualifier: Optional[CausalMechanismQualifierEnum] = Field(None, description="""A statement qualifier representing a type of molecular control mechanism through which an effect of a chemical on a gene or gene product is mediated (e.g. 'agonism', 'inhibition', 'allosteric modulation', 'channel blocker')""", json_schema_extra = { "linkml_meta": {'alias': 'causal_mechanism_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    anatomical_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing an anatomical location where an relationship expressed in an association took place (can be a tissue, cell type, or sub-cellular location).""", json_schema_extra = { "linkml_meta": {'alias': 'anatomical_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'blood'}, {'value': 'cerebral cortext'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Anatomical context values can be any term from UBERON. For '
                   'example, the context qualifier ‘cerebral cortext’ combines with a '
                   'core concept of ‘neuron’ to express the composed concept ‘neuron '
                   'in the cerebral cortext’. The species_context_qualifier applies '
                   'taxonomic context, e.g. species-specific molecular activity.  '
                   'Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)'],
         'subproperty_of': 'causes'} })
    species_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing a taxonomic category of species in which a relationship expressed in an association took place.""", json_schema_extra = { "linkml_meta": {'alias': 'species_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'zebrafish'}, {'value': 'human'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalAffectsGeneAssociation","biolink:ChemicalAffectsGeneAssociation"]] = Field(["biolink:ChemicalAffectsGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneAffectsChemicalAssociation(Association):
    """
    Describes an effect that a gene or gene product has on a chemical entity (e.g. an impact of on its abundance, activity, localization, processing, transport, etc.)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'examples': [{'value': "JsonObj(subject='TRPC4', predicate='affects', "
                                "qualified_predicte='causes', object='Barium', "
                                "object_aspect_qualifier='transport', "
                                "object_direction_qualifier='increased')"}],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'anatomical context qualifier': {'name': 'anatomical context '
                                                                 'qualifier',
                                                         'range': 'anatomical entity'},
                        'causal mechanism qualifier': {'name': 'causal mechanism '
                                                               'qualifier',
                                                       'range': 'CausalMechanismQualifierEnum'},
                        'object': {'name': 'object', 'range': 'chemical entity'},
                        'object aspect qualifier': {'name': 'object aspect qualifier',
                                                    'range': 'GeneOrGeneProductOrChemicalEntityAspectEnum'},
                        'object context qualifier': {'name': 'object context qualifier',
                                                     'range': 'anatomical entity'},
                        'object derivative qualifier': {'name': 'object derivative '
                                                                'qualifier',
                                                        'range': 'ChemicalEntityDerivativeEnum'},
                        'object direction qualifier': {'name': 'object direction '
                                                               'qualifier',
                                                       'range': 'DirectionQualifierEnum'},
                        'object form or variant qualifier': {'name': 'object form or '
                                                                     'variant '
                                                                     'qualifier',
                                                             'range': 'ChemicalOrGeneOrGeneProductFormOrVariantEnum'},
                        'object part qualifier': {'name': 'object part qualifier',
                                                  'range': 'GeneOrGeneProductOrChemicalPartQualifierEnum'},
                        'predicate': {'name': 'predicate', 'subproperty_of': 'affects'},
                        'qualified predicate': {'name': 'qualified predicate',
                                                'subproperty_of': 'causes'},
                        'species context qualifier': {'name': 'species context '
                                                              'qualifier',
                                                      'range': 'organism taxon'},
                        'subject': {'name': 'subject', 'range': 'gene or gene product'},
                        'subject aspect qualifier': {'name': 'subject aspect qualifier',
                                                     'range': 'GeneOrGeneProductOrChemicalEntityAspectEnum'},
                        'subject context qualifier': {'name': 'subject context '
                                                              'qualifier',
                                                      'range': 'anatomical entity'},
                        'subject direction qualifier': {'name': 'subject direction '
                                                                'qualifier',
                                                        'range': 'DirectionQualifierEnum'},
                        'subject form or variant qualifier': {'name': 'subject form or '
                                                                      'variant '
                                                                      'qualifier',
                                                              'range': 'ChemicalOrGeneOrGeneProductFormOrVariantEnum'},
                        'subject part qualifier': {'name': 'subject part qualifier',
                                                   'range': 'GeneOrGeneProductOrChemicalPartQualifierEnum'}}})

    subject_form_or_variant_qualifier: Optional[ChemicalOrGeneOrGeneProductFormOrVariantEnum] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'gene has variant that contributes to disease association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    subject_part_qualifier: Optional[GeneOrGeneProductOrChemicalPartQualifierEnum] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  subject of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    subject_derivative_qualifier: Optional[str] = Field(None, description="""A qualifier that composes with a core subject/object  concept to describe something that is derived from the core concept.  For example, the qualifier ‘metabolite’ combines with a ‘Chemical X’ core concept to express the composed concept ‘a metabolite of Chemical X’.  This qualifier is for the subject of an association  (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_derivative_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'metabolite'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'derivative qualifier'} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'subject_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_form_or_variant_qualifier: Optional[ChemicalOrGeneOrGeneProductFormOrVariantEnum] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    object_part_qualifier: Optional[GeneOrGeneProductOrChemicalPartQualifierEnum] = Field(None, description="""defines a specific part/component of the core concept (used in cases there this specific part has no IRI we can use to directly represent it, e.g. 'ESR1 transcript' q: polyA tail).  This qualifier is for the  object of an association (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_part_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'part qualifier'} })
    object_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_context_qualifier: Optional[str] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'object_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'context qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_derivative_qualifier: Optional[ChemicalEntityDerivativeEnum] = Field(None, description="""A qualifier that composes with a core subject/object  concept to describe something that is derived from the core concept.  For example, the qualifier ‘metabolite’ combines with a ‘Chemical X’ core concept to express the composed concept ‘a metabolite of Chemical X’.  This qualifier is for the object of an association  (or statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_derivative_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping', 'gene affects chemical association'],
         'examples': [{'value': 'metabolite'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'derivative qualifier'} })
    causal_mechanism_qualifier: Optional[CausalMechanismQualifierEnum] = Field(None, description="""A statement qualifier representing a type of molecular control mechanism through which an effect of a chemical on a gene or gene product is mediated (e.g. 'agonism', 'inhibition', 'allosteric modulation', 'channel blocker')""", json_schema_extra = { "linkml_meta": {'alias': 'causal_mechanism_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    anatomical_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing an anatomical location where an relationship expressed in an association took place (can be a tissue, cell type, or sub-cellular location).""", json_schema_extra = { "linkml_meta": {'alias': 'anatomical_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'blood'}, {'value': 'cerebral cortext'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Anatomical context values can be any term from UBERON. For '
                   'example, the context qualifier ‘cerebral cortext’ combines with a '
                   'core concept of ‘neuron’ to express the composed concept ‘neuron '
                   'in the cerebral cortext’. The species_context_qualifier applies '
                   'taxonomic context, e.g. species-specific molecular activity.  '
                   'Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)'],
         'subproperty_of': 'causes'} })
    species_context_qualifier: Optional[str] = Field(None, description="""A statement qualifier representing a taxonomic category of species in which a relationship expressed in an association took place.""", json_schema_extra = { "linkml_meta": {'alias': 'species_context_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association'],
         'examples': [{'value': 'zebrafish'}, {'value': 'human'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier',
         'notes': ['Ontology CURIEs are expected as values here, the examples below '
                   'are intended to help clarify the content of the CURIEs.']} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneAffectsChemicalAssociation","biolink:GeneAffectsChemicalAssociation"]] = Field(["biolink:GeneAffectsChemicalAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DrugToGeneAssociation(DrugToEntityAssociationMixin, Association):
    """
    An interaction between a drug and a gene or gene product.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['drug to entity association mixin'],
         'related_mappings': ['SIO:001257'],
         'slot_usage': {'object': {'description': 'the gene or gene product that is '
                                                  'affected by the drug',
                                   'name': 'object',
                                   'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""the drug that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the gene or gene product that is affected by the drug""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DrugToGeneAssociation","biolink:DrugToGeneAssociation"]] = Field(["biolink:DrugToGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MaterialSampleToEntityAssociationMixin(ConfiguredBaseModel):
    """
    An association between a material sample and something.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'the material sample being '
                                                   'described',
                                    'name': 'subject',
                                    'range': 'material sample'}}})

    subject: str = Field(..., description="""the material sample being described""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class MaterialSampleDerivationAssociation(Association):
    """
    An association between a material sample and the material entity from which it is derived.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'the material entity the sample was '
                                                  'derived from. This may be another '
                                                  'material sample, or any other '
                                                  'material entity, including for '
                                                  'example an organism, a geographic '
                                                  'feature, or some environmental '
                                                  'material.',
                                   'name': 'object'},
                        'predicate': {'description': 'derivation relationship',
                                      'name': 'predicate',
                                      'subproperty_of': 'derives from'},
                        'subject': {'description': 'the material sample being '
                                                   'described',
                                    'name': 'subject',
                                    'range': 'material sample'}}})

    subject: str = Field(..., description="""the material sample being described""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""derivation relationship""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'derives from'} })
    object: str = Field(..., description="""the material entity the sample was derived from. This may be another material sample, or any other material entity, including for example an organism, a geographic feature, or some environmental material.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MaterialSampleDerivationAssociation","biolink:MaterialSampleDerivationAssociation"]] = Field(["biolink:MaterialSampleDerivationAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DiseaseToEntityAssociationMixin(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'disease class',
                                    'examples': [{'description': 'Ehlers-Danlos '
                                                                 'syndrome, vascular '
                                                                 'type',
                                                  'value': 'MONDO:0017314'}],
                                    'name': 'subject',
                                    'range': 'disease',
                                    'values_from': ['mondo',
                                                    'omim',
                                                    'orphanet',
                                                    'ncit',
                                                    'doid']}}})

    subject: str = Field(..., description="""disease class""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject',
         'values_from': ['mondo', 'omim', 'orphanet', 'ncit', 'doid']} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class EntityToExposureEventAssociationMixin(ConfiguredBaseModel):
    """
    An association between some entity and an exposure event.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'object': {'name': 'object', 'range': 'exposure event'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class DiseaseToExposureEventAssociation(EntityToExposureEventAssociationMixin, DiseaseToEntityAssociationMixin, Association):
    """
    An association between an exposure event and a disease.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['disease to entity association mixin',
                    'entity to exposure event association mixin']})

    subject: str = Field(..., description="""disease class""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject',
         'values_from': ['mondo', 'omim', 'orphanet', 'ncit', 'doid']} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiseaseToExposureEventAssociation","biolink:DiseaseToExposureEventAssociation"]] = Field(["biolink:DiseaseToExposureEventAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EntityToOutcomeAssociationMixin(ConfiguredBaseModel):
    """
    An association between some entity and an outcome
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'object': {'name': 'object', 'range': 'outcome'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class ExposureEventToOutcomeAssociation(EntityToOutcomeAssociationMixin, Association):
    """
    An association between an exposure event and an outcome.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to outcome association mixin']})

    population_context_qualifier: Optional[str] = Field(None, description="""a biological population (general, study, cohort, etc.) with a specific set of characteristics to constrain an association.""", json_schema_extra = { "linkml_meta": {'alias': 'population_context_qualifier',
         'domain': 'association',
         'domain_of': ['named thing associated with likelihood of named thing '
                       'association',
                       'exposure event to outcome association'],
         'is_a': 'qualifier'} })
    temporal_context_qualifier: Optional[str] = Field(None, description="""a constraint of time placed upon the truth value of an association. for time intervales, use temporal interval qualifier.""", json_schema_extra = { "linkml_meta": {'alias': 'temporal_context_qualifier',
         'domain': 'association',
         'domain_of': ['exposure event to outcome association'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ExposureEventToOutcomeAssociation","biolink:ExposureEventToOutcomeAssociation"]] = Field(["biolink:ExposureEventToOutcomeAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class FrequencyQualifierMixin(ConfiguredBaseModel):
    """
    Qualifier for frequency type associations
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class EntityToFeatureOrDiseaseQualifiersMixin(FrequencyQualifierMixin):
    """
    Qualifiers for entity to disease or phenotype associations.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class FeatureOrDiseaseQualifiersToEntityMixin(FrequencyQualifierMixin):
    """
    Qualifiers for disease or phenotype to entity associations.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model', 'mixin': True})

    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class EntityToPhenotypicFeatureAssociationMixin(EntityToFeatureOrDiseaseQualifiersMixin, FrequencyQuantifier):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'mixins': ['frequency quantifier'],
         'slot_usage': {'object': {'examples': [{'description': 'Hyperkinesis',
                                                 'value': 'HP:0002487'},
                                                {'description': 'axon morphology '
                                                                'variant',
                                                 'value': 'WBPhenotype:0000180'},
                                                {'description': 'abnormal circulating '
                                                                'bilirubin level',
                                                 'value': 'MP:0001569'}],
                                   'name': 'object',
                                   'range': 'phenotypic feature',
                                   'values_from': ['upheno',
                                                   'hp',
                                                   'mp',
                                                   'wbphenotype']}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class PhenotypicFeatureToEntityAssociationMixin(FeatureOrDiseaseQualifiersToEntityMixin, FrequencyQuantifier):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'mixins': ['frequency quantifier'],
         'slot_usage': {'subject': {'examples': [{'description': 'Hyperkinesis',
                                                  'value': 'HP:0002487'},
                                                 {'description': 'axon morphology '
                                                                 'variant',
                                                  'value': 'WBPhenotype:0000180'},
                                                 {'description': 'abnormal circulating '
                                                                 'bilirubin level',
                                                  'value': 'MP:0001569'}],
                                    'name': 'subject',
                                    'range': 'phenotypic feature',
                                    'values_from': ['upheno',
                                                    'hp',
                                                    'mp',
                                                    'wbphenotype']}}})

    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class PhenotypicFeatureToPhenotypicFeatureAssociation(PhenotypicFeatureToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin, Association):
    """
    Association between two concept nodes of phenotypic character, qualified by the predicate used. This association may typically be used to specify 'similar_to' or 'member_of' relationships.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['phenotypic feature to entity association mixin',
                    'entity to phenotypic feature association mixin']})

    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhenotypicFeatureToPhenotypicFeatureAssociation","biolink:PhenotypicFeatureToPhenotypicFeatureAssociation"]] = Field(["biolink:PhenotypicFeatureToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class InformationContentEntityToNamedThingAssociation(Association):
    """
    association between a named thing and a information content entity where the specific context of the relationship between that named thing and the publication is unknown. For example, model organisms databases often capture the knowledge that a gene is found in a journal article, but not specifically the context in which that gene was documented in the article. In these cases, this association with the accompanying predicate 'mentions' could be used. Conversely, for more specific associations (like 'gene to disease association', the publication should be captured as an edge property).
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'in_subset': ['model_organism_database'],
         'slot_usage': {'object': {'name': 'object', 'range': 'named thing'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'mentions'},
                        'subject': {'domain': 'publication', 'name': 'subject'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'publication',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'mentions'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/InformationContentEntityToNamedThingAssociation","biolink:InformationContentEntityToNamedThingAssociation"]] = Field(["biolink:InformationContentEntityToNamedThingAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EntityToDiseaseAssociationMixin(EntityToFeatureOrDiseaseQualifiersMixin):
    """
    mixin class for any association whose object (target node) is a disease
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'object': {'description': 'disease',
                                   'examples': [{'description': 'Ehlers-Danlos '
                                                                'syndrome',
                                                 'value': 'MONDO:0020066'}],
                                   'name': 'object',
                                   'range': 'disease'}}})

    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class DiseaseOrPhenotypicFeatureToEntityAssociationMixin(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'disease or phenotype',
                                    'examples': [{'description': 'Ehlers-Danlos '
                                                                 'syndrome, vascular '
                                                                 'type',
                                                  'value': 'MONDO:0017314'},
                                                 {'description': 'abnormal brain '
                                                                 'ventricle size',
                                                  'value': 'MP:0013229'}],
                                    'name': 'subject',
                                    'range': 'disease or phenotypic feature'}}})

    subject: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class DiseaseOrPhenotypicFeatureToLocationAssociation(DiseaseOrPhenotypicFeatureToEntityAssociationMixin, Association):
    """
    An association between either a disease or a phenotypic feature and an anatomical entity, where the disease/feature manifests in that site.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['disease or phenotypic feature to entity association mixin'],
         'slot_usage': {'object': {'description': 'anatomical entity in which the '
                                                  'disease or feature is found.',
                                   'examples': [{'description': 'lung',
                                                 'value': 'UBERON:0002048'}],
                                   'name': 'object',
                                   'range': 'anatomical entity'}}})

    subject: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""anatomical entity in which the disease or feature is found.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'lung', 'value': 'UBERON:0002048'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiseaseOrPhenotypicFeatureToLocationAssociation","biolink:DiseaseOrPhenotypicFeatureToLocationAssociation"]] = Field(["biolink:DiseaseOrPhenotypicFeatureToLocationAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation(DiseaseOrPhenotypicFeatureToEntityAssociationMixin, Association):
    """
    An association between either a disease or a phenotypic feature and its mode of (genetic) inheritance.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['disease or phenotypic feature to entity association mixin'],
         'slot_usage': {'object': {'description': 'genetic inheritance associated with '
                                                  'the specified disease or phenotypic '
                                                  'feature.',
                                   'examples': [{'description': 'X-linked inheritance',
                                                 'value': 'HP:0001417'}],
                                   'name': 'object',
                                   'range': 'genetic inheritance'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has mode of inheritance'}}})

    subject: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has mode of inheritance'} })
    object: str = Field(..., description="""genetic inheritance associated with the specified disease or phenotypic feature.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'X-linked inheritance', 'value': 'HP:0001417'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation","biolink:DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation"]] = Field(["biolink:DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EntityToDiseaseOrPhenotypicFeatureAssociationMixin(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'object': {'description': 'disease or phenotype',
                                   'examples': [{'description': 'Ehlers-Danlos '
                                                                'syndrome, vascular '
                                                                'type',
                                                 'value': 'MONDO:0017314'},
                                                {'description': 'abnormal brain '
                                                                'ventricle size',
                                                 'value': 'MP:0013229'}],
                                   'name': 'object',
                                   'range': 'disease or phenotypic feature'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class CellLineToDiseaseOrPhenotypicFeatureAssociation(EntityToDiseaseOrPhenotypicFeatureAssociationMixin, CellLineToEntityAssociationMixin, Association):
    """
    An relationship between a cell line and a disease or a phenotype, where the cell line is derived from an individual with that disease or phenotype.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['cell line to entity association mixin',
                    'entity to disease or phenotypic feature association mixin'],
         'slot_usage': {'subject': {'name': 'subject',
                                    'range': 'disease or phenotypic feature'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CellLineToDiseaseOrPhenotypicFeatureAssociation","biolink:CellLineToDiseaseOrPhenotypicFeatureAssociation"]] = Field(["biolink:CellLineToDiseaseOrPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalToDiseaseOrPhenotypicFeatureAssociation(EntityToDiseaseOrPhenotypicFeatureAssociationMixin, ChemicalToEntityAssociationMixin, Association):
    """
    An interaction between a chemical entity and a phenotype or disease, where the presence of the chemical gives rise to or exacerbates the phenotype.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['chemical to entity association mixin',
                    'entity to disease or phenotypic feature association mixin'],
         'narrow_mappings': ['SIO:000993'],
         'slot_usage': {'object': {'description': 'the disease or phenotype that is '
                                                  'affected by the chemical',
                                   'name': 'object',
                                   'range': 'disease or phenotypic feature'}}})

    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the disease or phenotype that is affected by the chemical""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalToDiseaseOrPhenotypicFeatureAssociation","biolink:ChemicalToDiseaseOrPhenotypicFeatureAssociation"]] = Field(["biolink:ChemicalToDiseaseOrPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation(EntityToDiseaseOrPhenotypicFeatureAssociationMixin, ChemicalToEntityAssociationMixin, Association):
    """
    This association defines a relationship between a chemical or treatment (or procedure) and a disease or phenotypic feature where the disesae or phenotypic feature is a secondary undesirable effect.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['chemical to entity association mixin',
                    'entity to disease or phenotypic feature association mixin'],
         'slot_usage': {'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has adverse event'}}})

    FDA_adverse_event_level: Optional[FDAIDAAdverseEventEnum] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'FDA_adverse_event_level',
         'domain': 'association',
         'domain_of': ['chemical or drug or treatment to disease or phenotypic feature '
                       'association'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has adverse event'} })
    object: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation","biolink:ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation"]] = Field(["biolink:ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation(ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation, EntityToDiseaseOrPhenotypicFeatureAssociationMixin, ChemicalToEntityAssociationMixin):
    """
    This association defines a relationship between a chemical or treatment (or procedure) and a disease or phenotypic feature where the disesae or phenotypic feature is a secondary, typically (but not always) undesirable effect.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['chemical to entity association mixin',
                    'entity to disease or phenotypic feature association mixin'],
         'slot_usage': {'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has side effect'}}})

    subject: str = Field(..., description="""the chemical entity or entity that is an interactor""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has side effect'} })
    object: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    FDA_adverse_event_level: Optional[FDAIDAAdverseEventEnum] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'FDA_adverse_event_level',
         'domain': 'association',
         'domain_of': ['chemical or drug or treatment to disease or phenotypic feature '
                       'association'],
         'is_a': 'association slot'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation","biolink:ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation"]] = Field(["biolink:ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MaterialSampleToDiseaseOrPhenotypicFeatureAssociation(EntityToDiseaseOrPhenotypicFeatureAssociationMixin, MaterialSampleToEntityAssociationMixin, Association):
    """
    An association between a material sample and a disease or phenotype.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['material sample to entity association mixin',
                    'entity to disease or phenotypic feature association mixin']})

    subject: str = Field(..., description="""the material sample being described""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""disease or phenotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'},
                      {'description': 'abnormal brain ventricle size',
                       'value': 'MP:0013229'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MaterialSampleToDiseaseOrPhenotypicFeatureAssociation","biolink:MaterialSampleToDiseaseOrPhenotypicFeatureAssociation"]] = Field(["biolink:MaterialSampleToDiseaseOrPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenotypeToEntityAssociationMixin(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'genotype that is the subject of '
                                                   'the association',
                                    'name': 'subject',
                                    'range': 'genotype'}}})

    subject: str = Field(..., description="""genotype that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class GenotypeToPhenotypicFeatureAssociation(GenotypeToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin, Association):
    """
    Any association between one genotype and a phenotypic feature, where having the genotype confers the phenotype, either in isolation or through environment
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to phenotypic feature association mixin',
                    'genotype to entity association mixin'],
         'slot_usage': {'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has phenotype'},
                        'subject': {'description': 'genotype that is associated with '
                                                   'the phenotypic feature',
                                    'name': 'subject',
                                    'range': 'genotype'}}})

    subject: str = Field(..., description="""genotype that is associated with the phenotypic feature""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has phenotype'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypeToPhenotypicFeatureAssociation","biolink:GenotypeToPhenotypicFeatureAssociation"]] = Field(["biolink:GenotypeToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class ExposureEventToPhenotypicFeatureAssociation(EntityToPhenotypicFeatureAssociationMixin, Association):
    """
    Any association between an environment and a phenotypic feature, where being in the environment influences the phenotype.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to phenotypic feature association mixin'],
         'slot_usage': {'subject': {'name': 'subject', 'range': 'exposure event'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ExposureEventToPhenotypicFeatureAssociation","biolink:ExposureEventToPhenotypicFeatureAssociation"]] = Field(["biolink:ExposureEventToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class DiseaseToPhenotypicFeatureAssociation(EntityToPhenotypicFeatureAssociationMixin, DiseaseToEntityAssociationMixin, Association, FrequencyQuantifier):
    """
    An association between a disease and a phenotypic feature in which the phenotypic feature is associated with the disease in some way.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['dcid:DiseaseSymptomAssociation'],
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['frequency quantifier',
                    'entity to phenotypic feature association mixin',
                    'disease to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'phenotypic feature'},
                        'subject': {'name': 'subject', 'range': 'disease'}}})

    onset_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state when the phenotype appears is in the subject.""", json_schema_extra = { "linkml_meta": {'alias': 'onset_qualifier',
         'domain': 'association',
         'domain_of': ['disease to phenotypic feature association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier',
         'notes': ['This  is in Biolink to support HP ontology annotations which use '
                   '"onset" (with terms from HP)  as an annotation on a disease to '
                   'phenotypic feature association.  Please only use it for this '
                   'purpose.  If the intent is to describe the onset of a disease in '
                   'the context of a treatment,  use object_aspect_qualifier and '
                   'object_direction_qualifier to capture "delayed onset" or '
                   '"exacerbated onset" slot.']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject: str = Field(..., description="""disease class""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Ehlers-Danlos syndrome, vascular type',
                       'value': 'MONDO:0017314'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject',
         'values_from': ['mondo', 'omim', 'orphanet', 'ncit', 'doid']} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DiseaseToPhenotypicFeatureAssociation","biolink:DiseaseToPhenotypicFeatureAssociation"]] = Field(["biolink:DiseaseToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class CaseToPhenotypicFeatureAssociation(EntityToPhenotypicFeatureAssociationMixin, CaseToEntityAssociationMixin, Association):
    """
    An association between a case (e.g. individual patient) and a phenotypic feature in which the individual has or has had the phenotype.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to phenotypic feature association mixin',
                    'case to entity association mixin']})

    subject: str = Field(..., description="""the case (e.g. patient) that has the property""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CaseToPhenotypicFeatureAssociation","biolink:CaseToPhenotypicFeatureAssociation"]] = Field(["biolink:CaseToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class BehaviorToBehavioralFeatureAssociation(EntityToPhenotypicFeatureAssociationMixin, Association):
    """
    An association between an mixture behavior and a behavioral feature manifested by the individual exhibited or has exhibited the behavior.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to phenotypic feature association mixin'],
         'slot_usage': {'object': {'description': 'behavioral feature that is the '
                                                  'object of the association',
                                   'name': 'object',
                                   'range': 'behavioral feature'},
                        'subject': {'description': 'behavior that is the subject of '
                                                   'the association',
                                    'name': 'subject',
                                    'range': 'behavior'}}})

    subject: str = Field(..., description="""behavior that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""behavioral feature that is the object of the association""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/BehaviorToBehavioralFeatureAssociation","biolink:BehaviorToBehavioralFeatureAssociation"]] = Field(["biolink:BehaviorToBehavioralFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class GeneToEntityAssociationMixin(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'gene that is the subject of the '
                                                   'association',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""gene that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class GeneToPathwayAssociation(GeneToEntityAssociationMixin, Association):
    """
    An interaction between a gene or gene product and a biological process or pathway.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene to entity association mixin'],
         'slot_usage': {'object': {'description': 'the pathway that includes or is '
                                                  'affected by the gene or gene '
                                                  'product',
                                   'name': 'object',
                                   'range': 'pathway'},
                        'subject': {'description': 'the gene or gene product entity '
                                                   'that participates or influences '
                                                   'the pathway',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""the gene or gene product entity that participates or influences the pathway""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the pathway that includes or is affected by the gene or gene product""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToPathwayAssociation","biolink:GeneToPathwayAssociation"]] = Field(["biolink:GeneToPathwayAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class VariantToEntityAssociationMixin(ConfiguredBaseModel):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'variant annotation'}},
         'mixin': True,
         'slot_usage': {'subject': {'description': 'a sequence variant in which the '
                                                   'allele state is associated with '
                                                   'some other entity',
                                    'examples': [{'description': 'CLINVAR '
                                                                 'representation of '
                                                                 'NM_000059.3(BRCA2):c.7007G>A '
                                                                 '(p.Arg2336His)',
                                                  'value': 'CLINVAR:38077'},
                                                 {'description': 'chr13:g.32921033G>C '
                                                                 '(hg19) in ClinGen',
                                                  'value': 'ClinGen:CA024716'}],
                                    'name': 'subject',
                                    'range': 'sequence variant'}}})

    subject: str = Field(..., description="""a sequence variant in which the allele state is associated with some other entity""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'CLINVAR representation of '
                                      'NM_000059.3(BRCA2):c.7007G>A (p.Arg2336His)',
                       'value': 'CLINVAR:38077'},
                      {'description': 'chr13:g.32921033G>C (hg19) in ClinGen',
                       'value': 'ClinGen:CA024716'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class GeneToDiseaseOrPhenotypicFeatureAssociation(GeneToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'comments': ['NCIT:R176 refers to the inverse relationship',
                      'for use in describing the affect that the loss of function of a '
                      'gene can have on exacerbating or ameliorating a '
                      'symptom/phenotype',
                      'if the relationship of the statement using this predicate is '
                      'statistical in nature, please use `associated with likelihood` '
                      'or one of its children.'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to phenotypic feature association mixin',
                    'gene to entity association mixin'],
         'narrow_mappings': ['WBVocab:Gene-Phenotype-Association',
                             'dcid:DiseaseGeneAssociation',
                             'SIO:000983'],
         'slot_usage': {'object': {'name': 'object',
                                   'range': 'disease or phenotypic feature'},
                        'object direction qualifier': {'name': 'object direction '
                                                               'qualifier',
                                                       'range': 'DirectionQualifierEnum'},
                        'predicate': {'name': 'predicate', 'subproperty_of': 'affects'},
                        'subject': {'description': 'gene in which variation is '
                                                   'correlated with the phenotypic '
                                                   'feature',
                                    'examples': [{'description': 'COL1A1 (Human)',
                                                  'value': 'HGNC:2197'}],
                                    'name': 'subject',
                                    'range': 'gene or gene product'},
                        'subject aspect qualifier': {'name': 'subject aspect qualifier',
                                                     'range': 'GeneOrGeneProductOrChemicalEntityAspectEnum'}}})

    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    subject: str = Field(..., description="""gene in which variation is correlated with the phenotypic feature""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToDiseaseOrPhenotypicFeatureAssociation","biolink:GeneToDiseaseOrPhenotypicFeatureAssociation"]] = Field(["biolink:GeneToDiseaseOrPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class GeneToPhenotypicFeatureAssociation(GeneToDiseaseOrPhenotypicFeatureAssociation, GeneToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'exact_mappings': ['WBVocab:Gene-Phenotype-Association'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to phenotypic feature association mixin',
                    'gene to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'phenotypic feature'},
                        'subject': {'description': 'gene in which variation is '
                                                   'correlated with the phenotypic '
                                                   'feature',
                                    'examples': [{'description': 'COL1A1 (Human)',
                                                  'value': 'HGNC:2197'}],
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""gene in which variation is correlated with the phenotypic feature""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToPhenotypicFeatureAssociation","biolink:GeneToPhenotypicFeatureAssociation"]] = Field(["biolink:GeneToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class GeneToDiseaseAssociation(GeneToDiseaseOrPhenotypicFeatureAssociation, GeneToEntityAssociationMixin, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'close_mappings': ['dcid:DiseaseGeneAssociation'],
         'comments': ['NCIT:R176 refers to the inverse relationship'],
         'defining_slots': ['subject', 'object'],
         'exact_mappings': ['SIO:000983'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to disease association mixin',
                    'gene to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'disease'},
                        'subject': {'description': 'gene in which variation is '
                                                   'correlated with the disease, may '
                                                   'be protective or causative or '
                                                   'associative, or as a model',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""gene in which variation is correlated with the disease, may be protective or causative or associative, or as a model""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToDiseaseAssociation","biolink:GeneToDiseaseAssociation"]] = Field(["biolink:GeneToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class CausalGeneToDiseaseAssociation(GeneToDiseaseAssociation, GeneToEntityAssociationMixin, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to disease association mixin',
                    'gene to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'disease'},
                        'subject': {'description': 'gene in which variation is shown '
                                                   'to cause the disease.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""gene in which variation is shown to cause the disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CausalGeneToDiseaseAssociation","biolink:CausalGeneToDiseaseAssociation"]] = Field(["biolink:CausalGeneToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class CorrelatedGeneToDiseaseAssociation(GeneToDiseaseAssociation, GeneToEntityAssociationMixin, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to disease association mixin',
                    'gene to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'disease'},
                        'subject': {'description': 'gene in which variation is shown '
                                                   'to correlate with the disease.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""gene in which variation is shown to correlate with the disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CorrelatedGeneToDiseaseAssociation","biolink:CorrelatedGeneToDiseaseAssociation"]] = Field(["biolink:CorrelatedGeneToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class DruggableGeneToDiseaseAssociation(GeneToDiseaseAssociation, GeneToEntityAssociationMixin, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object', 'predicate'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to disease association mixin',
                    'gene to entity association mixin'],
         'slot_usage': {'has evidence': {'name': 'has evidence',
                                         'range': 'DruggableGeneCategoryEnum'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'target for'},
                        'subject': {'description': 'gene in which variation is '
                                                   'correlated with the disease in a '
                                                   'protective manner, or if the '
                                                   'product produced by the gene can '
                                                   'be targeted by a small molecule '
                                                   'and this leads to a protective or '
                                                   'improving disease state.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""gene in which variation is correlated with the disease in a protective manner, or if the product produced by the gene can be targeted by a small molecule and this leads to a protective or improving disease state.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'target for'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[DruggableGeneCategoryEnum]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/DruggableGeneToDiseaseAssociation","biolink:DruggableGeneToDiseaseAssociation"]] = Field(["biolink:DruggableGeneToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class PhenotypicFeatureToDiseaseAssociation(EntityToDiseaseAssociationMixin, PhenotypicFeatureToEntityAssociationMixin, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['entity to disease association mixin',
                    'phenotypic feature to entity association mixin'],
         'slot_usage': {'predicate': {'name': 'predicate',
                                      'subproperty_of': 'associated with'}}})

    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'associated with'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PhenotypicFeatureToDiseaseAssociation","biolink:PhenotypicFeatureToDiseaseAssociation"]] = Field(["biolink:PhenotypicFeatureToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class VariantToGeneAssociation(VariantToEntityAssociationMixin, Association):
    """
    An association between a variant and a gene, where the variant has a genetic association with the gene (i.e. is in linkage disequilibrium)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['variant to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'gene'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'genetically associated with'}}})

    subject: str = Field(..., description="""a sequence variant in which the allele state is associated with some other entity""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'CLINVAR representation of '
                                      'NM_000059.3(BRCA2):c.7007G>A (p.Arg2336His)',
                       'value': 'CLINVAR:38077'},
                      {'description': 'chr13:g.32921033G>C (hg19) in ClinGen',
                       'value': 'ClinGen:CA024716'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'genetically associated with'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/VariantToGeneAssociation","biolink:VariantToGeneAssociation"]] = Field(["biolink:VariantToGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class VariantToGeneExpressionAssociation(VariantToGeneAssociation, GeneExpressionMixin):
    """
    An association between a variant and expression of a gene (i.e. e-QTL)
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['gene expression mixin'],
         'slot_usage': {'predicate': {'name': 'predicate',
                                      'subproperty_of': 'affects'}}})

    quantifier_qualifier: Optional[str] = Field(None, description="""Optional quantitative value indicating degree of expression.""", json_schema_extra = { "linkml_meta": {'alias': 'quantifier_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'is_a': 'association slot',
         'narrow_mappings': ['LOINC:analyzes',
                             'LOINC:measured_by',
                             'LOINC:property_of',
                             'SEMMEDDB:MEASURES',
                             'UMLS:measures']} })
    expression_site: Optional[str] = Field(None, description="""location in which gene or protein expression takes place. May be cell, tissue, or organ.""", json_schema_extra = { "linkml_meta": {'alias': 'expression_site',
         'domain': 'association',
         'domain_of': ['gene expression mixin'],
         'examples': [{'description': 'cerebellum', 'value': 'UBERON:0002037'}],
         'is_a': 'association slot'} })
    stage_qualifier: Optional[str] = Field(None, description="""stage during which gene or protein expression of takes place.""", json_schema_extra = { "linkml_meta": {'alias': 'stage_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'examples': [{'description': 'larval stage', 'value': 'UBERON:0000069'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    phenotypic_state: Optional[str] = Field(None, description="""in experiments (e.g. gene expression) assaying diseased or unhealthy tissue, the phenotypic state can be put here, e.g. MONDO ID. For healthy tissues, use XXX.""", json_schema_extra = { "linkml_meta": {'alias': 'phenotypic_state',
         'domain': 'association',
         'domain_of': ['gene expression mixin'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""a sequence variant in which the allele state is associated with some other entity""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'CLINVAR representation of '
                                      'NM_000059.3(BRCA2):c.7007G>A (p.Arg2336His)',
                       'value': 'CLINVAR:38077'},
                      {'description': 'chr13:g.32921033G>C (hg19) in ClinGen',
                       'value': 'ClinGen:CA024716'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'affects'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/VariantToGeneExpressionAssociation","biolink:VariantToGeneExpressionAssociation"]] = Field(["biolink:VariantToGeneExpressionAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class VariantToPopulationAssociation(VariantToEntityAssociationMixin, FrequencyQualifierMixin, Association, FrequencyQuantifier):
    """
    An association between a variant and a population, where the variant has particular frequency in the population
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['variant to entity association mixin',
                    'frequency quantifier',
                    'frequency qualifier mixin'],
         'slot_usage': {'has count': {'description': 'number in object population that '
                                                     'carry a particular allele, aka '
                                                     'allele count',
                                      'examples': [{'description': '4 individuals in '
                                                                   'gnomad set',
                                                    'value': '4'}],
                                      'name': 'has count'},
                        'has quotient': {'description': 'frequency of allele in '
                                                        'population, expressed as a '
                                                        'number with allele divided by '
                                                        'number in reference '
                                                        'population, aka allele '
                                                        'frequency',
                                         'examples': [{'value': '0.0001666'}],
                                         'name': 'has quotient'},
                        'has total': {'description': 'number all populations that '
                                                     'carry a particular allele, aka '
                                                     'allele number',
                                      'examples': [{'description': '24014 individuals '
                                                                   'in gnomad set',
                                                    'value': '24014'}],
                                      'name': 'has total'},
                        'object': {'description': 'the population that is observed to '
                                                  'have the frequency',
                                   'examples': [{'description': 'African',
                                                 'value': 'HANCESTRO:0010'}],
                                   'name': 'object',
                                   'range': 'population of individual organisms'},
                        'subject': {'description': 'an allele that has a certain '
                                                   'frequency in a given population',
                                    'examples': [{'description': '17:41203088 A/C in '
                                                                 'gnomad',
                                                  'value': 'NC_000017.11:g.43051071A>T'}],
                                    'name': 'subject',
                                    'range': 'sequence variant'}}})

    subject: str = Field(..., description="""an allele that has a certain frequency in a given population""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': '17:41203088 A/C in gnomad',
                       'value': 'NC_000017.11:g.43051071A>T'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the population that is observed to have the frequency""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'African', 'value': 'HANCESTRO:0010'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    has_count: Optional[int] = Field(None, description="""number in object population that carry a particular allele, aka allele count""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'examples': [{'description': '4 individuals in gnomad set', 'value': '4'}],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""number all populations that carry a particular allele, aka allele number""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'examples': [{'description': '24014 individuals in gnomad set',
                       'value': '24014'}],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, description="""frequency of allele in population, expressed as a number with allele divided by number in reference population, aka allele frequency""", json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'examples': [{'value': '0.0001666'}],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/VariantToPopulationAssociation","biolink:VariantToPopulationAssociation"]] = Field(["biolink:VariantToPopulationAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class PopulationToPopulationAssociation(Association):
    """
    An association between a two populations
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'the population that form the object '
                                                  'of the association',
                                   'name': 'object',
                                   'range': 'population of individual organisms'},
                        'predicate': {'description': 'A relationship type that holds '
                                                     'between the subject and object '
                                                     'populations. Standard '
                                                     'mereological relations can be '
                                                     'used. E.g. subject part-of '
                                                     'object, subject overlaps object. '
                                                     'Derivation relationships can '
                                                     'also be used',
                                      'name': 'predicate'},
                        'subject': {'description': 'the population that form the '
                                                   'subject of the association',
                                    'name': 'subject',
                                    'range': 'population of individual organisms'}}})

    subject: str = Field(..., description="""the population that form the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A relationship type that holds between the subject and object populations. Standard mereological relations can be used. E.g. subject part-of object, subject overlaps object. Derivation relationships can also be used""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the population that form the object of the association""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/PopulationToPopulationAssociation","biolink:PopulationToPopulationAssociation"]] = Field(["biolink:PopulationToPopulationAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class VariantToPhenotypicFeatureAssociation(VariantToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['variant to entity association mixin',
                    'entity to phenotypic feature association mixin'],
         'slot_usage': {'subject': {'description': 'a sequence variant in which the '
                                                   'allele state is associated in some '
                                                   'way with the phenotype state',
                                    'name': 'subject',
                                    'range': 'sequence variant'}}})

    subject: str = Field(..., description="""a sequence variant in which the allele state is associated in some way with the phenotype state""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'CLINVAR representation of '
                                      'NM_000059.3(BRCA2):c.7007G>A (p.Arg2336His)',
                       'value': 'CLINVAR:38077'},
                      {'description': 'chr13:g.32921033G>C (hg19) in ClinGen',
                       'value': 'ClinGen:CA024716'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Hyperkinesis', 'value': 'HP:0002487'},
                      {'description': 'axon morphology variant',
                       'value': 'WBPhenotype:0000180'},
                      {'description': 'abnormal circulating bilirubin level',
                       'value': 'MP:0001569'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/VariantToPhenotypicFeatureAssociation","biolink:VariantToPhenotypicFeatureAssociation"]] = Field(["biolink:VariantToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class VariantToDiseaseAssociation(VariantToEntityAssociationMixin, EntityToDiseaseAssociationMixin, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'comments': ['TODO decide no how to model pathogenicity'],
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['variant to entity association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'object': {'description': 'a disease that is associated with '
                                                  'that variant',
                                   'examples': [{'description': 'hereditary breast '
                                                                'cancer',
                                                 'value': 'MONDO:0016419'}],
                                   'name': 'object'},
                        'predicate': {'description': 'E.g. is pathogenic for',
                                      'name': 'predicate',
                                      'subproperty_of': 'related condition'},
                        'subject': {'description': 'a sequence variant in which the '
                                                   'allele state is associated in some '
                                                   'way with the disease state',
                                    'examples': [{'description': 'NM_000059.3(BRCA2):c.7007G>C '
                                                                 '(p.Arg2336Pro)',
                                                  'value': 'CLINVAR:52241'}],
                                    'name': 'subject'}}})

    subject: str = Field(..., description="""a sequence variant in which the allele state is associated in some way with the disease state""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'NM_000059.3(BRCA2):c.7007G>C (p.Arg2336Pro)',
                       'value': 'CLINVAR:52241'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""E.g. is pathogenic for""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'related condition'} })
    object: str = Field(..., description="""a disease that is associated with that variant""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'hereditary breast cancer',
                       'value': 'MONDO:0016419'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/VariantToDiseaseAssociation","biolink:VariantToDiseaseAssociation"]] = Field(["biolink:VariantToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class GenotypeToDiseaseAssociation(GenotypeToEntityAssociationMixin, EntityToDiseaseAssociationMixin, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'comments': ['TODO decide no how to model pathogenicity'],
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['genotype to entity association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'object': {'description': 'a disease that is associated with '
                                                  'that genotype',
                                   'examples': [{'description': 'hereditary breast '
                                                                'cancer',
                                                 'value': 'MONDO:0016419'}],
                                   'name': 'object'},
                        'predicate': {'description': 'E.g. is pathogenic for',
                                      'name': 'predicate',
                                      'subproperty_of': 'related condition'},
                        'subject': {'description': 'a genotype that is associated in '
                                                   'some way with a disease state',
                                    'name': 'subject'}}})

    subject: str = Field(..., description="""a genotype that is associated in some way with a disease state""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""E.g. is pathogenic for""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'related condition'} })
    object: str = Field(..., description="""a disease that is associated with that genotype""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'hereditary breast cancer',
                       'value': 'MONDO:0016419'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypeToDiseaseAssociation","biolink:GenotypeToDiseaseAssociation"]] = Field(["biolink:GenotypeToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class ModelToDiseaseAssociationMixin(ConfiguredBaseModel):
    """
    This mixin is used for any association class for which the subject (source node) plays the role of a 'model', in that it recapitulates some features of the disease in a way that is useful for studying the disease outside a patient carrying the disease
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'predicate': {'description': 'The relationship to the disease',
                                      'name': 'predicate',
                                      'subproperty_of': 'model of'},
                        'subject': {'description': 'The entity that serves as the '
                                                   'model of the disease. This may be '
                                                   'an organism, a strain of organism, '
                                                   'a genotype or variant that '
                                                   'exhibits similar features, or a '
                                                   'gene that when mutated exhibits '
                                                   'features of the disease',
                                    'name': 'subject'}}})

    subject: str = Field(..., description="""The entity that serves as the model of the disease. This may be an organism, a strain of organism, a genotype or variant that exhibits similar features, or a gene that when mutated exhibits features of the disease""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""The relationship to the disease""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'model of'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class GeneAsAModelOfDiseaseAssociation(ModelToDiseaseAssociationMixin, GeneToDiseaseAssociation, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['model to disease association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'subject': {'description': 'A gene that has a role in modeling '
                                                   'the disease. This may be a model '
                                                   'organism ortholog of a known '
                                                   'disease gene, or it may be a gene '
                                                   'whose mutants recapitulate core '
                                                   'features of the disease.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject: str = Field(..., description="""A gene that has a role in modeling the disease. This may be a model organism ortholog of a known disease gene, or it may be a gene whose mutants recapitulate core features of the disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""The relationship to the disease""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'model of'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneAsAModelOfDiseaseAssociation","biolink:GeneAsAModelOfDiseaseAssociation"]] = Field(["biolink:GeneAsAModelOfDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class VariantAsAModelOfDiseaseAssociation(ModelToDiseaseAssociationMixin, VariantToDiseaseAssociation, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['model to disease association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'subject': {'description': 'A variant that has a role in '
                                                   'modeling the disease.',
                                    'name': 'subject',
                                    'range': 'sequence variant'}}})

    subject: str = Field(..., description="""A variant that has a role in modeling the disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'NM_000059.3(BRCA2):c.7007G>C (p.Arg2336Pro)',
                       'value': 'CLINVAR:52241'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""The relationship to the disease""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'model of'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/VariantAsAModelOfDiseaseAssociation","biolink:VariantAsAModelOfDiseaseAssociation"]] = Field(["biolink:VariantAsAModelOfDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class GenotypeAsAModelOfDiseaseAssociation(ModelToDiseaseAssociationMixin, GenotypeToDiseaseAssociation, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['model to disease association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'subject': {'description': 'A genotype that has a role in '
                                                   'modeling the disease.',
                                    'name': 'subject',
                                    'range': 'genotype'}}})

    subject: str = Field(..., description="""A genotype that has a role in modeling the disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""The relationship to the disease""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'model of'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenotypeAsAModelOfDiseaseAssociation","biolink:GenotypeAsAModelOfDiseaseAssociation"]] = Field(["biolink:GenotypeAsAModelOfDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class CellLineAsAModelOfDiseaseAssociation(ModelToDiseaseAssociationMixin, CellLineToDiseaseOrPhenotypicFeatureAssociation, EntityToDiseaseAssociationMixin):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['model to disease association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'subject': {'description': 'A cell line derived from an '
                                                   'organismal entity with a disease '
                                                   'state that is used as a model of '
                                                   'that disease.',
                                    'name': 'subject',
                                    'range': 'cell line'}}})

    subject: str = Field(..., description="""A cell line derived from an organismal entity with a disease state that is used as a model of that disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""The relationship to the disease""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'model of'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/CellLineAsAModelOfDiseaseAssociation","biolink:CellLineAsAModelOfDiseaseAssociation"]] = Field(["biolink:CellLineAsAModelOfDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class OrganismalEntityAsAModelOfDiseaseAssociation(ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['model to disease association mixin',
                    'entity to disease association mixin'],
         'slot_usage': {'subject': {'description': 'A organismal entity (strain, '
                                                   'breed) with a predisposition to a '
                                                   'disease, or bred/created '
                                                   'specifically to model a disease.',
                                    'name': 'subject',
                                    'range': 'organismal entity'}}})

    subject: str = Field(..., description="""A organismal entity (strain, breed) with a predisposition to a disease, or bred/created specifically to model a disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""The relationship to the disease""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'model of'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismalEntityAsAModelOfDiseaseAssociation","biolink:OrganismalEntityAsAModelOfDiseaseAssociation"]] = Field(["biolink:OrganismalEntityAsAModelOfDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    subject_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class OrganismToOrganismAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'An association between two '
                                                  'individual organisms.',
                                   'name': 'object',
                                   'range': 'individual organism'},
                        'subject': {'name': 'subject', 'range': 'individual organism'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""An association between two individual organisms.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismToOrganismAssociation","biolink:OrganismToOrganismAssociation"]] = Field(["biolink:OrganismToOrganismAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class TaxonToTaxonAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'An association between individuals '
                                                  'of different taxa.',
                                   'name': 'object',
                                   'range': 'organism taxon'},
                        'subject': {'name': 'subject', 'range': 'organism taxon'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""An association between individuals of different taxa.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/TaxonToTaxonAssociation","biolink:TaxonToTaxonAssociation"]] = Field(["biolink:TaxonToTaxonAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneHasVariantThatContributesToDiseaseAssociation(GeneToDiseaseAssociation):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'disease'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'contributes to'},
                        'subject': {'description': 'A gene that has a role in modeling '
                                                   'the disease. This may be a model '
                                                   'organism ortholog of a known '
                                                   'disease gene, or it may be a gene '
                                                   'whose mutants recapitulate core '
                                                   'features of the disease.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    subject_form_or_variant_qualifier: Optional[str] = Field(None, description="""A qualifier that composes with a core subject/object concept to define a specific type, variant, alternative version of this concept. The composed concept remains a subtype or instance of the core concept. For example, the qualifier ‘mutation’ combines with the core concept ‘Gene X’ to express the compose concept ‘a mutation of Gene X’.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_form_or_variant_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical gene interaction association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'gene has variant that contributes to disease association'],
         'examples': [{'value': 'mutation'},
                      {'value': 'late stage'},
                      {'value': 'severe'},
                      {'value': 'transplant'},
                      {'value': 'chemical analog'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'form or variant qualifier'} })
    subject: str = Field(..., description="""A gene that has a role in modeling the disease. This may be a model organism ortholog of a known disease gene, or it may be a gene whose mutants recapitulate core features of the disease.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'COL1A1 (Human)', 'value': 'HGNC:2197'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'contributes to'} })
    object: str = Field(..., description="""disease""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'Ehlers-Danlos syndrome',
                       'value': 'MONDO:0020066'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['upheno', 'hp', 'mp', 'wbphenotype']} })
    subject_aspect_qualifier: Optional[GeneOrGeneProductOrChemicalEntityAspectEnum] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    sex_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.""", json_schema_extra = { "linkml_meta": {'alias': 'sex_qualifier',
         'domain': 'association',
         'domain_of': ['entity to phenotypic feature association mixin',
                       'phenotypic feature to entity association mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneHasVariantThatContributesToDiseaseAssociation","biolink:GeneHasVariantThatContributesToDiseaseAssociation"]] = Field(["biolink:GeneHasVariantThatContributesToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })
    has_count: Optional[int] = Field(None, description="""number of things with a particular property""", json_schema_extra = { "linkml_meta": {'alias': 'has_count',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'exact_mappings': ['LOINC:has_count'],
         'is_a': 'aggregate statistic'} })
    has_total: Optional[int] = Field(None, description="""total number of things in a particular reference set""", json_schema_extra = { "linkml_meta": {'alias': 'has_total',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_quotient: Optional[float] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'has_quotient',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    has_percentage: Optional[float] = Field(None, description="""equivalent to has quotient multiplied by 100""", json_schema_extra = { "linkml_meta": {'alias': 'has_percentage',
         'domain': 'named thing',
         'domain_of': ['frequency quantifier'],
         'is_a': 'aggregate statistic'} })
    subject_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the subject of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'subject_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    object_aspect_qualifier: Optional[str] = Field(None, description="""Composes with the core concept to describe new concepts of a different ontological type. e.g. a process in which the core concept participates, a function/activity/role held by the core concept, or a characteristic/quality that inheres in the core concept.  The purpose of the aspect slot is to indicate what aspect is being affected in an 'affects' association.  This qualifier specifies a change in the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_aspect_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'examples': [{'value': 'stability'},
                      {'value': 'abundance'},
                      {'value': 'expression'},
                      {'value': 'exposure'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'aspect qualifier'} })
    qualified_predicate: Optional[str] = Field(None, description="""Predicate to be used in an association when subject and object qualifiers are present and the full reading of the statement requires a qualification to the predicate in use in order to refine or increase the specificity of the full statement reading.  This qualifier holds a relationship to be used instead of that expressed by the primary predicate, in a ‘full statement’ reading of the association, where qualifier-based semantics are included.  This is necessary only in cases where the primary predicate does not work in a full statement reading.""", json_schema_extra = { "linkml_meta": {'alias': 'qualified_predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin'],
         'is_a': 'qualifier',
         'notes': ['to express the statement that “Chemical X causes increased '
                   'expression of Gene Y”, the core triple is read using the fields '
                   'subject:ChemX, predicate:affects, object:GeneY . . . and the full '
                   'statement is read using the fields subject:ChemX, '
                   'qualified_predicate:causes, object:GeneY, object_aspect: '
                   'expression, object_direction:increased. The predicate ‘affects’ is '
                   'needed for the core triple reading, but does not make sense in the '
                   'full statement reading  (because “Chemical X affects increased '
                   "expression of Gene Y'' is not what we mean to say here: it causes "
                   'increased expression of Gene Y)']} })
    frequency_qualifier: Optional[str] = Field(None, description="""a qualifier used in a phenotypic association to state how frequent the phenotype is observed in the subject""", json_schema_extra = { "linkml_meta": {'alias': 'frequency_qualifier',
         'domain': 'association',
         'domain_of': ['frequency qualifier mixin'],
         'in_subset': ['translator_minimal'],
         'is_a': 'qualifier'} })


class GeneToExpressionSiteAssociation(Association):
    """
    An association between a gene and a gene expression site, possibly qualified by stage/timing info.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'predicate', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'notes': ['TBD: introduce subclasses for distinction between wild-type and '
                   'experimental conditions?'],
         'see_also': ['https://github.com/monarch-initiative/ingest-artifacts/tree/master/sources/BGee'],
         'slot_usage': {'object': {'description': 'location in which the gene is '
                                                  'expressed',
                                   'examples': [{'description': 'cerebellum',
                                                 'value': 'UBERON:0002037'}],
                                   'name': 'object',
                                   'range': 'anatomical entity'},
                        'predicate': {'description': 'expression relationship',
                                      'name': 'predicate',
                                      'subproperty_of': 'expressed in'},
                        'quantifier qualifier': {'description': 'can be used to '
                                                                'indicate magnitude, '
                                                                'or also ranking',
                                                 'name': 'quantifier qualifier'},
                        'stage qualifier': {'description': 'stage at which the gene is '
                                                           'expressed in the site',
                                            'examples': [{'description': 'larval stage',
                                                          'value': 'UBERON:0000069'}],
                                            'name': 'stage qualifier',
                                            'range': 'life stage'},
                        'subject': {'description': 'Gene or gene product positively '
                                                   'within the specified anatomical '
                                                   'entity (or subclass, i.e. cellular '
                                                   'component) location.',
                                    'name': 'subject',
                                    'range': 'gene or gene product'}}})

    stage_qualifier: Optional[str] = Field(None, description="""stage at which the gene is expressed in the site""", json_schema_extra = { "linkml_meta": {'alias': 'stage_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'examples': [{'description': 'larval stage', 'value': 'UBERON:0000069'}],
         'in_subset': ['translator_minimal'],
         'is_a': 'statement qualifier'} })
    quantifier_qualifier: Optional[str] = Field(None, description="""can be used to indicate magnitude, or also ranking""", json_schema_extra = { "linkml_meta": {'alias': 'quantifier_qualifier',
         'domain': 'association',
         'domain_of': ['gene expression mixin', 'gene to expression site association'],
         'is_a': 'association slot',
         'narrow_mappings': ['LOINC:analyzes',
                             'LOINC:measured_by',
                             'LOINC:property_of',
                             'SEMMEDDB:MEASURES',
                             'UMLS:measures']} })
    subject: str = Field(..., description="""Gene or gene product positively within the specified anatomical entity (or subclass, i.e. cellular component) location.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""expression relationship""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'expressed in'} })
    object: str = Field(..., description="""location in which the gene is expressed""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'cerebellum', 'value': 'UBERON:0002037'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToExpressionSiteAssociation","biolink:GeneToExpressionSiteAssociation"]] = Field(["biolink:GeneToExpressionSiteAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SequenceVariantModulatesTreatmentAssociation(Association):
    """
    An association between a sequence variant and a treatment or health intervention. The treatment object itself encompasses both the disease and the drug used.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'comments': ['An alternate way to model the same information could be via a '
                      'qualifier'],
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'treatment whose efficacy is '
                                                  'modulated by the subject variant',
                                   'name': 'object',
                                   'range': 'treatment'},
                        'subject': {'description': 'variant that modulates the '
                                                   'treatment of some disease',
                                    'name': 'subject',
                                    'range': 'sequence variant'}}})

    subject: str = Field(..., description="""variant that modulates the treatment of some disease""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""treatment whose efficacy is modulated by the subject variant""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SequenceVariantModulatesTreatmentAssociation","biolink:SequenceVariantModulatesTreatmentAssociation"]] = Field(["biolink:SequenceVariantModulatesTreatmentAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class FunctionalAssociation(Association):
    """
    An association between a macromolecular machine mixin (gene, gene product or complex of gene products) and either a molecular activity, a biological process or a cellular location in which a function is executed.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'class describing the activity, '
                                                  'process or localization of the gene '
                                                  'product',
                                   'examples': [{'description': 'kinase activity',
                                                 'value': 'GO:0016301'},
                                                {'description': 'postsynaptic membrane',
                                                 'value': 'GO:0045211'}],
                                   'name': 'object',
                                   'range': 'ontology class',
                                   'values_from': ['go']},
                        'subject': {'description': 'gene, product or macromolecular '
                                                   'complex that has the function '
                                                   'associated with the GO term',
                                    'examples': [{'description': 'twist1b',
                                                  'value': 'ZFIN:ZDB-GENE-050417-357'}],
                                    'name': 'subject',
                                    'range': 'macromolecular machine mixin'}}})

    subject: str = Field(..., description="""gene, product or macromolecular complex that has the function associated with the GO term""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'twist1b', 'value': 'ZFIN:ZDB-GENE-050417-357'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""class describing the activity, process or localization of the gene product""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'kinase activity', 'value': 'GO:0016301'},
                      {'description': 'postsynaptic membrane', 'value': 'GO:0045211'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['go']} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/FunctionalAssociation","biolink:FunctionalAssociation"]] = Field(["biolink:FunctionalAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MacromolecularMachineToEntityAssociationMixin(ConfiguredBaseModel):
    """
    an association which has a macromolecular machine mixin as a subject
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'domain': 'macromolecular machine mixin',
                                    'name': 'subject'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'macromolecular machine mixin',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class MacromolecularMachineToMolecularActivityAssociation(MacromolecularMachineToEntityAssociationMixin, FunctionalAssociation):
    """
    A functional association between a macromolecular machine (gene, gene product or complex) and a molecular activity (as represented in the GO molecular function branch), where the entity carries out the activity, or contributes to its execution.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['macromolecular machine to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'molecular activity'}}})

    subject: str = Field(..., description="""gene, product or macromolecular complex that has the function associated with the GO term""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'macromolecular machine mixin',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'twist1b', 'value': 'ZFIN:ZDB-GENE-050417-357'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""class describing the activity, process or localization of the gene product""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'kinase activity', 'value': 'GO:0016301'},
                      {'description': 'postsynaptic membrane', 'value': 'GO:0045211'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['go']} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MacromolecularMachineToMolecularActivityAssociation","biolink:MacromolecularMachineToMolecularActivityAssociation"]] = Field(["biolink:MacromolecularMachineToMolecularActivityAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MacromolecularMachineToBiologicalProcessAssociation(MacromolecularMachineToEntityAssociationMixin, FunctionalAssociation):
    """
    A functional association between a macromolecular machine (gene, gene product or complex) and a biological process or pathway (as represented in the GO biological process branch), where the entity carries out some part of the process, regulates it, or acts upstream of it.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['macromolecular machine to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'biological process'}}})

    subject: str = Field(..., description="""gene, product or macromolecular complex that has the function associated with the GO term""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'macromolecular machine mixin',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'twist1b', 'value': 'ZFIN:ZDB-GENE-050417-357'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""class describing the activity, process or localization of the gene product""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'kinase activity', 'value': 'GO:0016301'},
                      {'description': 'postsynaptic membrane', 'value': 'GO:0045211'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['go']} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MacromolecularMachineToBiologicalProcessAssociation","biolink:MacromolecularMachineToBiologicalProcessAssociation"]] = Field(["biolink:MacromolecularMachineToBiologicalProcessAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MacromolecularMachineToCellularComponentAssociation(MacromolecularMachineToEntityAssociationMixin, FunctionalAssociation):
    """
    A functional association between a macromolecular machine (gene, gene product or complex) and a cellular component (as represented in the GO cellular component branch), where the entity carries out its function in the cellular component.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['macromolecular machine to entity association mixin'],
         'slot_usage': {'object': {'name': 'object', 'range': 'cellular component'}}})

    subject: str = Field(..., description="""gene, product or macromolecular complex that has the function associated with the GO term""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'macromolecular machine mixin',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'twist1b', 'value': 'ZFIN:ZDB-GENE-050417-357'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""class describing the activity, process or localization of the gene product""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'kinase activity', 'value': 'GO:0016301'},
                      {'description': 'postsynaptic membrane', 'value': 'GO:0045211'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['go']} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MacromolecularMachineToCellularComponentAssociation","biolink:MacromolecularMachineToCellularComponentAssociation"]] = Field(["biolink:MacromolecularMachineToCellularComponentAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MolecularActivityToChemicalEntityAssociation(Association):
    """
    Added in response to capturing relationship between microbiome activities as measured via measurements of blood analytes as collected via blood and stool samples
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'chemical entity'},
                        'subject': {'name': 'subject', 'range': 'molecular activity'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MolecularActivityToChemicalEntityAssociation","biolink:MolecularActivityToChemicalEntityAssociation"]] = Field(["biolink:MolecularActivityToChemicalEntityAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class MolecularActivityToMolecularActivityAssociation(Association):
    """
    Added in response to capturing relationship between microbiome activities as measured via measurements of blood analytes as collected via blood and stool samples
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'molecular activity'},
                        'subject': {'name': 'subject', 'range': 'molecular activity'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/MolecularActivityToMolecularActivityAssociation","biolink:MolecularActivityToMolecularActivityAssociation"]] = Field(["biolink:MolecularActivityToMolecularActivityAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneToGoTermAssociation(FunctionalAssociation):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'aliases': ['functional association'],
         'defining_slots': ['subject', 'object'],
         'exact_mappings': ['WBVocab:Gene-GO-Association'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'class describing the activity, '
                                                  'process or localization of the gene '
                                                  'product',
                                   'examples': [{'description': 'kinase activity',
                                                 'value': 'GO:0016301'}],
                                   'name': 'object',
                                   'range': 'ontology class',
                                   'values_from': ['go']},
                        'subject': {'description': 'gene, product or macromolecular '
                                                   'complex that has the function '
                                                   'associated with the GO term',
                                    'examples': [{'description': 'twist1b',
                                                  'value': 'ZFIN:ZDB-GENE-050417-357'}],
                                    'name': 'subject',
                                    'range': 'gene'}}})

    subject: str = Field(..., description="""gene, product or macromolecular complex that has the function associated with the GO term""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'examples': [{'description': 'twist1b', 'value': 'ZFIN:ZDB-GENE-050417-357'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""class describing the activity, process or localization of the gene product""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'examples': [{'description': 'kinase activity', 'value': 'GO:0016301'}],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object',
         'values_from': ['go']} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToGoTermAssociation","biolink:GeneToGoTermAssociation"]] = Field(["biolink:GeneToGoTermAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EntityToDiseaseAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    clinical_approval_status: Optional[ClinicalApprovalStatusEnum] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'clinical_approval_status',
         'domain': 'association',
         'domain_of': ['entity to disease association',
                       'entity to phenotypic feature association'],
         'is_a': 'association slot'} })
    max_research_phase: Optional[MaxResearchPhaseEnum] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'max_research_phase',
         'domain': 'association',
         'domain_of': ['entity to disease association',
                       'entity to phenotypic feature association'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EntityToDiseaseAssociation","biolink:EntityToDiseaseAssociation"]] = Field(["biolink:EntityToDiseaseAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class EntityToPhenotypicFeatureAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model'})

    clinical_approval_status: Optional[ClinicalApprovalStatusEnum] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'clinical_approval_status',
         'domain': 'association',
         'domain_of': ['entity to disease association',
                       'entity to phenotypic feature association'],
         'is_a': 'association slot'} })
    max_research_phase: Optional[MaxResearchPhaseEnum] = Field(None, json_schema_extra = { "linkml_meta": {'alias': 'max_research_phase',
         'domain': 'association',
         'domain_of': ['entity to disease association',
                       'entity to phenotypic feature association'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/EntityToPhenotypicFeatureAssociation","biolink:EntityToPhenotypicFeatureAssociation"]] = Field(["biolink:EntityToPhenotypicFeatureAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SequenceAssociation(Association):
    """
    An association between a sequence feature and a nucleic acid entity it is localized to.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model'})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SequenceAssociation","biolink:SequenceAssociation"]] = Field(["biolink:SequenceAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GenomicSequenceLocalization(SequenceAssociation):
    """
    A relationship between a sequence feature and a nucleic acid entity it is localized to. The reference entity may be a chromosome, chromosome region or information entity such as a contig.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'broad_mappings': ['dcid:Chromosome'],
         'exact_mappings': ['dcid:GenomeAnnotation'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'aliases': ['reference'],
                                   'name': 'object',
                                   'range': 'nucleic acid entity'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has sequence location'},
                        'subject': {'aliases': ['sequence feature'],
                                    'name': 'subject',
                                    'range': 'nucleic acid entity'}}})

    start_interbase_coordinate: Optional[int] = Field(None, description="""The position at which the subject nucleic acid entity starts on the chromosome or other entity to which it is located on. (ie: the start of the sequence being referenced is 0).""", json_schema_extra = { "linkml_meta": {'alias': 'start_interbase_coordinate',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'end interbase coordinate'}},
         'close_mappings': ['faldo:begin'],
         'domain': 'genomic sequence localization',
         'domain_of': ['genomic sequence localization'],
         'is_a': 'interbase coordinate'} })
    end_interbase_coordinate: Optional[int] = Field(None, description="""The position at which the subject nucleic acid entity ends on the chromosome or other entity to which it is located on.""", json_schema_extra = { "linkml_meta": {'alias': 'end_interbase_coordinate',
         'annotations': {'opposite_of': {'tag': 'opposite_of',
                                         'value': 'start interbase coordinate'}},
         'close_mappings': ['faldo:end'],
         'domain': 'genomic sequence localization',
         'domain_of': ['genomic sequence localization'],
         'is_a': 'interbase coordinate'} })
    genome_build: Optional[StrandEnum] = Field(None, description="""The version of the genome on which a feature is located. For example, GRCh38 for Homo sapiens.""", json_schema_extra = { "linkml_meta": {'alias': 'genome_build',
         'domain': 'genomic sequence localization',
         'domain_of': ['genomic sequence localization'],
         'exact_mappings': ['gff3:strand'],
         'is_a': 'sequence localization attribute'} })
    strand: Optional[StrandEnum] = Field(None, description="""The strand on which a feature is located. Has a value of '+' (sense strand or forward strand) or '-' (anti-sense strand or reverse strand).""", json_schema_extra = { "linkml_meta": {'alias': 'strand',
         'domain': 'genomic sequence localization',
         'domain_of': ['genomic sequence localization'],
         'exact_mappings': ['gff3:strand'],
         'is_a': 'sequence localization attribute'} })
    phase: Optional[PhaseEnum] = Field(None, description="""The phase for a coding sequence entity. For example, phase of a CDS as represented in a GFF3 with a value of 0, 1 or 2.""", json_schema_extra = { "linkml_meta": {'alias': 'phase',
         'domain': 'coding sequence',
         'domain_of': ['genomic sequence localization'],
         'exact_mappings': ['gff3:phase'],
         'is_a': 'sequence localization attribute'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'aliases': ['sequence feature'],
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has sequence location'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'aliases': ['reference'],
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GenomicSequenceLocalization","biolink:GenomicSequenceLocalization"]] = Field(["biolink:GenomicSequenceLocalization"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class SequenceFeatureRelationship(Association):
    """
    For example, a particular exon is part of a particular transcript or gene
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'exact_mappings': ['CHADO:feature_relationship'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'nucleic acid entity'},
                        'subject': {'name': 'subject', 'range': 'nucleic acid entity'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/SequenceFeatureRelationship","biolink:SequenceFeatureRelationship"]] = Field(["biolink:SequenceFeatureRelationship"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class TranscriptToGeneRelationship(SequenceFeatureRelationship):
    """
    A gene is a collection of transcripts
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'gene'},
                        'subject': {'name': 'subject', 'range': 'transcript'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/TranscriptToGeneRelationship","biolink:TranscriptToGeneRelationship"]] = Field(["biolink:TranscriptToGeneRelationship"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class GeneToGeneProductRelationship(SequenceFeatureRelationship):
    """
    A gene is transcribed and potentially translated to a gene product
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'gene product mixin'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'has gene product'},
                        'subject': {'name': 'subject', 'range': 'gene'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'has gene product'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/GeneToGeneProductRelationship","biolink:GeneToGeneProductRelationship"]] = Field(["biolink:GeneToGeneProductRelationship"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ExonToTranscriptRelationship(SequenceFeatureRelationship):
    """
    A transcript is formed from multiple exons
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'transcript'},
                        'subject': {'name': 'subject', 'range': 'exon'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ExonToTranscriptRelationship","biolink:ExonToTranscriptRelationship"]] = Field(["biolink:ExonToTranscriptRelationship"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation(Association):
    """
    A regulatory relationship between two genes
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object',
                                   'range': 'gene or gene product',
                                   'role': 'regulated gene'},
                        'object direction qualifier': {'name': 'object direction '
                                                               'qualifier',
                                                       'range': 'DirectionQualifierEnum'},
                        'predicate': {'description': 'the direction is always from '
                                                     'regulator to regulated',
                                      'name': 'predicate',
                                      'subproperty_of': 'regulates'},
                        'subject': {'name': 'subject',
                                    'range': 'chemical entity or gene or gene product',
                                    'role': 'regulatory gene'}}})

    object_direction_qualifier: Optional[DirectionQualifierEnum] = Field(None, description="""Composes with the core concept (+ aspect if provided) to describe a change in its direction or degree. This qualifier qualifies the object of an association (aka: statement).""", json_schema_extra = { "linkml_meta": {'alias': 'object_direction_qualifier',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'gene regulates gene association',
                       'chemical affects gene association',
                       'gene affects chemical association',
                       'entity to feature or disease qualifiers mixin',
                       'feature or disease qualifiers to entity mixin',
                       'gene to disease or phenotypic feature association',
                       'chemical entity or gene or gene product regulates gene '
                       'association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'direction qualifier'} })
    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'role': 'regulatory gene',
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""the direction is always from regulator to regulated""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'regulates'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'role': 'regulated gene',
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation","biolink:ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation"]] = Field(["biolink:ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class AnatomicalEntityToAnatomicalEntityAssociation(Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'name': 'object', 'range': 'anatomical entity'},
                        'subject': {'name': 'subject', 'range': 'anatomical entity'}}})

    subject: str = Field(..., description="""connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/AnatomicalEntityToAnatomicalEntityAssociation","biolink:AnatomicalEntityToAnatomicalEntityAssociation"]] = Field(["biolink:AnatomicalEntityToAnatomicalEntityAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class AnatomicalEntityToAnatomicalEntityPartOfAssociation(AnatomicalEntityToAnatomicalEntityAssociation):
    """
    A relationship between two anatomical entities where the relationship is mereological, i.e the two entities are related by parthood. This includes relationships between cellular components and cells, between cells and tissues, tissues and whole organisms
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['predicate'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'the whole',
                                   'name': 'object',
                                   'range': 'anatomical entity'},
                        'predicate': {'name': 'predicate', 'subproperty_of': 'part of'},
                        'subject': {'description': 'the part',
                                    'name': 'subject',
                                    'range': 'anatomical entity'}}})

    subject: str = Field(..., description="""the part""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'part of'} })
    object: str = Field(..., description="""the whole""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/AnatomicalEntityToAnatomicalEntityPartOfAssociation","biolink:AnatomicalEntityToAnatomicalEntityPartOfAssociation"]] = Field(["biolink:AnatomicalEntityToAnatomicalEntityPartOfAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class AnatomicalEntityToAnatomicalEntityOntogenicAssociation(AnatomicalEntityToAnatomicalEntityAssociation):
    """
    A relationship between two anatomical entities where the relationship is ontogenic, i.e. the two entities are related by development. A number of different relationship types can be used to specify the precise nature of the relationship.
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['predicate'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'the structure at an earlier time',
                                   'name': 'object',
                                   'range': 'anatomical entity'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'develops from'},
                        'subject': {'description': 'the structure at a later time',
                                    'name': 'subject',
                                    'range': 'anatomical entity'}}})

    subject: str = Field(..., description="""the structure at a later time""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'develops from'} })
    object: str = Field(..., description="""the structure at an earlier time""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/AnatomicalEntityToAnatomicalEntityOntogenicAssociation","biolink:AnatomicalEntityToAnatomicalEntityOntogenicAssociation"]] = Field(["biolink:AnatomicalEntityToAnatomicalEntityOntogenicAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class OrganismTaxonToEntityAssociation(ConfiguredBaseModel):
    """
    An association between an organism taxon and another entity
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['subject'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixin': True,
         'slot_usage': {'subject': {'description': 'organism taxon that is the subject '
                                                   'of the association',
                                    'name': 'subject',
                                    'range': 'organism taxon'}}})

    subject: str = Field(..., description="""organism taxon that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })


class OrganismTaxonToOrganismTaxonAssociation(OrganismTaxonToEntityAssociation, Association):
    """
    A relationship between two organism taxon nodes
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'defining_slots': ['subject', 'object'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['organism taxon to entity association'],
         'slot_usage': {'object': {'name': 'object', 'range': 'organism taxon'},
                        'subject': {'name': 'subject', 'range': 'organism taxon'}}})

    subject: str = Field(..., description="""organism taxon that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""connects an association to the object of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismTaxonToOrganismTaxonAssociation","biolink:OrganismTaxonToOrganismTaxonAssociation"]] = Field(["biolink:OrganismTaxonToOrganismTaxonAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class OrganismTaxonToOrganismTaxonSpecialization(OrganismTaxonToOrganismTaxonAssociation):
    """
    A child-parent relationship between two taxa. For example: Homo sapiens subclass_of Homo
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['predicate'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'object': {'description': 'the more general taxon',
                                   'name': 'object',
                                   'range': 'organism taxon',
                                   'role': 'parent taxon'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'subclass of'},
                        'subject': {'description': 'the more specific taxon',
                                    'name': 'subject',
                                    'range': 'organism taxon',
                                    'role': 'child taxon'}}})

    subject: str = Field(..., description="""the more specific taxon""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'role': 'child taxon',
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'subclass of'} })
    object: str = Field(..., description="""the more general taxon""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'role': 'parent taxon',
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismTaxonToOrganismTaxonSpecialization","biolink:OrganismTaxonToOrganismTaxonSpecialization"]] = Field(["biolink:OrganismTaxonToOrganismTaxonSpecialization"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class OrganismTaxonToOrganismTaxonInteraction(OrganismTaxonToOrganismTaxonAssociation):
    """
    An interaction relationship between two taxa. This may be a symbiotic relationship (encompassing mutualism and parasitism), or it may be non-symbiotic. Example: plague transmitted_by flea; cattle domesticated_by Homo sapiens; plague infects Homo sapiens
    """
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'defining_slots': ['predicate'],
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'slot_usage': {'associated environmental context': {'description': 'the '
                                                                            'environment '
                                                                            'in which '
                                                                            'the two '
                                                                            'taxa '
                                                                            'interact',
                                                             'name': 'associated '
                                                                     'environmental '
                                                                     'context'},
                        'object': {'description': 'the taxon that is the subject of '
                                                  'the association',
                                   'name': 'object',
                                   'range': 'organism taxon',
                                   'role': 'interactee taxon'},
                        'predicate': {'name': 'predicate',
                                      'subproperty_of': 'interacts with'},
                        'subject': {'description': 'the taxon that is the subject of '
                                                   'the association',
                                    'name': 'subject',
                                    'range': 'organism taxon',
                                    'role': 'interactor taxon'}}})

    associated_environmental_context: Optional[str] = Field(None, description="""the environment in which the two taxa interact""", json_schema_extra = { "linkml_meta": {'alias': 'associated_environmental_context',
         'domain': 'association',
         'domain_of': ['organism taxon to organism taxon interaction'],
         'is_a': 'association slot'} })
    subject: str = Field(..., description="""the taxon that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'role': 'interactor taxon',
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate',
         'subproperty_of': 'interacts with'} })
    object: str = Field(..., description="""the taxon that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'role': 'interactee taxon',
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismTaxonToOrganismTaxonInteraction","biolink:OrganismTaxonToOrganismTaxonInteraction"]] = Field(["biolink:OrganismTaxonToOrganismTaxonInteraction"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


class OrganismTaxonToEnvironmentAssociation(OrganismTaxonToEntityAssociation, Association):
    linkml_meta: ClassVar[LinkMLMeta] = LinkMLMeta({'abstract': True,
         'from_schema': 'https://w3id.org/biolink/biolink-model',
         'mixins': ['organism taxon to entity association'],
         'slot_usage': {'object': {'description': 'the environment in which the '
                                                  'organism occurs',
                                   'name': 'object',
                                   'role': 'environmental context'},
                        'predicate': {'description': 'predicate describing the '
                                                     'relationship between the taxon '
                                                     'and the environment',
                                      'name': 'predicate'},
                        'subject': {'description': 'the taxon that is the subject of '
                                                   'the association',
                                    'name': 'subject',
                                    'range': 'organism taxon',
                                    'role': 'interactor taxon'}}})

    subject: str = Field(..., description="""the taxon that is the subject of the association""", json_schema_extra = { "linkml_meta": {'alias': 'subject',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedSource', 'OBAN:association_has_subject'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation subject'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with outgoing '
                                                       'relationship'}},
         'role': 'interactor taxon',
         'slot_uri': 'rdf:subject'} })
    predicate: str = Field(..., description="""predicate describing the relationship between the taxon and the environment""", json_schema_extra = { "linkml_meta": {'alias': 'predicate',
         'domain': 'association',
         'domain_of': ['predicate mapping',
                       'association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedProperty', 'OBAN:association_has_predicate'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation predicate'},
                         'translator': {'local_name_source': 'translator',
                                        'local_name_value': 'predicate'}},
         'notes': ['Has a value from the Biolink related_to hierarchy. In RDF,  this '
                   'corresponds to rdf:predicate and in Neo4j this corresponds to the '
                   'relationship type. The convention is for an edge label in '
                   'snake_case form. For example, biolink:related_to, biolink:causes, '
                   'biolink:treats'],
         'slot_uri': 'rdf:predicate'} })
    object: str = Field(..., description="""the environment in which the organism occurs""", json_schema_extra = { "linkml_meta": {'alias': 'object',
         'domain': 'association',
         'domain_of': ['association',
                       'cell line to entity association mixin',
                       'chemical entity to entity association mixin',
                       'drug to entity association mixin',
                       'chemical to entity association mixin',
                       'case to entity association mixin',
                       'chemical to chemical association',
                       'named thing associated with likelihood of named thing '
                       'association',
                       'material sample to entity association mixin',
                       'material sample derivation association',
                       'disease to entity association mixin',
                       'entity to exposure event association mixin',
                       'entity to outcome association mixin',
                       'frequency qualifier mixin',
                       'entity to phenotypic feature association mixin',
                       'disease or phenotypic feature to entity association mixin',
                       'entity to disease or phenotypic feature association mixin',
                       'genotype to entity association mixin',
                       'gene to entity association mixin',
                       'variant to entity association mixin',
                       'model to disease association mixin',
                       'macromolecular machine to entity association mixin',
                       'organism taxon to entity association'],
         'exact_mappings': ['owl:annotatedTarget', 'OBAN:association_has_object'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'descriptor'},
                         'neo4j': {'local_name_source': 'neo4j',
                                   'local_name_value': 'node with incoming '
                                                       'relationship'}},
         'role': 'environmental context',
         'slot_uri': 'rdf:object'} })
    negated: Optional[bool] = Field(None, description="""if set to true, then the association is negated i.e. is not true""", json_schema_extra = { "linkml_meta": {'alias': 'negated',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    qualifier: Optional[str] = Field(None, description="""grouping slot for all qualifiers on an edge.  useful for testing compliance with association classes""", json_schema_extra = { "linkml_meta": {'alias': 'qualifier',
         'domain': 'association',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal'],
         'is_a': 'association slot'} })
    qualifiers: Optional[List[str]] = Field(None, description="""connects an association to qualifiers that modify or qualify the meaning of that association""", json_schema_extra = { "linkml_meta": {'alias': 'qualifiers',
         'deprecated': 'True',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot',
         'local_names': {'ga4gh': {'local_name_source': 'ga4gh',
                                   'local_name_value': 'annotation qualifier'}}} })
    publications: Optional[List[str]] = Field(None, description="""One or more publications that report the statement expressed in an Association, or provide information used as evidence supporting this statement.""", json_schema_extra = { "linkml_meta": {'alias': 'publications',
         'aliases': ['supporting publications', 'supporting documents'],
         'comments': ['The notion of a ‘Publication’ is considered broadly to include '
                      'any document made available for public consumption. It covers '
                      'journal issues, individual articles, and books - and also '
                      'things like article pre-prints, white papers, patents, drug '
                      'labels, web pages, protocol documents, etc.'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    has_evidence: Optional[List[str]] = Field(None, description="""connects an association to an instance of supporting evidence""", json_schema_extra = { "linkml_meta": {'alias': 'has_evidence',
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['RO:0002558'],
         'is_a': 'association slot'} })
    knowledge_source: Optional[str] = Field(None, description="""An Information Resource from which the knowledge expressed in an Association was retrieved, directly or indirectly. This can be any resource through which the knowledge passed on its way to its currently serialized form. In practice, implementers should use one of the more specific subtypes of this generic property.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_source',
         'close_mappings': ['pav:providedBy'],
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    primary_knowledge_source: Optional[str] = Field(None, description="""The most upstream source of the knowledge expressed in an Association that an implementer can identify.  Performing a rigorous analysis of upstream data providers is expected; every effort is made to catalog the most upstream source of data in this property.  Only one data source should be declared primary in any association.  \"aggregator knowledge source\" can be used to capture non-primary sources.""", json_schema_extra = { "linkml_meta": {'alias': 'primary_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example: a single ChemicalToGene Edge originally curated by '
                   'ClinicalTrials.org, is aggregated by ChEMBL, then incorporated '
                   'into the MolePro KP, then sent via TRAPI message to the ARAGORN '
                   'ARA, and finally sent to the NCATS ARS. The retrieval path for '
                   'this Edge is as follows: ARS--retrieved_from-->  ARAGORN  '
                   '--retrieved_from-->   MolePro  --retrieved_from--> ChEMBL '
                   '--retrieved_from-->  ClinicalTrials.gov The "primary knowledge '
                   'source" for this edge is "infores:clinical-trials-gov".  '
                   '"infores:chembl" and "infores:molecular_data_provider" are listed '
                   'in the "aggregator knowledge source" property.']} })
    aggregator_knowledge_source: Optional[List[str]] = Field(None, description="""An intermediate aggregator resource from which knowledge expressed in an Association was retrieved downstream of the original source, on its path to its current serialized form.""", json_schema_extra = { "linkml_meta": {'alias': 'aggregator_knowledge_source',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'knowledge source',
         'notes': ['For example, in this Feature Variable Association Edge generated '
                   'by the Exposure Agent’s ICEES KP, through statistical analysis of '
                   'clinical and environmental data supplied by the UNC Clinical Data '
                   'Warehouse, the Edge is passed to the Ranking Agent’s ARAGORN ARA, '
                   'and then on to the ARS. The retrieval path for this Edge is as '
                   'follows: ARS--retrieved_from-->  ARAGORN  --retrieved_from-->   '
                   'ICEES --supporting_data_from-->  UNC Data Warehouse This example '
                   'illustrates how to represent the source provenance of KP-generated '
                   'knowledge, including the source of data from which the knowledge '
                   'was derived. The "primary knowledge source" for this edge is '
                   '"infores:icees-asthma". A "supporting data source" for this KP- '
                   'generated knowledge is "infores:unc-cdw-health."  The "aggregator '
                   'knowledge source" for this data is "infores:aragorn-ara"']} })
    knowledge_level: KnowledgeLevelEnum = Field(KnowledgeLevelEnum.not_provided, description="""Describes the level of knowledge expressed in a statement, based on the reasoning or analysis methods used to generate the statement, or the scope or specificity of what the statement expresses to be true.""", json_schema_extra = { "linkml_meta": {'alias': 'knowledge_level',
         'aliases': ['knowledge type'],
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'knowledge_assertion'},
                      {'value': 'prediction'},
                      {'value': 'statistical_association'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ["The notion of a 'level' of knowledge can in one sense relate to "
                   'the strength  of a statement - i.e. how confident we are that it '
                   'says something true about our domain of discourse. Here, we can '
                   'generally consider Assertions to be  stronger than Entailments to '
                   "be stronger than Predictions.  But in another sense, 'level' of "
                   'knowledge can refer to the scope or specificity of what a '
                   'statement expresses - on a spectrum from context-specific results '
                   'of a data analysis, to generalized assertions of knowledge or '
                   'fact. Here, Statistical  Associations and  Observations represent '
                   'more foundational statements that are only  slightly removed from '
                   'the data on which they are based (the former reporting the  direct '
                   'results of  an analysis in terms of correlations between variables '
                   'in the data, and the latter describing phenomena that were '
                   'observed/reported to have occurred).']} })
    agent_type: AgentTypeEnum = Field(AgentTypeEnum.not_provided, description="""Describes the high-level category of agent who originally generated a  statement of knowledge or other type of information.""", json_schema_extra = { "linkml_meta": {'alias': 'agent_type',
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'value': 'manual_agent'},
                      {'value': 'automated_agent'},
                      {'value': 'computational_model'},
                      {'value': 'text_mining_agent'}],
         'ifabsent': 'string(not_provided)',
         'is_a': 'association slot',
         'notes': ['Note that this property indicates the type of agent who produced '
                   'a  final statement of knowledge, which is often different from '
                   'the  agent oragents who produced information used as evidence to  '
                   'support generation of this knowledge. For example, if a human '
                   'curator concludes that a particular gene variant causes a medical '
                   'condition - based on their interpretation of information produced '
                   'by computational  modeling tools, automated data analysis '
                   'pipelines, and robotic laboratory assay systems - the agent_type '
                   "for this statement is 'manual agent' -  despite all of the "
                   'evidence being created by automated agents. But if any of these '
                   'systems is programmed to generate knowledge statements  directly '
                   'and without human assistance, the statement would be attributed  '
                   "to an 'automated_agent'."]} })
    timepoint: Optional[str] = Field(None, description="""a point in time""", json_schema_extra = { "linkml_meta": {'alias': 'timepoint',
         'aliases': ['duration'],
         'domain_of': ['geographic location at time', 'exposure event', 'association']} })
    original_subject: Optional[str] = Field(None, description="""used to hold the original subject of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_subject',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    original_predicate: Optional[str] = Field(None, description="""used to hold the original relation/predicate that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_predicate',
         'aliases': ['original relation', 'relation'],
         'domain': 'association',
         'domain_of': ['association'],
         'id_prefixes': ['RO', 'BSPO', 'SIO'],
         'is_a': 'association slot'} })
    original_object: Optional[str] = Field(None, description="""used to hold the original object of a relation (or predicate) that an external knowledge source uses before transformation to match the biolink-model specification.""", json_schema_extra = { "linkml_meta": {'alias': 'original_object',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    subject_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Gene'.",
                       'value': 'biolink:Gene'}],
         'is_a': 'association slot'} })
    object_category: Optional[str] = Field(None, description="""Used to hold the biolink class/category of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'biolink:Disease'.",
                       'value': 'biolink:Disease'}],
         'is_a': 'association slot'} })
    subject_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'association slot'} })
    object_closure: Optional[List[str]] = Field(None, description="""Used to hold the object closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object closure of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is the set of all diseases that are "
                                      "ancestors of 'breast cancer' in the MONDO "
                                      'ontology.  Note: typically the "subclass of" '
                                      'and "part of" relations are used to construct '
                                      'the closure, but other relations may be used as '
                                      'well.',
                       'value': "['MONDO:0000167', 'MONDO:0005395']"}],
         'is_a': 'association slot'} })
    subject_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Gene' in "
                                      'the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Gene", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    object_category_closure: Optional[List[str]] = Field(None, description="""Used to hold the object category closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_category_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object category closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all biolink "
                                      "classes that are ancestors of 'biolink:Disease' "
                                      'in the biolink model.  Note: typically the '
                                      '"subclass of" and "part of" relations are used '
                                      'to construct the closure, but other relations '
                                      'may be used as well.',
                       'value': '[\'biolink:Disease", "biolink:NamedThing\']'}],
         'is_a': 'association slot'} })
    subject_namespace: Optional[str] = Field(None, description="""Used to hold the subject namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_namespace',
         'aliases': ['subject prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject namespace of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is 'NCBIGene'.",
                       'value': 'NCBIGene'}],
         'is_a': 'association slot'} })
    object_namespace: Optional[str] = Field(None, description="""Used to hold the object namespace of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_namespace',
         'aliases': ['object prefix'],
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object namespace of the association between '
                                      "the gene 'BRCA1' and the disease 'breast "
                                      "cancer' is 'MONDO'.",
                       'value': 'MONDO'}],
         'is_a': 'association slot'} })
    subject_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the subject label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'subject_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The subject label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'BRCA1' in the biolink model.",
                       'value': "['BRACA1']"}],
         'is_a': 'association slot'} })
    object_label_closure: Optional[List[str]] = Field(None, description="""Used to hold the object label closure of an association. This is a denormalized field used primarily in the SQL serialization of a knowledge graph via KGX.""", json_schema_extra = { "linkml_meta": {'alias': 'object_label_closure',
         'annotations': {'denormalized': {'tag': 'denormalized', 'value': True}},
         'domain': 'association',
         'domain_of': ['association'],
         'examples': [{'description': 'The object label closure of the association '
                                      "between the gene 'BRCA1' and the disease "
                                      "'breast cancer' is the set of all labels that "
                                      "are ancestors of 'breast cancer' in the biolink "
                                      'model.',
                       'value': 'breast cancer'},
                      {'value': 'cancer'}],
         'is_a': 'association slot'} })
    retrieval_source_ids: Optional[List[str]] = Field(None, description="""A list of retrieval sources that served as a source of knowledge expressed in an Edge, or a source of data used to generate this knowledge.""", json_schema_extra = { "linkml_meta": {'alias': 'retrieval_source_ids',
         'domain_of': ['association'],
         'in_subset': ['translator_minimal']} })
    p_value: Optional[float] = Field(None, description="""A quantitative confidence value that represents the probability of obtaining a result at least as extreme as that actually obtained, assuming that the actual value was the result of chance alone.""", json_schema_extra = { "linkml_meta": {'alias': 'p_value',
         'aliases': ['unadjusted p value'],
         'domain': 'association',
         'domain_of': ['association'],
         'exact_mappings': ['OBI:0000175', 'NCIT:C44185', 'EDAM-DATA:1669'],
         'is_a': 'association slot'} })
    adjusted_p_value: Optional[float] = Field(None, description="""The adjusted p-value is the probability of obtaining test results at least as extreme as the results actually observed, under the assumption that the null hypothesis is correct, adjusted for multiple comparisons. P is always italicized and capitalized. The actual P value* should be expressed (P=. 04) rather than expressing a statement of inequality (P<. 05), unless P<.""", json_schema_extra = { "linkml_meta": {'alias': 'adjusted_p_value',
         'domain': 'association',
         'domain_of': ['association'],
         'is_a': 'p value'} })
    id: str = Field(..., description="""A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI""", json_schema_extra = { "linkml_meta": {'alias': 'id',
         'domain': 'entity',
         'domain_of': ['ontology class', 'entity'],
         'exact_mappings': ['AGRKB:primaryId', 'gff3:ID', 'gpi:DB_Object_ID'],
         'in_subset': ['translator_minimal']} })
    iri: Optional[str] = Field(None, description="""An IRI for an entity. This is determined by the id using expansion rules.""", json_schema_extra = { "linkml_meta": {'alias': 'iri',
         'domain_of': ['attribute', 'entity'],
         'exact_mappings': ['WIKIDATA_PROPERTY:P854'],
         'in_subset': ['translator_minimal', 'samples']} })
    category: List[Literal["https://w3id.org/biolink/vocab/OrganismTaxonToEnvironmentAssociation","biolink:OrganismTaxonToEnvironmentAssociation"]] = Field(["biolink:OrganismTaxonToEnvironmentAssociation"], description="""Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class. In a neo4j database this MAY correspond to the neo4j label tag. In an RDF database it should be a biolink model class URI. This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`. In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}""", json_schema_extra = { "linkml_meta": {'alias': 'category',
         'designates_type': True,
         'domain': 'entity',
         'domain_of': ['entity'],
         'in_subset': ['translator_minimal'],
         'is_a': 'type',
         'is_class_field': True} })
    type: Optional[List[str]] = Field(None, description="""rdf:type of biolink:Association should be fixed at rdf:Statement""", json_schema_extra = { "linkml_meta": {'alias': 'type',
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['gff3:type', 'gpi:DB_Object_Type'],
         'slot_uri': 'rdf:type'} })
    name: Optional[str] = Field(None, description="""A human-readable name for an attribute or entity.""", json_schema_extra = { "linkml_meta": {'alias': 'name',
         'aliases': ['label', 'display name', 'title'],
         'domain': 'entity',
         'domain_of': ['attribute', 'entity', 'macromolecular machine mixin'],
         'exact_mappings': ['gff3:Name', 'gpi:DB_Object_Name'],
         'in_subset': ['translator_minimal', 'samples'],
         'narrow_mappings': ['dct:title', 'WIKIDATA_PROPERTY:P1476'],
         'slot_uri': 'rdfs:label'} })
    description: Optional[str] = Field(None, description="""a human-readable description of an entity""", json_schema_extra = { "linkml_meta": {'alias': 'description',
         'aliases': ['definition'],
         'domain_of': ['entity'],
         'exact_mappings': ['IAO:0000115', 'skos:definitions'],
         'in_subset': ['translator_minimal'],
         'narrow_mappings': ['gff3:Description'],
         'slot_uri': 'dct:description'} })
    has_attribute: Optional[List[str]] = Field(None, description="""connects any entity to an attribute""", json_schema_extra = { "linkml_meta": {'alias': 'has_attribute',
         'close_mappings': ['OBI:0001927'],
         'domain': 'entity',
         'domain_of': ['entity'],
         'exact_mappings': ['SIO:000008'],
         'in_subset': ['samples'],
         'narrow_mappings': ['OBAN:association_has_subject_property',
                             'OBAN:association_has_object_property',
                             'CPT:has_possibly_included_panel_element',
                             'DRUGBANK:category',
                             'EFO:is_executed_in',
                             'HANCESTRO:0301',
                             'LOINC:has_action_guidance',
                             'LOINC:has_adjustment',
                             'LOINC:has_aggregation_view',
                             'LOINC:has_approach_guidance',
                             'LOINC:has_divisor',
                             'LOINC:has_exam',
                             'LOINC:has_method',
                             'LOINC:has_modality_subtype',
                             'LOINC:has_object_guidance',
                             'LOINC:has_scale',
                             'LOINC:has_suffix',
                             'LOINC:has_time_aspect',
                             'LOINC:has_time_modifier',
                             'LOINC:has_timing_of',
                             'NCIT:R88',
                             'NCIT:eo_disease_has_property_or_attribute',
                             'NCIT:has_data_element',
                             'NCIT:has_pharmaceutical_administration_method',
                             'NCIT:has_pharmaceutical_basic_dose_form',
                             'NCIT:has_pharmaceutical_intended_site',
                             'NCIT:has_pharmaceutical_release_characteristics',
                             'NCIT:has_pharmaceutical_state_of_matter',
                             'NCIT:has_pharmaceutical_transformation',
                             'NCIT:is_qualified_by',
                             'NCIT:qualifier_applies_to',
                             'NCIT:role_has_domain',
                             'NCIT:role_has_range',
                             'INO:0000154',
                             'HANCESTRO:0308',
                             'OMIM:has_inheritance_type',
                             'orphanet:C016',
                             'orphanet:C017',
                             'RO:0000053',
                             'RO:0000086',
                             'RO:0000087',
                             'SNOMED:has_access',
                             'SNOMED:has_clinical_course',
                             'SNOMED:has_count_of_base_of_active_ingredient',
                             'SNOMED:has_dose_form_administration_method',
                             'SNOMED:has_dose_form_release_characteristic',
                             'SNOMED:has_dose_form_transformation',
                             'SNOMED:has_finding_context',
                             'SNOMED:has_finding_informer',
                             'SNOMED:has_inherent_attribute',
                             'SNOMED:has_intent',
                             'SNOMED:has_interpretation',
                             'SNOMED:has_laterality',
                             'SNOMED:has_measurement_method',
                             'SNOMED:has_method',
                             'SNOMED:has_priority',
                             'SNOMED:has_procedure_context',
                             'SNOMED:has_process_duration',
                             'SNOMED:has_property',
                             'SNOMED:has_revision_status',
                             'SNOMED:has_scale_type',
                             'SNOMED:has_severity',
                             'SNOMED:has_specimen',
                             'SNOMED:has_state_of_matter',
                             'SNOMED:has_subject_relationship_context',
                             'SNOMED:has_surgical_approach',
                             'SNOMED:has_technique',
                             'SNOMED:has_temporal_context',
                             'SNOMED:has_time_aspect',
                             'SNOMED:has_units',
                             'UMLS:has_structural_class',
                             'UMLS:has_supported_concept_property',
                             'UMLS:has_supported_concept_relationship',
                             'UMLS:may_be_qualified_by']} })
    deprecated: Optional[bool] = Field(None, description="""A boolean flag indicating that an entity is no longer considered current or valid.""", json_schema_extra = { "linkml_meta": {'alias': 'deprecated',
         'domain_of': ['entity'],
         'exact_mappings': ['oboInOwl:ObsoleteClass']} })


# Model rebuild
# see https://pydantic-docs.helpmanual.io/usage/models/#rebuilding-a-model
MappingCollection.model_rebuild()
PredicateMapping.model_rebuild()
OntologyClass.model_rebuild()
Annotation.model_rebuild()
QuantityValue.model_rebuild()
RelationshipQuantifier.model_rebuild()
SensitivityQuantifier.model_rebuild()
SpecificityQuantifier.model_rebuild()
PathognomonicityQuantifier.model_rebuild()
FrequencyQuantifier.model_rebuild()
ChemicalOrDrugOrTreatment.model_rebuild()
Entity.model_rebuild()
NamedThing.model_rebuild()
Attribute.model_rebuild()
ChemicalRole.model_rebuild()
BiologicalSex.model_rebuild()
PhenotypicSex.model_rebuild()
GenotypicSex.model_rebuild()
SeverityValue.model_rebuild()
RelationshipType.model_rebuild()
TaxonomicRank.model_rebuild()
OrganismTaxon.model_rebuild()
Event.model_rebuild()
AdministrativeEntity.model_rebuild()
Agent.model_rebuild()
InformationContentEntity.model_rebuild()
StudyResult.model_rebuild()
StudyVariable.model_rebuild()
CommonDataElement.model_rebuild()
ConceptCountAnalysisResult.model_rebuild()
ObservedExpectedFrequencyAnalysisResult.model_rebuild()
RelativeFrequencyAnalysisResult.model_rebuild()
TextMiningResult.model_rebuild()
ChiSquaredAnalysisResult.model_rebuild()
LogOddsAnalysisResult.model_rebuild()
Dataset.model_rebuild()
DatasetDistribution.model_rebuild()
DatasetVersion.model_rebuild()
DatasetSummary.model_rebuild()
ConfidenceLevel.model_rebuild()
EvidenceType.model_rebuild()
Publication.model_rebuild()
Book.model_rebuild()
BookChapter.model_rebuild()
Serial.model_rebuild()
Article.model_rebuild()
JournalArticle.model_rebuild()
Patent.model_rebuild()
WebPage.model_rebuild()
PreprintPublication.model_rebuild()
DrugLabel.model_rebuild()
RetrievalSource.model_rebuild()
PhysicalEssenceOrOccurrent.model_rebuild()
PhysicalEssence.model_rebuild()
PhysicalEntity.model_rebuild()
Occurrent.model_rebuild()
ActivityAndBehavior.model_rebuild()
Activity.model_rebuild()
Study.model_rebuild()
Procedure.model_rebuild()
Phenomenon.model_rebuild()
Device.model_rebuild()
DiagnosticAid.model_rebuild()
SubjectOfInvestigation.model_rebuild()
MaterialSample.model_rebuild()
PlanetaryEntity.model_rebuild()
EnvironmentalProcess.model_rebuild()
EnvironmentalFeature.model_rebuild()
GeographicLocation.model_rebuild()
GeographicLocationAtTime.model_rebuild()
ThingWithTaxon.model_rebuild()
BiologicalEntity.model_rebuild()
GenomicEntity.model_rebuild()
EpigenomicEntity.model_rebuild()
BiologicalProcessOrActivity.model_rebuild()
MolecularActivity.model_rebuild()
BiologicalProcess.model_rebuild()
Pathway.model_rebuild()
PhysiologicalProcess.model_rebuild()
Behavior.model_rebuild()
OrganismAttribute.model_rebuild()
PhenotypicQuality.model_rebuild()
GeneticInheritance.model_rebuild()
OrganismalEntity.model_rebuild()
Bacterium.model_rebuild()
Virus.model_rebuild()
CellularOrganism.model_rebuild()
Mammal.model_rebuild()
Human.model_rebuild()
Plant.model_rebuild()
Invertebrate.model_rebuild()
Vertebrate.model_rebuild()
Fungus.model_rebuild()
LifeStage.model_rebuild()
IndividualOrganism.model_rebuild()
PopulationOfIndividualOrganisms.model_rebuild()
StudyPopulation.model_rebuild()
DiseaseOrPhenotypicFeature.model_rebuild()
Disease.model_rebuild()
PhenotypicFeature.model_rebuild()
BehavioralFeature.model_rebuild()
AnatomicalEntity.model_rebuild()
CellularComponent.model_rebuild()
Cell.model_rebuild()
CellLine.model_rebuild()
GrossAnatomicalStructure.model_rebuild()
ChemicalEntityOrGeneOrGeneProduct.model_rebuild()
RegulatoryRegion.model_rebuild()
AccessibleDnaRegion.model_rebuild()
TranscriptionFactorBindingSite.model_rebuild()
ChemicalEntityOrProteinOrPolypeptide.model_rebuild()
ChemicalEntity.model_rebuild()
MolecularEntity.model_rebuild()
SmallMolecule.model_rebuild()
ChemicalMixture.model_rebuild()
NucleicAcidEntity.model_rebuild()
MolecularMixture.model_rebuild()
ComplexMolecularMixture.model_rebuild()
ProcessedMaterial.model_rebuild()
Drug.model_rebuild()
EnvironmentalFoodContaminant.model_rebuild()
FoodAdditive.model_rebuild()
Food.model_rebuild()
MacromolecularMachineMixin.model_rebuild()
GeneOrGeneProduct.model_rebuild()
Gene.model_rebuild()
GeneProductMixin.model_rebuild()
GeneProductIsoformMixin.model_rebuild()
MacromolecularComplex.model_rebuild()
NucleosomeModification.model_rebuild()
Genome.model_rebuild()
Exon.model_rebuild()
Transcript.model_rebuild()
CodingSequence.model_rebuild()
Polypeptide.model_rebuild()
Protein.model_rebuild()
ProteinIsoform.model_rebuild()
PosttranslationalModification.model_rebuild()
NucleicAcidSequenceMotif.model_rebuild()
RNAProduct.model_rebuild()
RNAProductIsoform.model_rebuild()
NoncodingRNAProduct.model_rebuild()
MicroRNA.model_rebuild()
SiRNA.model_rebuild()
GeneGroupingMixin.model_rebuild()
ProteinDomain.model_rebuild()
ProteinFamily.model_rebuild()
GeneFamily.model_rebuild()
Zygosity.model_rebuild()
Genotype.model_rebuild()
Haplotype.model_rebuild()
SequenceVariant.model_rebuild()
Snv.model_rebuild()
ReagentTargetedGene.model_rebuild()
ClinicalAttribute.model_rebuild()
ClinicalMeasurement.model_rebuild()
ClinicalModifier.model_rebuild()
ClinicalCourse.model_rebuild()
Onset.model_rebuild()
ClinicalEntity.model_rebuild()
ClinicalTrial.model_rebuild()
ClinicalIntervention.model_rebuild()
ClinicalFinding.model_rebuild()
Hospitalization.model_rebuild()
SocioeconomicAttribute.model_rebuild()
Case.model_rebuild()
Cohort.model_rebuild()
ExposureEvent.model_rebuild()
GenomicBackgroundExposure.model_rebuild()
PathologicalEntityMixin.model_rebuild()
PathologicalProcess.model_rebuild()
PathologicalProcessExposure.model_rebuild()
PathologicalAnatomicalStructure.model_rebuild()
PathologicalAnatomicalExposure.model_rebuild()
DiseaseOrPhenotypicFeatureExposure.model_rebuild()
ChemicalExposure.model_rebuild()
ComplexChemicalExposure.model_rebuild()
DrugExposure.model_rebuild()
DrugToGeneInteractionExposure.model_rebuild()
Treatment.model_rebuild()
BioticExposure.model_rebuild()
EnvironmentalExposure.model_rebuild()
GeographicExposure.model_rebuild()
BehavioralExposure.model_rebuild()
SocioeconomicExposure.model_rebuild()
Outcome.model_rebuild()
PathologicalProcessOutcome.model_rebuild()
PathologicalAnatomicalOutcome.model_rebuild()
DiseaseOrPhenotypicFeatureOutcome.model_rebuild()
BehavioralOutcome.model_rebuild()
HospitalizationOutcome.model_rebuild()
MortalityOutcome.model_rebuild()
EpidemiologicalOutcome.model_rebuild()
SocioeconomicOutcome.model_rebuild()
Association.model_rebuild()
ChemicalEntityAssessesNamedThingAssociation.model_rebuild()
ContributorAssociation.model_rebuild()
GenotypeToGenotypePartAssociation.model_rebuild()
GenotypeToGeneAssociation.model_rebuild()
GenotypeToVariantAssociation.model_rebuild()
GeneToGeneAssociation.model_rebuild()
GeneToGeneHomologyAssociation.model_rebuild()
GeneToGeneFamilyAssociation.model_rebuild()
GeneExpressionMixin.model_rebuild()
GeneToGeneCoexpressionAssociation.model_rebuild()
PairwiseGeneToGeneInteraction.model_rebuild()
PairwiseMolecularInteraction.model_rebuild()
CellLineToEntityAssociationMixin.model_rebuild()
ChemicalEntityToEntityAssociationMixin.model_rebuild()
DrugToEntityAssociationMixin.model_rebuild()
ChemicalToEntityAssociationMixin.model_rebuild()
CaseToEntityAssociationMixin.model_rebuild()
ChemicalToChemicalAssociation.model_rebuild()
ReactionToParticipantAssociation.model_rebuild()
ReactionToCatalystAssociation.model_rebuild()
ChemicalToChemicalDerivationAssociation.model_rebuild()
MolecularActivityToPathwayAssociation.model_rebuild()
ChemicalToPathwayAssociation.model_rebuild()
NamedThingAssociatedWithLikelihoodOfNamedThingAssociation.model_rebuild()
ChemicalGeneInteractionAssociation.model_rebuild()
GeneRegulatesGeneAssociation.model_rebuild()
ProcessRegulatesProcessAssociation.model_rebuild()
ChemicalAffectsGeneAssociation.model_rebuild()
GeneAffectsChemicalAssociation.model_rebuild()
DrugToGeneAssociation.model_rebuild()
MaterialSampleToEntityAssociationMixin.model_rebuild()
MaterialSampleDerivationAssociation.model_rebuild()
DiseaseToEntityAssociationMixin.model_rebuild()
EntityToExposureEventAssociationMixin.model_rebuild()
DiseaseToExposureEventAssociation.model_rebuild()
EntityToOutcomeAssociationMixin.model_rebuild()
ExposureEventToOutcomeAssociation.model_rebuild()
FrequencyQualifierMixin.model_rebuild()
EntityToFeatureOrDiseaseQualifiersMixin.model_rebuild()
FeatureOrDiseaseQualifiersToEntityMixin.model_rebuild()
EntityToPhenotypicFeatureAssociationMixin.model_rebuild()
PhenotypicFeatureToEntityAssociationMixin.model_rebuild()
PhenotypicFeatureToPhenotypicFeatureAssociation.model_rebuild()
InformationContentEntityToNamedThingAssociation.model_rebuild()
EntityToDiseaseAssociationMixin.model_rebuild()
DiseaseOrPhenotypicFeatureToEntityAssociationMixin.model_rebuild()
DiseaseOrPhenotypicFeatureToLocationAssociation.model_rebuild()
DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation.model_rebuild()
EntityToDiseaseOrPhenotypicFeatureAssociationMixin.model_rebuild()
CellLineToDiseaseOrPhenotypicFeatureAssociation.model_rebuild()
ChemicalToDiseaseOrPhenotypicFeatureAssociation.model_rebuild()
ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation.model_rebuild()
ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation.model_rebuild()
MaterialSampleToDiseaseOrPhenotypicFeatureAssociation.model_rebuild()
GenotypeToEntityAssociationMixin.model_rebuild()
GenotypeToPhenotypicFeatureAssociation.model_rebuild()
ExposureEventToPhenotypicFeatureAssociation.model_rebuild()
DiseaseToPhenotypicFeatureAssociation.model_rebuild()
CaseToPhenotypicFeatureAssociation.model_rebuild()
BehaviorToBehavioralFeatureAssociation.model_rebuild()
GeneToEntityAssociationMixin.model_rebuild()
GeneToPathwayAssociation.model_rebuild()
VariantToEntityAssociationMixin.model_rebuild()
GeneToDiseaseOrPhenotypicFeatureAssociation.model_rebuild()
GeneToPhenotypicFeatureAssociation.model_rebuild()
GeneToDiseaseAssociation.model_rebuild()
CausalGeneToDiseaseAssociation.model_rebuild()
CorrelatedGeneToDiseaseAssociation.model_rebuild()
DruggableGeneToDiseaseAssociation.model_rebuild()
PhenotypicFeatureToDiseaseAssociation.model_rebuild()
VariantToGeneAssociation.model_rebuild()
VariantToGeneExpressionAssociation.model_rebuild()
VariantToPopulationAssociation.model_rebuild()
PopulationToPopulationAssociation.model_rebuild()
VariantToPhenotypicFeatureAssociation.model_rebuild()
VariantToDiseaseAssociation.model_rebuild()
GenotypeToDiseaseAssociation.model_rebuild()
ModelToDiseaseAssociationMixin.model_rebuild()
GeneAsAModelOfDiseaseAssociation.model_rebuild()
VariantAsAModelOfDiseaseAssociation.model_rebuild()
GenotypeAsAModelOfDiseaseAssociation.model_rebuild()
CellLineAsAModelOfDiseaseAssociation.model_rebuild()
OrganismalEntityAsAModelOfDiseaseAssociation.model_rebuild()
OrganismToOrganismAssociation.model_rebuild()
TaxonToTaxonAssociation.model_rebuild()
GeneHasVariantThatContributesToDiseaseAssociation.model_rebuild()
GeneToExpressionSiteAssociation.model_rebuild()
SequenceVariantModulatesTreatmentAssociation.model_rebuild()
FunctionalAssociation.model_rebuild()
MacromolecularMachineToEntityAssociationMixin.model_rebuild()
MacromolecularMachineToMolecularActivityAssociation.model_rebuild()
MacromolecularMachineToBiologicalProcessAssociation.model_rebuild()
MacromolecularMachineToCellularComponentAssociation.model_rebuild()
MolecularActivityToChemicalEntityAssociation.model_rebuild()
MolecularActivityToMolecularActivityAssociation.model_rebuild()
GeneToGoTermAssociation.model_rebuild()
EntityToDiseaseAssociation.model_rebuild()
EntityToPhenotypicFeatureAssociation.model_rebuild()
SequenceAssociation.model_rebuild()
GenomicSequenceLocalization.model_rebuild()
SequenceFeatureRelationship.model_rebuild()
TranscriptToGeneRelationship.model_rebuild()
GeneToGeneProductRelationship.model_rebuild()
ExonToTranscriptRelationship.model_rebuild()
ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation.model_rebuild()
AnatomicalEntityToAnatomicalEntityAssociation.model_rebuild()
AnatomicalEntityToAnatomicalEntityPartOfAssociation.model_rebuild()
AnatomicalEntityToAnatomicalEntityOntogenicAssociation.model_rebuild()
OrganismTaxonToEntityAssociation.model_rebuild()
OrganismTaxonToOrganismTaxonAssociation.model_rebuild()
OrganismTaxonToOrganismTaxonSpecialization.model_rebuild()
OrganismTaxonToOrganismTaxonInteraction.model_rebuild()
OrganismTaxonToEnvironmentAssociation.model_rebuild()

